/* Generated by Cython 0.18 on Mon Jul 29 09:38:24 2013 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#if PY_MAJOR_VERSION < 3 && PY_MINOR_VERSION < 6
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((k=k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__javabridge___javabridge
#define __PYX_HAVE_API__javabridge___javabridge
#include "string.h"
#include "stdio.h"
#include "stdlib.h"
#include "numpy/arrayobject.h"
#include "numpy/ufuncobject.h"
#include "jni.h"
#include "mac_javabridge_utils.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const long n; const char* encoding; const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/

#define __Pyx_PyBytes_FromUString(s) PyBytes_FromString((char*)s)
#define __Pyx_PyBytes_AsUString(s)   ((unsigned char*) PyBytes_AsString(s))
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
    
static PyObject *__pyx_m;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "_javabridge.pyx",
  "numpy.pxd",
  "type.pxd",
};
#define IS_UNSIGNED(type) (((type) -1) > 0)
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name; /* for error messages only */
  struct __Pyx_StructField_* fields;
  size_t size;     /* sizeof(type) */
  size_t arraysize[8]; /* length of array in each dimension */
  int ndim;
  char typegroup; /* _R_eal, _C_omplex, Signed _I_nt, _U_nsigned int, _S_truct, _P_ointer, _O_bject, c_H_ar */
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;


/* "numpy.pxd":723
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "numpy.pxd":724
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "numpy.pxd":725
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "numpy.pxd":726
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "numpy.pxd":730
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "numpy.pxd":731
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "numpy.pxd":732
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "numpy.pxd":733
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "numpy.pxd":737
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "numpy.pxd":738
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "numpy.pxd":747
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "numpy.pxd":748
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "numpy.pxd":749
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "numpy.pxd":751
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "numpy.pxd":752
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "numpy.pxd":753
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "numpy.pxd":755
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "numpy.pxd":756
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "numpy.pxd":758
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "numpy.pxd":759
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "numpy.pxd":760
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif


/*--- Type declarations ---*/
struct __pyx_obj_10javabridge_11_javabridge_JB_Object;
struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID;
struct __pyx_obj_10javabridge_11_javabridge_JB_Env;
struct __pyx_obj_10javabridge_11_javabridge_JB_Class;
struct __pyx_obj_10javabridge_11_javabridge_JB_VM;
struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID;

/* "numpy.pxd":762
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "numpy.pxd":763
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "numpy.pxd":764
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "numpy.pxd":766
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;

/* "javabridge/_javabridge.pyx":323
 *     return (args.version, [args.options[i].optionString for i in range(args.nOptions)])
 * 
 * cdef class JB_Object:             # <<<<<<<<<<<<<<
 *     '''A Java object'''
 *     cdef:
 */
struct __pyx_obj_10javabridge_11_javabridge_JB_Object {
  PyObject_HEAD
  jobject o;
  PyObject *env;
  PyObject *gc_collect;
};


/* "javabridge/_javabridge.pyx":367
 *         return "<Java method with sig=%s at 0x%x>"%(self.sig,<int>(self.id))
 * 
 * cdef class __JB_FieldID:             # <<<<<<<<<<<<<<
 *     '''A field ID as returned by get_field_id'''
 *     cdef:
 */
struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID {
  PyObject_HEAD
  jfieldID id;
  PyObject *sig;
  PyObject *is_static;
};


/* "javabridge/_javabridge.pyx":546
 *             self.vm = NULL
 * 
 * cdef class JB_Env:             # <<<<<<<<<<<<<<
 *     '''Represents the Java VM and the Java execution environment'''
 *     cdef:
 */
struct __pyx_obj_10javabridge_11_javabridge_JB_Env {
  PyObject_HEAD
  JNIEnv *env;
  PyObject *defer_fn;
};


/* "javabridge/_javabridge.pyx":344
 *         return str(<int>(self.o))
 * 
 * cdef class JB_Class:             # <<<<<<<<<<<<<<
 *     '''A Java class'''
 *     cdef:
 */
struct __pyx_obj_10javabridge_11_javabridge_JB_Class {
  PyObject_HEAD
  jclass c;
};


/* "javabridge/_javabridge.pyx":448
 *                          (len(args), orig_sig))
 * 
 * cdef class JB_VM:             # <<<<<<<<<<<<<<
 *     '''Represents the Java virtual machine'''
 *     cdef JavaVM *vm
 */
struct __pyx_obj_10javabridge_11_javabridge_JB_VM {
  PyObject_HEAD
  JavaVM *vm;
};


/* "javabridge/_javabridge.pyx":353
 *         return "<Java class at 0x%x>"%<int>(self.c)
 * 
 * cdef class __JB_MethodID:             # <<<<<<<<<<<<<<
 *     '''A method ID as returned by get_method_id'''
 *     cdef:
 */
struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID {
  PyObject_HEAD
  jmethodID id;
  PyObject *sig;
  PyObject *is_static;
};

#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

static PyObject *__Pyx_GetName(PyObject *dict, PyObject *name); /*proto*/

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
#define __Pyx_GetItemInt_List(o, i, size, to_py_func) (((size) <= sizeof(Py_ssize_t)) ? \
                                                    __Pyx_GetItemInt_List_Fast(o, i) : \
                                                    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely((0 <= i) & (i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    else if ((-PyList_GET_SIZE(o) <= i) & (i < 0)) {
        PyObject *r = PyList_GET_ITEM(o, PyList_GET_SIZE(o) + i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
#define __Pyx_GetItemInt_Tuple(o, i, size, to_py_func) (((size) <= sizeof(Py_ssize_t)) ? \
                                                    __Pyx_GetItemInt_Tuple_Fast(o, i) : \
                                                    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely((0 <= i) & (i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    else if ((-PyTuple_GET_SIZE(o) <= i) & (i < 0)) {
        PyObject *r = PyTuple_GET_ITEM(o, PyTuple_GET_SIZE(o) + i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
#define __Pyx_GetItemInt(o, i, size, to_py_func) (((size) <= sizeof(Py_ssize_t)) ? \
                                                    __Pyx_GetItemInt_Fast(o, i) : \
                                                    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (PyList_CheckExact(o)) {
        Py_ssize_t n = (likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if (likely((n >= 0) & (n < PyList_GET_SIZE(o)))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = (likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if (likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {  /* inlined PySequence_GetItem() */
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (unlikely(l < 0)) return NULL;
                i += l;
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

static double __Pyx__PyObject_AsDouble(PyObject* obj); /* proto */
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj) \
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) : \
 likely(PyInt_CheckExact(obj)) ? \
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj) \
((likely(PyFloat_CheckExact(obj))) ? \
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type); /*proto*/

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

static int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact); /*proto*/

static CYTHON_INLINE long __Pyx_div_long(long, long); /* proto */

static CYTHON_INLINE long __Pyx_mod_long(long, long); /* proto */

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void); /*proto*/

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected); /*proto*/

static CYTHON_INLINE int  __Pyx_GetBufferAndValidate(Py_buffer* buf, PyObject* obj,
    __Pyx_TypeInfo* dtype, int flags, int nd, int cast, __Pyx_BufFmt_StackElem* stack);
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info);

static void __Pyx_RaiseBufferFallbackError(void); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


static Py_ssize_t __Pyx_zeros[] = {0, 0, 0, 0, 0, 0, 0, 0};
static Py_ssize_t __Pyx_minusones[] = {-1, -1, -1, -1, -1, -1, -1, -1};

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level); /*proto*/

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jint(jint);

static CYTHON_INLINE jint __Pyx_PyInt_from_py_jint(PyObject *);

static CYTHON_INLINE jbyte __Pyx_PyInt_from_py_jbyte(PyObject *);

static CYTHON_INLINE jshort __Pyx_PyInt_from_py_jshort(PyObject *);

static CYTHON_INLINE jlong __Pyx_PyInt_from_py_jlong(PyObject *);

static int __Pyx_Print(PyObject*, PyObject *, int); /*proto*/
#if CYTHON_COMPILING_IN_PYPY || PY_MAJOR_VERSION >= 3
static PyObject* __pyx_print = 0;
static PyObject* __pyx_print_kwargs = 0;
#endif

static int __Pyx_PrintOne(PyObject* stream, PyObject *o); /*proto*/

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jbyte(jbyte);

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jchar(jchar);

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jshort(jshort);

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jlong(jlong);

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(_WIN32) && defined(__cplusplus) && CYTHON_CCOMPLEX
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

#if CYTHON_CCOMPLEX
    #define __Pyx_c_eqf(a, b)   ((a)==(b))
    #define __Pyx_c_sumf(a, b)  ((a)+(b))
    #define __Pyx_c_difff(a, b) ((a)-(b))
    #define __Pyx_c_prodf(a, b) ((a)*(b))
    #define __Pyx_c_quotf(a, b) ((a)/(b))
    #define __Pyx_c_negf(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zerof(z) ((z)==(float)0)
    #define __Pyx_c_conjf(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_absf(z)     (::std::abs(z))
        #define __Pyx_c_powf(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zerof(z) ((z)==0)
    #define __Pyx_c_conjf(z)    (conjf(z))
    #if 1
        #define __Pyx_c_absf(z)     (cabsf(z))
        #define __Pyx_c_powf(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eqf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sumf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_difff(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prodf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quotf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_negf(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zerof(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conjf(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_absf(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_powf(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);

#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq(a, b)   ((a)==(b))
    #define __Pyx_c_sum(a, b)  ((a)+(b))
    #define __Pyx_c_diff(a, b) ((a)-(b))
    #define __Pyx_c_prod(a, b) ((a)*(b))
    #define __Pyx_c_quot(a, b) ((a)/(b))
    #define __Pyx_c_neg(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero(z) ((z)==(double)0)
    #define __Pyx_c_conj(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs(z)     (::std::abs(z))
        #define __Pyx_c_pow(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero(z) ((z)==0)
    #define __Pyx_c_conj(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs(z)     (cabs(z))
        #define __Pyx_c_pow(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static int __Pyx_check_binary_version(void);

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyObject *__Pyx_ImportModule(const char *name); /*proto*/

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);  /*proto*/

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;
static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *, char *, char *, int *); /*proto*/

/* Module declarations from 'cython' */

/* Module declarations from 'javabridge._javabridge' */
static PyTypeObject *__pyx_ptype_10javabridge_11_javabridge_ndarray = 0;
static PyTypeObject *__pyx_ptype_10javabridge_11_javabridge_JB_Object = 0;
static PyTypeObject *__pyx_ptype_10javabridge_11_javabridge_JB_Class = 0;
static PyTypeObject *__pyx_ptype_10javabridge_11_javabridge___JB_MethodID = 0;
static PyTypeObject *__pyx_ptype_10javabridge_11_javabridge___JB_FieldID = 0;
static PyTypeObject *__pyx_ptype_10javabridge_11_javabridge_JB_VM = 0;
static PyTypeObject *__pyx_ptype_10javabridge_11_javabridge_JB_Env = 0;
static PyObject *__pyx_f_10javabridge_11_javabridge_fill_values(PyObject *, PyObject *, jvalue **); /*proto*/
static PyObject *__pyx_f_10javabridge_11_javabridge_make_jb_object(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *, jobject); /*proto*/
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t = { "uint8_t", NULL, sizeof(__pyx_t_5numpy_uint8_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_uint8_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_uint8_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t = { "int16_t", NULL, sizeof(__pyx_t_5numpy_int16_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int16_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int16_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t = { "int32_t", NULL, sizeof(__pyx_t_5numpy_int32_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int32_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int32_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t = { "int64_t", NULL, sizeof(__pyx_t_5numpy_int64_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int64_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int64_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t = { "float32_t", NULL, sizeof(__pyx_t_5numpy_float32_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t = { "float64_t", NULL, sizeof(__pyx_t_5numpy_float64_t), { 0 }, 0, 'R', 0, 0 };
#define __Pyx_MODULE_NAME "javabridge._javabridge"
int __pyx_module_is_main_javabridge___javabridge = 0;

/* Implementation of 'javabridge._javabridge' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_unichr;
static PyObject *__pyx_pf_10javabridge_11_javabridge_get_default_java_vm_init_args(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static int __pyx_pf_10javabridge_11_javabridge_9JB_Object___cinit__(struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_9JB_Object_2__repr__(struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_self); /* proto */
static void __pyx_pf_10javabridge_11_javabridge_9JB_Object_4__dealloc__(struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_9JB_Object_6addr(struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_self); /* proto */
static int __pyx_pf_10javabridge_11_javabridge_8JB_Class___cinit__(struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_8JB_Class_2__repr__(struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_self); /* proto */
static int __pyx_pf_10javabridge_11_javabridge_13__JB_MethodID___cinit__(struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_13__JB_MethodID_2__repr__(struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_self); /* proto */
static int __pyx_pf_10javabridge_11_javabridge_12__JB_FieldID___cinit__(struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_12__JB_FieldID_2__repr__(struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_create(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_options); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_2create_mac(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_options, PyObject *__pyx_v_class_name); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_4attach(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_6attach_as_daemon(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_8detach(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_10destroy(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self); /* proto */
static int __pyx_pf_10javabridge_11_javabridge_6JB_Env___init__(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_2__repr__(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_4set_env(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, char *__pyx_v_address); /* proto */
static void __pyx_pf_10javabridge_11_javabridge_6JB_Env_6__dealloc__(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_8set_defer_fn(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_defer_fn); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_10dealloc_jobject(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_jbo); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_12get_version(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_14find_class(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, char *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_16get_object_class(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_18is_instance_of(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_20exception_occurred(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_22exception_describe(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_24exception_clear(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_26get_method_id(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, char *__pyx_v_name, char *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_28get_static_method_id(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, char *__pyx_v_name, char *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_30from_reflected_method(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_method, char *__pyx_v_sig, PyObject *__pyx_v_is_static); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_32call_method(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_34call_static_method(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_36get_field_id(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, char *__pyx_v_name, char *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_38get_object_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_40get_boolean_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_42get_byte_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_44get_short_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_46get_int_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_48get_long_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_50get_float_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_52get_double_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_54set_object_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_56set_boolean_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_58set_byte_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_60set_char_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_62set_short_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_64set_int_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_66set_long_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_68set_float_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_70set_double_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_72get_static_field_id(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, char *__pyx_v_name, char *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_74get_static_object_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_76get_static_boolean_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_78get_static_byte_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_80get_static_short_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_82get_static_int_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_84get_static_long_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_86get_static_float_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_88get_static_double_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_90set_static_object_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_92set_static_boolean_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_94set_static_byte_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_96set_static_char_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_98set_static_short_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_100set_static_int_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_102set_static_long_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_104set_static_float_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_106set_static_double_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_108new_object(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_110new_string_utf(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, char *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_112get_string_utf(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_114get_array_length(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_116get_boolean_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_118get_byte_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_120get_short_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_122get_int_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_124get_long_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_126get_float_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_128get_double_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_130get_object_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_132make_boolean_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_134make_byte_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_136make_short_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_138make_int_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_140make_long_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_142make_float_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_144make_double_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_146make_object_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, int __pyx_v_len, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_klass); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_148set_object_array_element(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_jbo, int __pyx_v_index, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_v); /* proto */
static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_150make_jb_object(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, char *__pyx_v_address); /* proto */
static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static char __pyx_k_1[] = "<Java object at 0x%x>";
static char __pyx_k_2[] = "<Java class at 0x%x>";
static char __pyx_k_3[] = "";
static char __pyx_k_4[] = "<Java method with sig=%s at 0x%x>";
static char __pyx_k_5[] = "<Java field with sig=%s at 0x%x>";
static char __pyx_k_6[] = "# of arguments (%d) in call did not match signature (%s)";
static char __pyx_k_7[] = "[";
static char __pyx_k_8[] = "%s is not a Java object";
static char __pyx_k_9[] = "Bad signature: %s";
static char __pyx_k_10[] = ";";
static char __pyx_k_12[] = "Unhandled signature: %s";
static char __pyx_k_13[] = "Too few arguments (%d) for signature (%s)";
static char __pyx_k_14[] = "Failed to allocate JavaVMInitArgs";
static char __pyx_k_16[] = "Failed to create Java VM. Return code = %d";
static char __pyx_k_18[] = "Failed to attach to current thread. Return code = %d";
static char __pyx_k_19[] = "<JB_Env at 0x%x>";
static char __pyx_k_20[] = "Failed to get class ";
static char __pyx_k_21[] = "Class = None on call to get_method_id";
static char __pyx_k_23[] = "Method ID is None - check your method ID call";
static char __pyx_k_25[] = "call_method called with a static method. Use call_static_method instead";
static char __pyx_k_27[] = "(";
static char __pyx_k_28[] = "Bad function signature: %s";
static char __pyx_k_29[] = ")";
static char __pyx_k_31[] = "Unhandled return type. Signature = %s";
static char __pyx_k_33[] = "static_call_method called with an object method. Use call_method instead";
static char __pyx_k_37[] = "Failed to allocate string";
static char __pyx_k_39[] = "Failed to allocate byte array of size %d";
static char __pyx_k_40[] = "Failed to allocate short array of size %d";
static char __pyx_k_41[] = "Failed to allocate int array of size %d";
static char __pyx_k_42[] = "Failed to allocate long array of size %d";
static char __pyx_k_43[] = "Failed to allocate float array of size %d";
static char __pyx_k_44[] = "Failed to allocate double array of size %d";
static char __pyx_k_45[] = "Failed to allocate object array of size %d";
static char __pyx_k_46[] = "Failed to make new global reference";
static char __pyx_k_48[] = "ndarray is not C contiguous";
static char __pyx_k_50[] = "ndarray is not Fortran contiguous";
static char __pyx_k_52[] = "Non-native byte order not supported";
static char __pyx_k_54[] = "unknown dtype code in numpy.pxd (%d)";
static char __pyx_k_55[] = "Format string allocated too short, see comment in numpy.pxd";
static char __pyx_k_58[] = "Format string allocated too short.";
static char __pyx_k_60[] = "javabridge - a Python/Java bridge via JNI\n\njavabridge is designed to wrap JNI at the lowest level. The bridge can create\nan environment and can make calls on the environment. However, it's up to\nhigher-level code to combine primitives into more concise operations.\n\nJavabridge implements several classes:\n\nJB_Env: represents a Java VM and environment as returned by\n         JNI_CreateJavaVM.\n\nJB_Object: represents a Java object.\n\nJava array objects are handled as numpy arrays\n\nCellProfiler is distributed under the GNU General Public License,\nbut this file is licensed under the more permissive BSD license.\nSee the accompanying file LICENSE for details.\n\nCopyright (c) 2003-2009 Massachusetts Institute of Technology\nCopyright (c) 2009-2013 Broad Institute\nAll rights reserved.\n\nPlease see the AUTHORS file for credits.\n\nWebsite: http://www.cellprofiler.org\n";
static char __pyx_k_63[] = "get_default_java_vm_init_args";
static char __pyx_k_64[] = "/Users/ljosa/src/python-javabridge/_javabridge.pyx";
static char __pyx_k_65[] = "javabridge._javabridge";
static char __pyx_k__B[] = "B";
static char __pyx_k__C[] = "C";
static char __pyx_k__D[] = "D";
static char __pyx_k__F[] = "F";
static char __pyx_k__H[] = "H";
static char __pyx_k__I[] = "I";
static char __pyx_k__J[] = "J";
static char __pyx_k__L[] = "L";
static char __pyx_k__O[] = "O";
static char __pyx_k__Q[] = "Q";
static char __pyx_k__S[] = "S";
static char __pyx_k__V[] = "V";
static char __pyx_k__Z[] = "Z";
static char __pyx_k__b[] = "b";
static char __pyx_k__c[] = "c";
static char __pyx_k__d[] = "d";
static char __pyx_k__f[] = "f";
static char __pyx_k__g[] = "g";
static char __pyx_k__h[] = "h";
static char __pyx_k__i[] = "i";
static char __pyx_k__l[] = "l";
static char __pyx_k__m[] = "m";
static char __pyx_k__o[] = "o";
static char __pyx_k__q[] = "q";
static char __pyx_k__v[] = "v";
static char __pyx_k__Zd[] = "Zd";
static char __pyx_k__Zf[] = "Zf";
static char __pyx_k__Zg[] = "Zg";
static char __pyx_k__np[] = "np";
static char __pyx_k__jbo[] = "jbo";
static char __pyx_k__len[] = "len";
static char __pyx_k__sig[] = "sig";
static char __pyx_k__sys[] = "sys";
static char __pyx_k__args[] = "args";
static char __pyx_k__find[] = "find";
static char __pyx_k__name[] = "name";
static char __pyx_k__bool8[] = "bool8";
static char __pyx_k__dtype[] = "dtype";
static char __pyx_k__field[] = "field";
static char __pyx_k__index[] = "index";
static char __pyx_k__int16[] = "int16";
static char __pyx_k__int32[] = "int32";
static char __pyx_k__int64[] = "int64";
static char __pyx_k__klass[] = "klass";
static char __pyx_k__numpy[] = "numpy";
static char __pyx_k__range[] = "range";
static char __pyx_k__shape[] = "shape";
static char __pyx_k__uint8[] = "uint8";
static char __pyx_k__value[] = "value";
static char __pyx_k__zeros[] = "zeros";
static char __pyx_k__astype[] = "astype";
static char __pyx_k__method[] = "method";
static char __pyx_k__result[] = "result";
static char __pyx_k__unichr[] = "unichr";
static char __pyx_k__float32[] = "float32";
static char __pyx_k__float64[] = "float64";
static char __pyx_k__options[] = "options";
static char __pyx_k____main__[] = "__main__";
static char __pyx_k____test__[] = "__test__";
static char __pyx_k__enumerate[] = "enumerate";
static char __pyx_k__is_static[] = "is_static";
static char __pyx_k__ValueError[] = "ValueError";
static char __pyx_k__class_name[] = "class_name";
static char __pyx_k__MemoryError[] = "MemoryError";
static char __pyx_k__RuntimeError[] = "RuntimeError";
static char __pyx_k__dealloc_jobject[] = "dealloc_jobject";
static PyObject *__pyx_kp_s_1;
static PyObject *__pyx_kp_s_10;
static PyObject *__pyx_kp_s_12;
static PyObject *__pyx_kp_s_13;
static PyObject *__pyx_kp_s_14;
static PyObject *__pyx_kp_s_16;
static PyObject *__pyx_kp_s_18;
static PyObject *__pyx_kp_s_19;
static PyObject *__pyx_kp_s_2;
static PyObject *__pyx_kp_s_20;
static PyObject *__pyx_kp_s_21;
static PyObject *__pyx_kp_s_23;
static PyObject *__pyx_kp_s_25;
static PyObject *__pyx_kp_s_27;
static PyObject *__pyx_kp_s_28;
static PyObject *__pyx_kp_s_29;
static PyObject *__pyx_kp_s_3;
static PyObject *__pyx_kp_s_31;
static PyObject *__pyx_kp_s_33;
static PyObject *__pyx_kp_s_37;
static PyObject *__pyx_kp_s_39;
static PyObject *__pyx_kp_s_4;
static PyObject *__pyx_kp_s_40;
static PyObject *__pyx_kp_s_41;
static PyObject *__pyx_kp_s_42;
static PyObject *__pyx_kp_s_43;
static PyObject *__pyx_kp_s_44;
static PyObject *__pyx_kp_s_45;
static PyObject *__pyx_kp_s_46;
static PyObject *__pyx_kp_u_48;
static PyObject *__pyx_kp_s_5;
static PyObject *__pyx_kp_u_50;
static PyObject *__pyx_kp_u_52;
static PyObject *__pyx_kp_u_54;
static PyObject *__pyx_kp_u_55;
static PyObject *__pyx_kp_u_58;
static PyObject *__pyx_kp_s_6;
static PyObject *__pyx_n_s_63;
static PyObject *__pyx_kp_s_64;
static PyObject *__pyx_n_s_65;
static PyObject *__pyx_kp_s_7;
static PyObject *__pyx_kp_s_8;
static PyObject *__pyx_kp_s_9;
static PyObject *__pyx_n_s__B;
static PyObject *__pyx_n_s__C;
static PyObject *__pyx_n_s__D;
static PyObject *__pyx_n_s__F;
static PyObject *__pyx_n_s__I;
static PyObject *__pyx_n_s__J;
static PyObject *__pyx_n_s__L;
static PyObject *__pyx_n_s__MemoryError;
static PyObject *__pyx_n_s__RuntimeError;
static PyObject *__pyx_n_s__S;
static PyObject *__pyx_n_s__V;
static PyObject *__pyx_n_s__ValueError;
static PyObject *__pyx_n_s__Z;
static PyObject *__pyx_n_s____main__;
static PyObject *__pyx_n_s____test__;
static PyObject *__pyx_n_s__args;
static PyObject *__pyx_n_s__astype;
static PyObject *__pyx_n_s__bool8;
static PyObject *__pyx_n_s__c;
static PyObject *__pyx_n_s__class_name;
static PyObject *__pyx_n_s__dealloc_jobject;
static PyObject *__pyx_n_s__dtype;
static PyObject *__pyx_n_s__enumerate;
static PyObject *__pyx_n_s__field;
static PyObject *__pyx_n_s__find;
static PyObject *__pyx_n_s__float32;
static PyObject *__pyx_n_s__float64;
static PyObject *__pyx_n_s__i;
static PyObject *__pyx_n_s__index;
static PyObject *__pyx_n_s__int16;
static PyObject *__pyx_n_s__int32;
static PyObject *__pyx_n_s__int64;
static PyObject *__pyx_n_s__is_static;
static PyObject *__pyx_n_s__jbo;
static PyObject *__pyx_n_s__klass;
static PyObject *__pyx_n_s__len;
static PyObject *__pyx_n_s__m;
static PyObject *__pyx_n_s__method;
static PyObject *__pyx_n_s__name;
static PyObject *__pyx_n_s__np;
static PyObject *__pyx_n_s__numpy;
static PyObject *__pyx_n_s__o;
static PyObject *__pyx_n_s__options;
static PyObject *__pyx_n_s__range;
static PyObject *__pyx_n_s__result;
static PyObject *__pyx_n_s__shape;
static PyObject *__pyx_n_s__sig;
static PyObject *__pyx_n_s__sys;
static PyObject *__pyx_n_s__uint8;
static PyObject *__pyx_n_s__unichr;
static PyObject *__pyx_n_s__v;
static PyObject *__pyx_n_s__value;
static PyObject *__pyx_n_s__zeros;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_int_15;
static PyObject *__pyx_k_tuple_11;
static PyObject *__pyx_k_tuple_15;
static PyObject *__pyx_k_tuple_17;
static PyObject *__pyx_k_tuple_22;
static PyObject *__pyx_k_tuple_24;
static PyObject *__pyx_k_tuple_26;
static PyObject *__pyx_k_tuple_30;
static PyObject *__pyx_k_tuple_32;
static PyObject *__pyx_k_tuple_34;
static PyObject *__pyx_k_tuple_35;
static PyObject *__pyx_k_tuple_36;
static PyObject *__pyx_k_tuple_38;
static PyObject *__pyx_k_tuple_47;
static PyObject *__pyx_k_tuple_49;
static PyObject *__pyx_k_tuple_51;
static PyObject *__pyx_k_tuple_53;
static PyObject *__pyx_k_tuple_56;
static PyObject *__pyx_k_tuple_57;
static PyObject *__pyx_k_tuple_59;
static PyObject *__pyx_k_tuple_61;
static PyObject *__pyx_k_codeobj_62;

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_1get_default_java_vm_init_args(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_get_default_java_vm_init_args[] = "Return the version and default option strings as a tuple";
static PyMethodDef __pyx_mdef_10javabridge_11_javabridge_1get_default_java_vm_init_args = {__Pyx_NAMESTR("get_default_java_vm_init_args"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_1get_default_java_vm_init_args, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_get_default_java_vm_init_args)};
static PyObject *__pyx_pw_10javabridge_11_javabridge_1get_default_java_vm_init_args(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_default_java_vm_init_args (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_get_default_java_vm_init_args(__pyx_self);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":314
 * 
 * 
 * def get_default_java_vm_init_args():             # <<<<<<<<<<<<<<
 *     '''Return the version and default option strings as a tuple'''
 *     cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_get_default_java_vm_init_args(CYTHON_UNUSED PyObject *__pyx_self) {
  JavaVMInitArgs __pyx_v_args;
  CYTHON_UNUSED jint __pyx_v_result;
  jint __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jint __pyx_t_3;
  jint __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_default_java_vm_init_args", 0);

  /* "javabridge/_javabridge.pyx":319
 *         JavaVMInitArgs args
 *         jint result
 *     args.version = JNI_VERSION_1_4             # <<<<<<<<<<<<<<
 *     result = JNI_GetDefaultJavaVMInitArgs(<void *>&args)
 *     return (args.version, [args.options[i].optionString for i in range(args.nOptions)])
 */
  __pyx_v_args.version = JNI_VERSION_1_4;

  /* "javabridge/_javabridge.pyx":320
 *         jint result
 *     args.version = JNI_VERSION_1_4
 *     result = JNI_GetDefaultJavaVMInitArgs(<void *>&args)             # <<<<<<<<<<<<<<
 *     return (args.version, [args.options[i].optionString for i in range(args.nOptions)])
 * 
 */
  __pyx_v_result = JNI_GetDefaultJavaVMInitArgs(((void *)(&__pyx_v_args)));

  /* "javabridge/_javabridge.pyx":321
 *     args.version = JNI_VERSION_1_4
 *     result = JNI_GetDefaultJavaVMInitArgs(<void *>&args)
 *     return (args.version, [args.options[i].optionString for i in range(args.nOptions)])             # <<<<<<<<<<<<<<
 * 
 * cdef class JB_Object:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jint(__pyx_v_args.version); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_v_args.nOptions;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;
    __pyx_t_5 = PyBytes_FromString((__pyx_v_args.options[__pyx_v_i]).optionString); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_5));
    if (unlikely(__Pyx_PyList_Append(__pyx_t_2, (PyObject*)__pyx_t_5))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_t_2));
  PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_r = ((PyObject *)__pyx_t_5);
  __pyx_t_5 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("javabridge._javabridge.get_default_java_vm_init_args", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_10javabridge_11_javabridge_9JB_Object_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_10javabridge_11_javabridge_9JB_Object_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_9JB_Object___cinit__(((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":329
 *         env
 *         gc_collect
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.o = NULL
 *         self.env = None
 */

static int __pyx_pf_10javabridge_11_javabridge_9JB_Object___cinit__(struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "javabridge/_javabridge.pyx":330
 *         gc_collect
 *     def __cinit__(self):
 *         self.o = NULL             # <<<<<<<<<<<<<<
 *         self.env = None
 *         self.gc_collect = False
 */
  __pyx_v_self->o = NULL;

  /* "javabridge/_javabridge.pyx":331
 *     def __cinit__(self):
 *         self.o = NULL
 *         self.env = None             # <<<<<<<<<<<<<<
 *         self.gc_collect = False
 *     def __repr__(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->env);
  __Pyx_DECREF(__pyx_v_self->env);
  __pyx_v_self->env = Py_None;

  /* "javabridge/_javabridge.pyx":332
 *         self.o = NULL
 *         self.env = None
 *         self.gc_collect = False             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return "<Java object at 0x%x>"%<int>(self.o)
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->gc_collect);
  __Pyx_DECREF(__pyx_v_self->gc_collect);
  __pyx_v_self->gc_collect = __pyx_t_1;
  __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Object.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_9JB_Object_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_10javabridge_11_javabridge_9JB_Object_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_9JB_Object_2__repr__(((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":333
 *         self.env = None
 *         self.gc_collect = False
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java object at 0x%x>"%<int>(self.o)
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_9JB_Object_2__repr__(struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "javabridge/_javabridge.pyx":334
 *         self.gc_collect = False
 *     def __repr__(self):
 *         return "<Java object at 0x%x>"%<int>(self.o)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(((int)__pyx_v_self->o)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_1), __pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Object.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static void __pyx_pw_10javabridge_11_javabridge_9JB_Object_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_10javabridge_11_javabridge_9JB_Object_5__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_10javabridge_11_javabridge_9JB_Object_4__dealloc__(((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
}

/* "javabridge/_javabridge.pyx":336
 *         return "<Java object at 0x%x>"%<int>(self.o)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.env is not None and self.gc_collect:
 *             self.env.dealloc_jobject(self)
 */

static void __pyx_pf_10javabridge_11_javabridge_9JB_Object_4__dealloc__(struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "javabridge/_javabridge.pyx":337
 * 
 *     def __dealloc__(self):
 *         if self.env is not None and self.gc_collect:             # <<<<<<<<<<<<<<
 *             self.env.dealloc_jobject(self)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->env != Py_None);
  if (__pyx_t_1) {
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->gc_collect); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 337; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = __pyx_t_1;
  }
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":338
 *     def __dealloc__(self):
 *         if self.env is not None and self.gc_collect:
 *             self.env.dealloc_jobject(self)             # <<<<<<<<<<<<<<
 * 
 *     def addr(self):
 */
    __pyx_t_4 = PyObject_GetAttr(__pyx_v_self->env, __pyx_n_s__dealloc_jobject); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __pyx_t_6 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Object.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_9JB_Object_7addr(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_9JB_Object_6addr[] = "Return the address of the Java object as a string";
static PyObject *__pyx_pw_10javabridge_11_javabridge_9JB_Object_7addr(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addr (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_9JB_Object_6addr(((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":340
 *             self.env.dealloc_jobject(self)
 * 
 *     def addr(self):             # <<<<<<<<<<<<<<
 *         '''Return the address of the Java object as a string'''
 *         return str(<int>(self.o))
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_9JB_Object_6addr(struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addr", 0);

  /* "javabridge/_javabridge.pyx":342
 *     def addr(self):
 *         '''Return the address of the Java object as a string'''
 *         return str(<int>(self.o))             # <<<<<<<<<<<<<<
 * 
 * cdef class JB_Class:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(((int)__pyx_v_self->o)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)(&PyString_Type))), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Object.addr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_10javabridge_11_javabridge_8JB_Class_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_10javabridge_11_javabridge_8JB_Class_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_8JB_Class___cinit__(((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":348
 *     cdef:
 *         jclass c
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.c = NULL
 *     def __repr__(self):
 */

static int __pyx_pf_10javabridge_11_javabridge_8JB_Class___cinit__(struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "javabridge/_javabridge.pyx":349
 *         jclass c
 *     def __cinit__(self):
 *         self.c = NULL             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return "<Java class at 0x%x>"%<int>(self.c)
 */
  __pyx_v_self->c = NULL;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_8JB_Class_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_10javabridge_11_javabridge_8JB_Class_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_8JB_Class_2__repr__(((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":350
 *     def __cinit__(self):
 *         self.c = NULL
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java class at 0x%x>"%<int>(self.c)
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_8JB_Class_2__repr__(struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "javabridge/_javabridge.pyx":351
 *         self.c = NULL
 *     def __repr__(self):
 *         return "<Java class at 0x%x>"%<int>(self.c)             # <<<<<<<<<<<<<<
 * 
 * cdef class __JB_MethodID:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(((int)__pyx_v_self->c)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_2), __pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Class.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_10javabridge_11_javabridge_13__JB_MethodID_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_10javabridge_11_javabridge_13__JB_MethodID_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_13__JB_MethodID___cinit__(((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":359
 *         sig
 *         is_static
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.id = NULL
 *         self.sig = ''
 */

static int __pyx_pf_10javabridge_11_javabridge_13__JB_MethodID___cinit__(struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "javabridge/_javabridge.pyx":360
 *         is_static
 *     def __cinit__(self):
 *         self.id = NULL             # <<<<<<<<<<<<<<
 *         self.sig = ''
 *         self.is_static = False
 */
  __pyx_v_self->id = NULL;

  /* "javabridge/_javabridge.pyx":361
 *     def __cinit__(self):
 *         self.id = NULL
 *         self.sig = ''             # <<<<<<<<<<<<<<
 *         self.is_static = False
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_3));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_3));
  __Pyx_GOTREF(__pyx_v_self->sig);
  __Pyx_DECREF(__pyx_v_self->sig);
  __pyx_v_self->sig = ((PyObject *)__pyx_kp_s_3);

  /* "javabridge/_javabridge.pyx":362
 *         self.id = NULL
 *         self.sig = ''
 *         self.is_static = False             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->is_static);
  __Pyx_DECREF(__pyx_v_self->is_static);
  __pyx_v_self->is_static = __pyx_t_1;
  __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.__JB_MethodID.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_13__JB_MethodID_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_10javabridge_11_javabridge_13__JB_MethodID_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_13__JB_MethodID_2__repr__(((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":364
 *         self.is_static = False
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java method with sig=%s at 0x%x>"%(self.sig,<int>(self.id))
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_13__JB_MethodID_2__repr__(struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "javabridge/_javabridge.pyx":365
 * 
 *     def __repr__(self):
 *         return "<Java method with sig=%s at 0x%x>"%(self.sig,<int>(self.id))             # <<<<<<<<<<<<<<
 * 
 * cdef class __JB_FieldID:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(((int)__pyx_v_self->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 365; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 365; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->sig);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->sig);
  __Pyx_GIVEREF(__pyx_v_self->sig);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_4), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 365; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.__JB_MethodID.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_10javabridge_11_javabridge_12__JB_FieldID_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_10javabridge_11_javabridge_12__JB_FieldID_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_12__JB_FieldID___cinit__(((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":373
 *         sig
 *         is_static
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.id = NULL
 *         self.sig = ''
 */

static int __pyx_pf_10javabridge_11_javabridge_12__JB_FieldID___cinit__(struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "javabridge/_javabridge.pyx":374
 *         is_static
 *     def __cinit__(self):
 *         self.id = NULL             # <<<<<<<<<<<<<<
 *         self.sig = ''
 *         self.is_static = False
 */
  __pyx_v_self->id = NULL;

  /* "javabridge/_javabridge.pyx":375
 *     def __cinit__(self):
 *         self.id = NULL
 *         self.sig = ''             # <<<<<<<<<<<<<<
 *         self.is_static = False
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_3));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_3));
  __Pyx_GOTREF(__pyx_v_self->sig);
  __Pyx_DECREF(__pyx_v_self->sig);
  __pyx_v_self->sig = ((PyObject *)__pyx_kp_s_3);

  /* "javabridge/_javabridge.pyx":376
 *         self.id = NULL
 *         self.sig = ''
 *         self.is_static = False             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->is_static);
  __Pyx_DECREF(__pyx_v_self->is_static);
  __pyx_v_self->is_static = __pyx_t_1;
  __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.__JB_FieldID.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_12__JB_FieldID_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_10javabridge_11_javabridge_12__JB_FieldID_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_12__JB_FieldID_2__repr__(((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":378
 *         self.is_static = False
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<Java field with sig=%s at 0x%x>"%(self.sig, <int>(self.id))
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_12__JB_FieldID_2__repr__(struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "javabridge/_javabridge.pyx":379
 * 
 *     def __repr__(self):
 *         return "<Java field with sig=%s at 0x%x>"%(self.sig, <int>(self.id))             # <<<<<<<<<<<<<<
 * 
 * cdef fill_values(orig_sig, args, jvalue **pvalues):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(((int)__pyx_v_self->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->sig);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->sig);
  __Pyx_GIVEREF(__pyx_v_self->sig);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_5), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.__JB_FieldID.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":381
 *         return "<Java field with sig=%s at 0x%x>"%(self.sig, <int>(self.id))
 * 
 * cdef fill_values(orig_sig, args, jvalue **pvalues):             # <<<<<<<<<<<<<<
 *     cdef:
 *         jvalue *values
 */

static PyObject *__pyx_f_10javabridge_11_javabridge_fill_values(PyObject *__pyx_v_orig_sig, PyObject *__pyx_v_args, jvalue **__pyx_v_pvalues) {
  jvalue *__pyx_v_values;
  int __pyx_v_i;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_jbobject = 0;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_jbclass = 0;
  Py_UNICODE *__pyx_v_usz;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  long __pyx_t_9;
  jbyte __pyx_t_10;
  jshort __pyx_t_11;
  jint __pyx_t_12;
  jlong __pyx_t_13;
  double __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  jobject __pyx_t_17;
  jclass __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fill_values", 0);

  /* "javabridge/_javabridge.pyx":389
 *         Py_UNICODE *usz
 * 
 *     sig = orig_sig             # <<<<<<<<<<<<<<
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))
 *     pvalues[0] = values
 */
  __Pyx_INCREF(__pyx_v_orig_sig);
  __pyx_v_sig = __pyx_v_orig_sig;

  /* "javabridge/_javabridge.pyx":390
 * 
 *     sig = orig_sig
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))             # <<<<<<<<<<<<<<
 *     pvalues[0] = values
 *     for i,arg in enumerate(args):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 390; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_values = ((jvalue *)malloc(((sizeof(jvalue)) * __pyx_t_1)));

  /* "javabridge/_javabridge.pyx":391
 *     sig = orig_sig
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))
 *     pvalues[0] = values             # <<<<<<<<<<<<<<
 *     for i,arg in enumerate(args):
 *         if len(sig) == 0:
 */
  (__pyx_v_pvalues[0]) = __pyx_v_values;

  /* "javabridge/_javabridge.pyx":392
 *     values = <jvalue *>malloc(sizeof(jvalue)*len(args))
 *     pvalues[0] = values
 *     for i,arg in enumerate(args):             # <<<<<<<<<<<<<<
 *         if len(sig) == 0:
 *             free(<void *>values)
 */
  __pyx_t_2 = 0;
  if (PyList_CheckExact(__pyx_v_args) || PyTuple_CheckExact(__pyx_v_args)) {
    __pyx_t_3 = __pyx_v_args; __Pyx_INCREF(__pyx_t_3); __pyx_t_1 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_args); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_4 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_5); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_4 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_5); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_3);
      if (unlikely(!__pyx_t_5)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF(__pyx_v_arg);
    __pyx_v_arg = __pyx_t_5;
    __pyx_t_5 = 0;
    __pyx_v_i = __pyx_t_2;
    __pyx_t_2 = (__pyx_t_2 + 1);

    /* "javabridge/_javabridge.pyx":393
 *     pvalues[0] = values
 *     for i,arg in enumerate(args):
 *         if len(sig) == 0:             # <<<<<<<<<<<<<<
 *             free(<void *>values)
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_sig); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_7 = (__pyx_t_6 == 0);
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":394
 *     for i,arg in enumerate(args):
 *         if len(sig) == 0:
 *             free(<void *>values)             # <<<<<<<<<<<<<<
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 *                               (len(args), orig_sig))
 */
      free(((void *)__pyx_v_values));

      /* "javabridge/_javabridge.pyx":395
 *         if len(sig) == 0:
 *             free(<void *>values)
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%             # <<<<<<<<<<<<<<
 *                               (len(args), orig_sig))
 *         if sig[0] == 'Z': #boolean
 */
      __Pyx_XDECREF(__pyx_r);

      /* "javabridge/_javabridge.pyx":396
 *             free(<void *>values)
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 *                               (len(args), orig_sig))             # <<<<<<<<<<<<<<
 *         if sig[0] == 'Z': #boolean
 *             values[i].z = 1 if arg else 0
 */
      __pyx_t_6 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 396; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 396; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 396; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_orig_sig);
      PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_orig_sig);
      __Pyx_GIVEREF(__pyx_v_orig_sig);
      __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_6), ((PyObject *)__pyx_t_8)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_5));
      __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
      __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_t_5));
      __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
      __pyx_t_5 = 0;
      __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L0;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "javabridge/_javabridge.pyx":397
 *             return ValueError("# of arguments (%d) in call did not match signature (%s)"%
 *                               (len(args), orig_sig))
 *         if sig[0] == 'Z': #boolean             # <<<<<<<<<<<<<<
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_5, ((PyObject *)__pyx_n_s__Z), Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":398
 *                               (len(args), orig_sig))
 *         if sig[0] == 'Z': #boolean
 *             values[i].z = 1 if arg else 0             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'B': #byte
 */
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_arg); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 398; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_7) {
        __pyx_t_9 = 1;
      } else {
        __pyx_t_9 = 0;
      }
      (__pyx_v_values[__pyx_v_i]).z = __pyx_t_9;

      /* "javabridge/_javabridge.pyx":399
 *         if sig[0] == 'Z': #boolean
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'B': #byte
 *             values[i].b = int(arg)
 */
      __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 399; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L6;
    }

    /* "javabridge/_javabridge.pyx":400
 *             values[i].z = 1 if arg else 0
 *             sig = sig[1:]
 *         elif sig[0] == 'B': #byte             # <<<<<<<<<<<<<<
 *             values[i].b = int(arg)
 *             sig = sig[1:]
 */
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_8) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 400; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_n_s__B), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 400; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 400; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":401
 *             sig = sig[1:]
 *         elif sig[0] == 'B': #byte
 *             values[i].b = int(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'C': #char
 */
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 401; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_arg);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_arg);
      __Pyx_GIVEREF(__pyx_v_arg);
      __pyx_t_8 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 401; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __pyx_t_10 = __Pyx_PyInt_from_py_jbyte(__pyx_t_8); if (unlikely((__pyx_t_10 == (jbyte)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 401; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      (__pyx_v_values[__pyx_v_i]).b = __pyx_t_10;

      /* "javabridge/_javabridge.pyx":402
 *         elif sig[0] == 'B': #byte
 *             values[i].b = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'C': #char
 *             usz = PyUnicode_AS_UNICODE(unicode(arg))
 */
      __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L6;
    }

    /* "javabridge/_javabridge.pyx":403
 *             values[i].b = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'C': #char             # <<<<<<<<<<<<<<
 *             usz = PyUnicode_AS_UNICODE(unicode(arg))
 *             values[i].c = usz[0]
 */
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_8) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 403; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_n_s__C), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 403; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 403; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":404
 *             sig = sig[1:]
 *         elif sig[0] == 'C': #char
 *             usz = PyUnicode_AS_UNICODE(unicode(arg))             # <<<<<<<<<<<<<<
 *             values[i].c = usz[0]
 *             sig = sig[1:]
 */
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 404; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_arg);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_arg);
      __Pyx_GIVEREF(__pyx_v_arg);
      __pyx_t_8 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 404; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __pyx_v_usz = PyUnicode_AS_UNICODE(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "javabridge/_javabridge.pyx":405
 *         elif sig[0] == 'C': #char
 *             usz = PyUnicode_AS_UNICODE(unicode(arg))
 *             values[i].c = usz[0]             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'S': #short
 */
      (__pyx_v_values[__pyx_v_i]).c = (__pyx_v_usz[0]);

      /* "javabridge/_javabridge.pyx":406
 *             usz = PyUnicode_AS_UNICODE(unicode(arg))
 *             values[i].c = usz[0]
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'S': #short
 *             values[i].s = int(arg)
 */
      __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L6;
    }

    /* "javabridge/_javabridge.pyx":407
 *             values[i].c = usz[0]
 *             sig = sig[1:]
 *         elif sig[0] == 'S': #short             # <<<<<<<<<<<<<<
 *             values[i].s = int(arg)
 *             sig = sig[1:]
 */
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_8) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 407; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_n_s__S), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 407; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 407; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":408
 *             sig = sig[1:]
 *         elif sig[0] == 'S': #short
 *             values[i].s = int(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'I': #int
 */
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 408; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_arg);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_arg);
      __Pyx_GIVEREF(__pyx_v_arg);
      __pyx_t_8 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 408; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __pyx_t_11 = __Pyx_PyInt_from_py_jshort(__pyx_t_8); if (unlikely((__pyx_t_11 == (jshort)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 408; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      (__pyx_v_values[__pyx_v_i]).s = __pyx_t_11;

      /* "javabridge/_javabridge.pyx":409
 *         elif sig[0] == 'S': #short
 *             values[i].s = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'I': #int
 *             values[i].i = int(arg)
 */
      __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L6;
    }

    /* "javabridge/_javabridge.pyx":410
 *             values[i].s = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'I': #int             # <<<<<<<<<<<<<<
 *             values[i].i = int(arg)
 *             sig = sig[1:]
 */
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_8) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_n_s__I), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":411
 *             sig = sig[1:]
 *         elif sig[0] == 'I': #int
 *             values[i].i = int(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'J': #long
 */
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_arg);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_arg);
      __Pyx_GIVEREF(__pyx_v_arg);
      __pyx_t_8 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __pyx_t_12 = __Pyx_PyInt_from_py_jint(__pyx_t_8); if (unlikely((__pyx_t_12 == (jint)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      (__pyx_v_values[__pyx_v_i]).i = __pyx_t_12;

      /* "javabridge/_javabridge.pyx":412
 *         elif sig[0] == 'I': #int
 *             values[i].i = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'J': #long
 *             values[i].j = int(arg)
 */
      __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 412; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L6;
    }

    /* "javabridge/_javabridge.pyx":413
 *             values[i].i = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'J': #long             # <<<<<<<<<<<<<<
 *             values[i].j = int(arg)
 *             sig = sig[1:]
 */
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_8) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_n_s__J), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":414
 *             sig = sig[1:]
 *         elif sig[0] == 'J': #long
 *             values[i].j = int(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'F': #float
 */
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 414; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_arg);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_arg);
      __Pyx_GIVEREF(__pyx_v_arg);
      __pyx_t_8 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 414; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __pyx_t_13 = __Pyx_PyInt_from_py_jlong(__pyx_t_8); if (unlikely((__pyx_t_13 == (jlong)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 414; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      (__pyx_v_values[__pyx_v_i]).j = __pyx_t_13;

      /* "javabridge/_javabridge.pyx":415
 *         elif sig[0] == 'J': #long
 *             values[i].j = int(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'F': #float
 *             values[i].f = float(arg)
 */
      __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 415; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L6;
    }

    /* "javabridge/_javabridge.pyx":416
 *             values[i].j = int(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'F': #float             # <<<<<<<<<<<<<<
 *             values[i].f = float(arg)
 *             sig = sig[1:]
 */
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_8) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_n_s__F), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":417
 *             sig = sig[1:]
 *         elif sig[0] == 'F': #float
 *             values[i].f = float(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'D': #double
 */
      __pyx_t_14 = __Pyx_PyObject_AsDouble(__pyx_v_arg); if (unlikely(__pyx_t_14 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 417; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      (__pyx_v_values[__pyx_v_i]).f = __pyx_t_14;

      /* "javabridge/_javabridge.pyx":418
 *         elif sig[0] == 'F': #float
 *             values[i].f = float(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'D': #double
 *             values[i].d = float(arg)
 */
      __pyx_t_5 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L6;
    }

    /* "javabridge/_javabridge.pyx":419
 *             values[i].f = float(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'D': #double             # <<<<<<<<<<<<<<
 *             values[i].d = float(arg)
 *             sig = sig[1:]
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 419; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_5, ((PyObject *)__pyx_n_s__D), Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 419; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 419; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":420
 *             sig = sig[1:]
 *         elif sig[0] == 'D': #double
 *             values[i].d = float(arg)             # <<<<<<<<<<<<<<
 *             sig = sig[1:]
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 */
      __pyx_t_14 = __Pyx_PyObject_AsDouble(__pyx_v_arg); if (unlikely(__pyx_t_14 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      (__pyx_v_values[__pyx_v_i]).d = __pyx_t_14;

      /* "javabridge/_javabridge.pyx":421
 *         elif sig[0] == 'D': #double
 *             values[i].d = float(arg)
 *             sig = sig[1:]             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 *             if isinstance(arg, JB_Object):
 */
      __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 421; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L6;
    }

    /* "javabridge/_javabridge.pyx":422
 *             values[i].d = float(arg)
 *             sig = sig[1:]
 *         elif sig[0] == 'L' or sig[0] == '[': #object             # <<<<<<<<<<<<<<
 *             if isinstance(arg, JB_Object):
 *                  jbobject = arg
 */
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_8) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_n_s__L), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!__pyx_t_7) {
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = PyObject_RichCompare(__pyx_t_5, ((PyObject *)__pyx_kp_s_7), Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_15 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_16 = __pyx_t_15;
    } else {
      __pyx_t_16 = __pyx_t_7;
    }
    if (__pyx_t_16) {

      /* "javabridge/_javabridge.pyx":423
 *             sig = sig[1:]
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 *             if isinstance(arg, JB_Object):             # <<<<<<<<<<<<<<
 *                  jbobject = arg
 *                  values[i].l = jbobject.o
 */
      __pyx_t_16 = __Pyx_TypeCheck(__pyx_v_arg, ((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Object)); 
      if (__pyx_t_16) {

        /* "javabridge/_javabridge.pyx":424
 *         elif sig[0] == 'L' or sig[0] == '[': #object
 *             if isinstance(arg, JB_Object):
 *                  jbobject = arg             # <<<<<<<<<<<<<<
 *                  values[i].l = jbobject.o
 *             elif isinstance(arg, JB_Class):
 */
        if (!(likely(((__pyx_v_arg) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_arg, __pyx_ptype_10javabridge_11_javabridge_JB_Object))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 424; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_INCREF(__pyx_v_arg);
        __Pyx_XDECREF(((PyObject *)__pyx_v_jbobject));
        __pyx_v_jbobject = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_arg);

        /* "javabridge/_javabridge.pyx":425
 *             if isinstance(arg, JB_Object):
 *                  jbobject = arg
 *                  values[i].l = jbobject.o             # <<<<<<<<<<<<<<
 *             elif isinstance(arg, JB_Class):
 *                  jbclass = arg
 */
        __pyx_t_17 = __pyx_v_jbobject->o;
        (__pyx_v_values[__pyx_v_i]).l = __pyx_t_17;
        goto __pyx_L7;
      }

      /* "javabridge/_javabridge.pyx":426
 *                  jbobject = arg
 *                  values[i].l = jbobject.o
 *             elif isinstance(arg, JB_Class):             # <<<<<<<<<<<<<<
 *                  jbclass = arg
 *                  values[i].l = jbclass.c
 */
      __pyx_t_16 = __Pyx_TypeCheck(__pyx_v_arg, ((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Class)); 
      if (__pyx_t_16) {

        /* "javabridge/_javabridge.pyx":427
 *                  values[i].l = jbobject.o
 *             elif isinstance(arg, JB_Class):
 *                  jbclass = arg             # <<<<<<<<<<<<<<
 *                  values[i].l = jbclass.c
 *             elif arg is None:
 */
        if (!(likely(((__pyx_v_arg) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_arg, __pyx_ptype_10javabridge_11_javabridge_JB_Class))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_INCREF(__pyx_v_arg);
        __Pyx_XDECREF(((PyObject *)__pyx_v_jbclass));
        __pyx_v_jbclass = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)__pyx_v_arg);

        /* "javabridge/_javabridge.pyx":428
 *             elif isinstance(arg, JB_Class):
 *                  jbclass = arg
 *                  values[i].l = jbclass.c             # <<<<<<<<<<<<<<
 *             elif arg is None:
 *                  values[i].l = NULL
 */
        __pyx_t_18 = __pyx_v_jbclass->c;
        (__pyx_v_values[__pyx_v_i]).l = __pyx_t_18;
        goto __pyx_L7;
      }

      /* "javabridge/_javabridge.pyx":429
 *                  jbclass = arg
 *                  values[i].l = jbclass.c
 *             elif arg is None:             # <<<<<<<<<<<<<<
 *                  values[i].l = NULL
 *             else:
 */
      __pyx_t_16 = (__pyx_v_arg == Py_None);
      if (__pyx_t_16) {

        /* "javabridge/_javabridge.pyx":430
 *                  values[i].l = jbclass.c
 *             elif arg is None:
 *                  values[i].l = NULL             # <<<<<<<<<<<<<<
 *             else:
 *                  free(<void *>values)
 */
        (__pyx_v_values[__pyx_v_i]).l = NULL;
        goto __pyx_L7;
      }
      /*else*/ {

        /* "javabridge/_javabridge.pyx":432
 *                  values[i].l = NULL
 *             else:
 *                  free(<void *>values)             # <<<<<<<<<<<<<<
 *                  return ValueError("%s is not a Java object"%str(arg))
 *             if sig[0] == '[':
 */
        free(((void *)__pyx_v_values));

        /* "javabridge/_javabridge.pyx":433
 *             else:
 *                  free(<void *>values)
 *                  return ValueError("%s is not a Java object"%str(arg))             # <<<<<<<<<<<<<<
 *             if sig[0] == '[':
 *                  if len(sig) == 1:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_arg);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_arg);
        __Pyx_GIVEREF(__pyx_v_arg);
        __pyx_t_5 = PyObject_Call(((PyObject *)((PyObject*)(&PyString_Type))), ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
        __pyx_t_8 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_8), __pyx_t_5); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_8));
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_t_8));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
        __pyx_t_8 = 0;
        __pyx_t_8 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
        __pyx_r = __pyx_t_8;
        __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L0;
      }
      __pyx_L7:;

      /* "javabridge/_javabridge.pyx":434
 *                  free(<void *>values)
 *                  return ValueError("%s is not a Java object"%str(arg))
 *             if sig[0] == '[':             # <<<<<<<<<<<<<<
 *                  if len(sig) == 1:
 *                      raise ValueError("Bad signature: %s"%orig_sig)
 */
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_8) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_kp_s_7), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_16 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_16) {

        /* "javabridge/_javabridge.pyx":435
 *                  return ValueError("%s is not a Java object"%str(arg))
 *             if sig[0] == '[':
 *                  if len(sig) == 1:             # <<<<<<<<<<<<<<
 *                      raise ValueError("Bad signature: %s"%orig_sig)
 *                  if sig[1] != 'L':
 */
        __pyx_t_6 = PyObject_Length(__pyx_v_sig); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_16 = (__pyx_t_6 == 1);
        if (__pyx_t_16) {

          /* "javabridge/_javabridge.pyx":436
 *             if sig[0] == '[':
 *                  if len(sig) == 1:
 *                      raise ValueError("Bad signature: %s"%orig_sig)             # <<<<<<<<<<<<<<
 *                  if sig[1] != 'L':
 *                      # An array of primitive type:
 */
          __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_9), __pyx_v_orig_sig); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(((PyObject *)__pyx_t_5));
          __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_t_5));
          __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
          __pyx_t_5 = 0;
          __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
          __Pyx_Raise(__pyx_t_5, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L9;
        }
        __pyx_L9:;

        /* "javabridge/_javabridge.pyx":437
 *                  if len(sig) == 1:
 *                      raise ValueError("Bad signature: %s"%orig_sig)
 *                  if sig[1] != 'L':             # <<<<<<<<<<<<<<
 *                      # An array of primitive type:
 *                      sig = sig[2:]
 */
        __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_sig, 1, sizeof(long), PyInt_FromLong); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = PyObject_RichCompare(__pyx_t_5, ((PyObject *)__pyx_n_s__L), Py_NE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_16 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_16) {

          /* "javabridge/_javabridge.pyx":439
 *                  if sig[1] != 'L':
 *                      # An array of primitive type:
 *                      sig = sig[2:]             # <<<<<<<<<<<<<<
 *                      continue
 *             sig = sig[sig.find(';')+1:]
 */
          __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 2, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 439; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_v_sig);
          __pyx_v_sig = __pyx_t_8;
          __pyx_t_8 = 0;

          /* "javabridge/_javabridge.pyx":440
 *                      # An array of primitive type:
 *                      sig = sig[2:]
 *                      continue             # <<<<<<<<<<<<<<
 *             sig = sig[sig.find(';')+1:]
 *         else:
 */
          goto __pyx_L3_continue;
          goto __pyx_L10;
        }
        __pyx_L10:;
        goto __pyx_L8;
      }
      __pyx_L8:;

      /* "javabridge/_javabridge.pyx":441
 *                      sig = sig[2:]
 *                      continue
 *             sig = sig[sig.find(';')+1:]             # <<<<<<<<<<<<<<
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 */
      __pyx_t_8 = PyObject_GetAttr(__pyx_v_sig, __pyx_n_s__find); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_5 = PyObject_Call(__pyx_t_8, ((PyObject *)__pyx_k_tuple_11), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyNumber_Add(__pyx_t_5, __pyx_int_1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PySequence_GetSlice(__pyx_v_sig, __pyx_t_6, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_v_sig);
      __pyx_v_sig = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L6;
    }
    /*else*/ {

      /* "javabridge/_javabridge.pyx":443
 *             sig = sig[sig.find(';')+1:]
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)             # <<<<<<<<<<<<<<
 *     if len(sig) > 0:
 *         return ValueError("Too few arguments (%d) for signature (%s)"%
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_12), __pyx_v_orig_sig); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_8));
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_t_8));
      __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
      __pyx_t_8 = 0;
      __pyx_t_8 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L0;
    }
    __pyx_L6:;
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":444
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 *     if len(sig) > 0:             # <<<<<<<<<<<<<<
 *         return ValueError("Too few arguments (%d) for signature (%s)"%
 *                          (len(args), orig_sig))
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_sig); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 444; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_16 = (__pyx_t_1 > 0);
  if (__pyx_t_16) {

    /* "javabridge/_javabridge.pyx":445
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 *     if len(sig) > 0:
 *         return ValueError("Too few arguments (%d) for signature (%s)"%             # <<<<<<<<<<<<<<
 *                          (len(args), orig_sig))
 * 
 */
    __Pyx_XDECREF(__pyx_r);

    /* "javabridge/_javabridge.pyx":446
 *     if len(sig) > 0:
 *         return ValueError("Too few arguments (%d) for signature (%s)"%
 *                          (len(args), orig_sig))             # <<<<<<<<<<<<<<
 * 
 * cdef class JB_VM:
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 446; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 446; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 446; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_orig_sig);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_orig_sig);
    __Pyx_GIVEREF(__pyx_v_orig_sig);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_13), ((PyObject *)__pyx_t_8)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 445; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
    __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 445; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 445; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
    goto __pyx_L11;
  }
  __pyx_L11:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("javabridge._javabridge.fill_values", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbobject);
  __Pyx_XDECREF((PyObject *)__pyx_v_jbclass);
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_1create(PyObject *__pyx_v_self, PyObject *__pyx_v_options); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_5JB_VM_create[] = "Create the Java VM";
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_1create(PyObject *__pyx_v_self, PyObject *__pyx_v_options) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_5JB_VM_create(((struct __pyx_obj_10javabridge_11_javabridge_JB_VM *)__pyx_v_self), ((PyObject *)__pyx_v_options));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":452
 *     cdef JavaVM *vm
 * 
 *     def create(self, options):             # <<<<<<<<<<<<<<
 *         '''Create the Java VM'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_create(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_options) {
  JavaVMInitArgs __pyx_v_args;
  JNIEnv *__pyx_v_env;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_jenv = 0;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_option = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  char *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);
  __Pyx_INCREF(__pyx_v_options);

  /* "javabridge/_javabridge.pyx":459
 *             JB_Env jenv
 * 
 *         args.version = JNI_VERSION_1_4             # <<<<<<<<<<<<<<
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 */
  __pyx_v_args.version = JNI_VERSION_1_4;

  /* "javabridge/_javabridge.pyx":460
 * 
 *         args.version = JNI_VERSION_1_4
 *         args.nOptions = len(options)             # <<<<<<<<<<<<<<
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_options); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 460; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_args.nOptions = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":461
 *         args.version = JNI_VERSION_1_4
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)             # <<<<<<<<<<<<<<
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 */
  __pyx_v_args.options = ((JavaVMOption *)malloc(((sizeof(JavaVMOption)) * __pyx_v_args.nOptions)));

  /* "javabridge/_javabridge.pyx":462
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]
 */
  __pyx_t_2 = (__pyx_v_args.options == NULL);
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":463
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")             # <<<<<<<<<<<<<<
 *         options = [str(option) for option in options]
 *         for i, option in enumerate(options):
 */
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_k_tuple_15), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 463; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 463; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":464
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]             # <<<<<<<<<<<<<<
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyList_CheckExact(__pyx_v_options) || PyTuple_CheckExact(__pyx_v_options)) {
    __pyx_t_4 = __pyx_v_options; __Pyx_INCREF(__pyx_t_4); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_options); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_4)) {
      if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_4)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_4)) {
      if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_6 = __pyx_t_5(__pyx_t_4);
      if (unlikely(!__pyx_t_6)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF(__pyx_v_option);
    __pyx_v_option = __pyx_t_6;
    __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_option);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_option);
    __Pyx_GIVEREF(__pyx_v_option);
    __pyx_t_7 = PyObject_Call(((PyObject *)((PyObject*)(&PyString_Type))), ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
    if (unlikely(__Pyx_PyList_Append(__pyx_t_3, (PyObject*)__pyx_t_7))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = ((PyObject *)__pyx_t_3);
  __Pyx_INCREF(__pyx_t_4);
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_v_options);
  __pyx_v_options = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":465
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]
 *         for i, option in enumerate(options):             # <<<<<<<<<<<<<<
 *             args.options[i].optionString = option
 *         result = JNI_CreateJavaVM(&self.vm, <void **>&env, &args)
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_4 = __pyx_int_0;
  if (PyList_CheckExact(__pyx_v_options) || PyTuple_CheckExact(__pyx_v_options)) {
    __pyx_t_3 = __pyx_v_options; __Pyx_INCREF(__pyx_t_3); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_options); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_7 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_7 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_7 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_7 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_7)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF(__pyx_v_option);
    __pyx_v_option = __pyx_t_7;
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_XDECREF(__pyx_v_i);
    __pyx_v_i = __pyx_t_4;
    __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_int_1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4);
    __pyx_t_4 = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "javabridge/_javabridge.pyx":466
 *         options = [str(option) for option in options]
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option             # <<<<<<<<<<<<<<
 *         result = JNI_CreateJavaVM(&self.vm, <void **>&env, &args)
 *         free(args.options)
 */
    __pyx_t_8 = PyBytes_AsString(__pyx_v_option); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    (__pyx_v_args.options[__pyx_t_9]).optionString = __pyx_t_8;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":467
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option
 *         result = JNI_CreateJavaVM(&self.vm, <void **>&env, &args)             # <<<<<<<<<<<<<<
 *         free(args.options)
 *         if result != 0:
 */
  __pyx_t_4 = __Pyx_PyInt_to_py_jint(JNI_CreateJavaVM((&__pyx_v_self->vm), ((void **)(&__pyx_v_env)), (&__pyx_v_args))); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 467; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":468
 *             args.options[i].optionString = option
 *         result = JNI_CreateJavaVM(&self.vm, <void **>&env, &args)
 *         free(args.options)             # <<<<<<<<<<<<<<
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 */
  free(__pyx_v_args.options);

  /* "javabridge/_javabridge.pyx":469
 *         result = JNI_CreateJavaVM(&self.vm, <void **>&env, &args)
 *         free(args.options)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_result, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 469; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 469; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":470
 *         free(args.options)
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)             # <<<<<<<<<<<<<<
 *         jenv = JB_Env()
 *         jenv.env = env
 */
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_16), __pyx_v_result); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_4));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L8;
  }
  __pyx_L8:;

  /* "javabridge/_javabridge.pyx":471
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 *         jenv = JB_Env()             # <<<<<<<<<<<<<<
 *         jenv.env = env
 *         return jenv
 */
  __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Env)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_jenv = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":472
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 *         jenv = JB_Env()
 *         jenv.env = env             # <<<<<<<<<<<<<<
 *         return jenv
 * 
 */
  __pyx_v_jenv->env = __pyx_v_env;

  /* "javabridge/_javabridge.pyx":473
 *         jenv = JB_Env()
 *         jenv.env = env
 *         return jenv             # <<<<<<<<<<<<<<
 * 
 *     def create_mac(self, options, class_name):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jenv));
  __pyx_r = ((PyObject *)__pyx_v_jenv);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("javabridge._javabridge.JB_VM.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jenv);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_option);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_options);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_3create_mac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_5JB_VM_2create_mac[] = "Create the Java VM on OS/X in a different thread\n        \n        On the Mac, (assuming this works), you need to start a PThread \n        and do so in a very particular manner if you ever want to run UI\n        code in Java and Python. This creates that thread and it then runs\n        a runnable.\n        \n        org.cellprofiler.runnablequeue.RunnableQueue is a class that uses\n        a queue to ferry runnables to this main thread. You can use that\n        and then call RunnableQueue's static methods to run things on the\n        main thread.\n        \n        You should run this on its own thread since it will not return until\n        after the JVM exits.\n        \n        options - the option strings\n        \n        class_name - the name of the Runnable to run on the Java main thread\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_3create_mac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_options = 0;
  PyObject *__pyx_v_class_name = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_mac (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__options,&__pyx_n_s__class_name,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__options)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__class_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("create_mac", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 475; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_mac") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 475; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_options = values[0];
    __pyx_v_class_name = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_mac", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 475; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_VM.create_mac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_5JB_VM_2create_mac(((struct __pyx_obj_10javabridge_11_javabridge_JB_VM *)__pyx_v_self), __pyx_v_options, __pyx_v_class_name);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":475
 *         return jenv
 * 
 *     def create_mac(self, options, class_name):             # <<<<<<<<<<<<<<
 *         '''Create the Java VM on OS/X in a different thread
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_2create_mac(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self, PyObject *__pyx_v_options, PyObject *__pyx_v_class_name) {
  JavaVMInitArgs __pyx_v_args;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_option = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  char *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_mac", 0);
  __Pyx_INCREF(__pyx_v_options);

  /* "javabridge/_javabridge.pyx":500
 *             JB_Env jenv
 * 
 *         args.version = JNI_VERSION_1_4             # <<<<<<<<<<<<<<
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 */
  __pyx_v_args.version = JNI_VERSION_1_4;

  /* "javabridge/_javabridge.pyx":501
 * 
 *         args.version = JNI_VERSION_1_4
 *         args.nOptions = len(options)             # <<<<<<<<<<<<<<
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_options); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 501; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_args.nOptions = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":502
 *         args.version = JNI_VERSION_1_4
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)             # <<<<<<<<<<<<<<
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 */
  __pyx_v_args.options = ((JavaVMOption *)malloc(((sizeof(JavaVMOption)) * __pyx_v_args.nOptions)));

  /* "javabridge/_javabridge.pyx":503
 *         args.nOptions = len(options)
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]
 */
  __pyx_t_2 = (__pyx_v_args.options == NULL);
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":504
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")             # <<<<<<<<<<<<<<
 *         options = [str(option) for option in options]
 *         for i, option in enumerate(options):
 */
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_k_tuple_17), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":505
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]             # <<<<<<<<<<<<<<
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyList_CheckExact(__pyx_v_options) || PyTuple_CheckExact(__pyx_v_options)) {
    __pyx_t_4 = __pyx_v_options; __Pyx_INCREF(__pyx_t_4); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_options); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_4)) {
      if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_4)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_4)) {
      if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_6 = __pyx_t_5(__pyx_t_4);
      if (unlikely(!__pyx_t_6)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF(__pyx_v_option);
    __pyx_v_option = __pyx_t_6;
    __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_option);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_option);
    __Pyx_GIVEREF(__pyx_v_option);
    __pyx_t_7 = PyObject_Call(((PyObject *)((PyObject*)(&PyString_Type))), ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
    if (unlikely(__Pyx_PyList_Append(__pyx_t_3, (PyObject*)__pyx_t_7))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = ((PyObject *)__pyx_t_3);
  __Pyx_INCREF(__pyx_t_4);
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_v_options);
  __pyx_v_options = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":506
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")
 *         options = [str(option) for option in options]
 *         for i, option in enumerate(options):             # <<<<<<<<<<<<<<
 *             args.options[i].optionString = option
 *         result = MacStartVM(&self.vm, &args, class_name)
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_4 = __pyx_int_0;
  if (PyList_CheckExact(__pyx_v_options) || PyTuple_CheckExact(__pyx_v_options)) {
    __pyx_t_3 = __pyx_v_options; __Pyx_INCREF(__pyx_t_3); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_options); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_7 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_7 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_7 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_7 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_7)) {
        if (PyErr_Occurred()) {
          if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF(__pyx_v_option);
    __pyx_v_option = __pyx_t_7;
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_XDECREF(__pyx_v_i);
    __pyx_v_i = __pyx_t_4;
    __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_int_1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4);
    __pyx_t_4 = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "javabridge/_javabridge.pyx":507
 *         options = [str(option) for option in options]
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option             # <<<<<<<<<<<<<<
 *         result = MacStartVM(&self.vm, &args, class_name)
 *         free(args.options)
 */
    __pyx_t_8 = PyBytes_AsString(__pyx_v_option); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 507; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 507; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    (__pyx_v_args.options[__pyx_t_9]).optionString = __pyx_t_8;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":508
 *         for i, option in enumerate(options):
 *             args.options[i].optionString = option
 *         result = MacStartVM(&self.vm, &args, class_name)             # <<<<<<<<<<<<<<
 *         free(args.options)
 *         if result != 0:
 */
  __pyx_t_8 = PyBytes_AsString(__pyx_v_class_name); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = PyInt_FromLong(MacStartVM((&__pyx_v_self->vm), (&__pyx_v_args), __pyx_t_8)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":509
 *             args.options[i].optionString = option
 *         result = MacStartVM(&self.vm, &args, class_name)
 *         free(args.options)             # <<<<<<<<<<<<<<
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 */
  free(__pyx_v_args.options);

  /* "javabridge/_javabridge.pyx":510
 *         result = MacStartVM(&self.vm, &args, class_name)
 *         free(args.options)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 * 
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_result, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":511
 *         free(args.options)
 *         if result != 0:
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)             # <<<<<<<<<<<<<<
 * 
 *     def attach(self):
 */
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_16), __pyx_v_result); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_4));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L8;
  }
  __pyx_L8:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("javabridge._javabridge.JB_VM.create_mac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_option);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_options);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_5attach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_5JB_VM_4attach[] = "Attach this thread to the VM returning an environment";
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_5attach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("attach (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_5JB_VM_4attach(((struct __pyx_obj_10javabridge_11_javabridge_JB_VM *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":513
 *             raise RuntimeError("Failed to create Java VM. Return code = %d"%result)
 * 
 *     def attach(self):             # <<<<<<<<<<<<<<
 *         '''Attach this thread to the VM returning an environment'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_4attach(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self) {
  JNIEnv *__pyx_v_env;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_jenv = 0;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("attach", 0);

  /* "javabridge/_javabridge.pyx":518
 *             JNIEnv *env
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThread(self.vm, <void **>&env, NULL)             # <<<<<<<<<<<<<<
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 */
  __pyx_t_1 = __Pyx_PyInt_to_py_jint((__pyx_v_self->vm[0])->AttachCurrentThread(__pyx_v_self->vm, ((void **)(&__pyx_v_env)), NULL)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 518; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":519
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThread(self.vm, <void **>&env, NULL)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_result, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":520
 *         result = self.vm[0].AttachCurrentThread(self.vm, <void **>&env, NULL)
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)             # <<<<<<<<<<<<<<
 *         jenv = JB_Env()
 *         jenv.env = env
 */
    __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_18), __pyx_v_result); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 520; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 520; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_1));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 520; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 520; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":521
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()             # <<<<<<<<<<<<<<
 *         jenv.env = env
 *         return jenv
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Env)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_jenv = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":522
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 *         jenv.env = env             # <<<<<<<<<<<<<<
 *         return jenv
 * 
 */
  __pyx_v_jenv->env = __pyx_v_env;

  /* "javabridge/_javabridge.pyx":523
 *         jenv = JB_Env()
 *         jenv.env = env
 *         return jenv             # <<<<<<<<<<<<<<
 * 
 *     def attach_as_daemon(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jenv));
  __pyx_r = ((PyObject *)__pyx_v_jenv);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("javabridge._javabridge.JB_VM.attach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jenv);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_7attach_as_daemon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_5JB_VM_6attach_as_daemon[] = "Attach this thread as a daemon thread";
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_7attach_as_daemon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("attach_as_daemon (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_5JB_VM_6attach_as_daemon(((struct __pyx_obj_10javabridge_11_javabridge_JB_VM *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":525
 *         return jenv
 * 
 *     def attach_as_daemon(self):             # <<<<<<<<<<<<<<
 *         '''Attach this thread as a daemon thread'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_6attach_as_daemon(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self) {
  JNIEnv *__pyx_v_env;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_jenv = 0;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("attach_as_daemon", 0);

  /* "javabridge/_javabridge.pyx":530
 *             JNIEnv *env
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThreadAsDaemon(self.vm, <void *>&env, NULL)             # <<<<<<<<<<<<<<
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 */
  __pyx_t_1 = __Pyx_PyInt_to_py_jint((__pyx_v_self->vm[0])->AttachCurrentThreadAsDaemon(__pyx_v_self->vm, ((void *)(&__pyx_v_env)), NULL)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":531
 *             JB_Env jenv
 *         result = self.vm[0].AttachCurrentThreadAsDaemon(self.vm, <void *>&env, NULL)
 *         if result != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_result, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 531; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 531; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":532
 *         result = self.vm[0].AttachCurrentThreadAsDaemon(self.vm, <void *>&env, NULL)
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)             # <<<<<<<<<<<<<<
 *         jenv = JB_Env()
 *         jenv.env = env
 */
    __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_18), __pyx_v_result); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_1));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":533
 *         if result != 0:
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()             # <<<<<<<<<<<<<<
 *         jenv.env = env
 *         return jenv
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Env)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 533; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_jenv = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":534
 *             raise RuntimeError("Failed to attach to current thread. Return code = %d"%result)
 *         jenv = JB_Env()
 *         jenv.env = env             # <<<<<<<<<<<<<<
 *         return jenv
 * 
 */
  __pyx_v_jenv->env = __pyx_v_env;

  /* "javabridge/_javabridge.pyx":535
 *         jenv = JB_Env()
 *         jenv.env = env
 *         return jenv             # <<<<<<<<<<<<<<
 * 
 *     def detach(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jenv));
  __pyx_r = ((PyObject *)__pyx_v_jenv);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("javabridge._javabridge.JB_VM.attach_as_daemon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jenv);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_9detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_5JB_VM_8detach[] = "Detach this thread from the VM";
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_9detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("detach (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_5JB_VM_8detach(((struct __pyx_obj_10javabridge_11_javabridge_JB_VM *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":537
 *         return jenv
 * 
 *     def detach(self):             # <<<<<<<<<<<<<<
 *         '''Detach this thread from the VM'''
 *         self.vm[0].DetachCurrentThread(self.vm)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_8detach(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("detach", 0);

  /* "javabridge/_javabridge.pyx":539
 *     def detach(self):
 *         '''Detach this thread from the VM'''
 *         self.vm[0].DetachCurrentThread(self.vm)             # <<<<<<<<<<<<<<
 * 
 *     def destroy(self):
 */
  (__pyx_v_self->vm[0])->DetachCurrentThread(__pyx_v_self->vm);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_11destroy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_10javabridge_11_javabridge_5JB_VM_11destroy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("destroy (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_5JB_VM_10destroy(((struct __pyx_obj_10javabridge_11_javabridge_JB_VM *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":541
 *         self.vm[0].DetachCurrentThread(self.vm)
 * 
 *     def destroy(self):             # <<<<<<<<<<<<<<
 *         if self.vm != NULL:
 *             self.vm[0].DestroyJavaVM(self.vm)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_5JB_VM_10destroy(struct __pyx_obj_10javabridge_11_javabridge_JB_VM *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("destroy", 0);

  /* "javabridge/_javabridge.pyx":542
 * 
 *     def destroy(self):
 *         if self.vm != NULL:             # <<<<<<<<<<<<<<
 *             self.vm[0].DestroyJavaVM(self.vm)
 *             self.vm = NULL
 */
  __pyx_t_1 = (__pyx_v_self->vm != NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":543
 *     def destroy(self):
 *         if self.vm != NULL:
 *             self.vm[0].DestroyJavaVM(self.vm)             # <<<<<<<<<<<<<<
 *             self.vm = NULL
 * 
 */
    (__pyx_v_self->vm[0])->DestroyJavaVM(__pyx_v_self->vm);

    /* "javabridge/_javabridge.pyx":544
 *         if self.vm != NULL:
 *             self.vm[0].DestroyJavaVM(self.vm)
 *             self.vm = NULL             # <<<<<<<<<<<<<<
 * 
 * cdef class JB_Env:
 */
    __pyx_v_self->vm = NULL;
    goto __pyx_L3;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_10javabridge_11_javabridge_6JB_Env_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_10javabridge_11_javabridge_6JB_Env_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env___init__(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":552
 *         defer_fn
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.defer_fn = None
 *     def __repr__(self):
 */

static int __pyx_pf_10javabridge_11_javabridge_6JB_Env___init__(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "javabridge/_javabridge.pyx":553
 * 
 *     def __init__(self):
 *         self.defer_fn = None             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->defer_fn);
  __Pyx_DECREF(__pyx_v_self->defer_fn);
  __pyx_v_self->defer_fn = Py_None;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_2__repr__(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":554
 *     def __init__(self):
 *         self.defer_fn = None
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_2__repr__(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "javabridge/_javabridge.pyx":555
 *         self.defer_fn = None
 *     def __repr__(self):
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))             # <<<<<<<<<<<<<<
 * 
 *     def set_env(self, char *address):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((size_t)__pyx_v_self->env)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_19), __pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_5set_env(PyObject *__pyx_v_self, PyObject *__pyx_arg_address); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_4set_env[] = "Set the JNIEnv to a memory address\n        \n        address - address as an integer representation of a string\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_5set_env(PyObject *__pyx_v_self, PyObject *__pyx_arg_address) {
  char *__pyx_v_address;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_env (wrapper)", 0);
  assert(__pyx_arg_address); {
    __pyx_v_address = PyBytes_AsString(__pyx_arg_address); if (unlikely((!__pyx_v_address) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 557; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_env", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_4set_env(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((char *)__pyx_v_address));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":557
 *         return "<JB_Env at 0x%x>"%(<size_t>(self.env))
 * 
 *     def set_env(self, char *address):             # <<<<<<<<<<<<<<
 *         '''Set the JNIEnv to a memory address
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_4set_env(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, char *__pyx_v_address) {
  size_t *__pyx_v_cp_addr;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_env", 0);

  /* "javabridge/_javabridge.pyx":564
 *         cdef:
 *             size_t *cp_addr
 *         cp_addr = <size_t *>&(self.env)             # <<<<<<<<<<<<<<
 *         cp_addr[0] = strtoull(address, NULL, 0)
 * 
 */
  __pyx_v_cp_addr = ((size_t *)(&__pyx_v_self->env));

  /* "javabridge/_javabridge.pyx":565
 *             size_t *cp_addr
 *         cp_addr = <size_t *>&(self.env)
 *         cp_addr[0] = strtoull(address, NULL, 0)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  (__pyx_v_cp_addr[0]) = strtoull(__pyx_v_address, NULL, 0);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static void __pyx_pw_10javabridge_11_javabridge_6JB_Env_7__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_10javabridge_11_javabridge_6JB_Env_7__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_10javabridge_11_javabridge_6JB_Env_6__dealloc__(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
}

/* "javabridge/_javabridge.pyx":567
 *         cp_addr[0] = strtoull(address, NULL, 0)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self.env = NULL
 * 
 */

static void __pyx_pf_10javabridge_11_javabridge_6JB_Env_6__dealloc__(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "javabridge/_javabridge.pyx":568
 * 
 *     def __dealloc__(self):
 *         self.env = NULL             # <<<<<<<<<<<<<<
 * 
 *     def set_defer_fn(self, defer_fn):
 */
  __pyx_v_self->env = NULL;

  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_9set_defer_fn(PyObject *__pyx_v_self, PyObject *__pyx_v_defer_fn); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_8set_defer_fn[] = "The defer function defers object deallocation, running it on the main Java thread";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_9set_defer_fn(PyObject *__pyx_v_self, PyObject *__pyx_v_defer_fn) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_defer_fn (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_8set_defer_fn(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((PyObject *)__pyx_v_defer_fn));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":570
 *         self.env = NULL
 * 
 *     def set_defer_fn(self, defer_fn):             # <<<<<<<<<<<<<<
 *         '''The defer function defers object deallocation, running it on the main Java thread'''
 *         self.defer_fn = defer_fn
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_8set_defer_fn(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_defer_fn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_defer_fn", 0);

  /* "javabridge/_javabridge.pyx":572
 *     def set_defer_fn(self, defer_fn):
 *         '''The defer function defers object deallocation, running it on the main Java thread'''
 *         self.defer_fn = defer_fn             # <<<<<<<<<<<<<<
 *         self.env = NULL
 * 
 */
  __Pyx_INCREF(__pyx_v_defer_fn);
  __Pyx_GIVEREF(__pyx_v_defer_fn);
  __Pyx_GOTREF(__pyx_v_self->defer_fn);
  __Pyx_DECREF(__pyx_v_self->defer_fn);
  __pyx_v_self->defer_fn = __pyx_v_defer_fn;

  /* "javabridge/_javabridge.pyx":573
 *         '''The defer function defers object deallocation, running it on the main Java thread'''
 *         self.defer_fn = defer_fn
 *         self.env = NULL             # <<<<<<<<<<<<<<
 * 
 *     def dealloc_jobject(self, JB_Object jbo):
 */
  __pyx_v_self->env = NULL;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_11dealloc_jobject(PyObject *__pyx_v_self, PyObject *__pyx_v_jbo); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_10dealloc_jobject[] = "Deallocate an object as it goes out of scope\n        \n        DON'T call this externally.\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_11dealloc_jobject(PyObject *__pyx_v_self, PyObject *__pyx_v_jbo) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dealloc_jobject (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_jbo), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "jbo", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 575; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_10dealloc_jobject(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_jbo));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":575
 *         self.env = NULL
 * 
 *     def dealloc_jobject(self, JB_Object jbo):             # <<<<<<<<<<<<<<
 *         '''Deallocate an object as it goes out of scope
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_10dealloc_jobject(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_jbo) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_safer_object = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  jobject __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dealloc_jobject", 0);

  /* "javabridge/_javabridge.pyx":582
 *         cdef:
 *             JB_Object safer_object
 *         if self.defer_fn is not None:             # <<<<<<<<<<<<<<
 *             #
 *             # jbo might be gc, so gen a new object that will survive
 */
  __pyx_t_1 = (__pyx_v_self->defer_fn != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":586
 *             # jbo might be gc, so gen a new object that will survive
 *             #
 *             safer_object=JB_Object()             # <<<<<<<<<<<<<<
 *             safer_object.o = jbo.o
 *             safer_object.env = self
 */
    __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Object)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 586; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_safer_object = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "javabridge/_javabridge.pyx":587
 *             #
 *             safer_object=JB_Object()
 *             safer_object.o = jbo.o             # <<<<<<<<<<<<<<
 *             safer_object.env = self
 *             self.defer_fn(safer_object)
 */
    __pyx_t_3 = __pyx_v_jbo->o;
    __pyx_v_safer_object->o = __pyx_t_3;

    /* "javabridge/_javabridge.pyx":588
 *             safer_object=JB_Object()
 *             safer_object.o = jbo.o
 *             safer_object.env = self             # <<<<<<<<<<<<<<
 *             self.defer_fn(safer_object)
 *         elif (jbo.env is not None) and self.env != NULL:
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_GOTREF(__pyx_v_safer_object->env);
    __Pyx_DECREF(__pyx_v_safer_object->env);
    __pyx_v_safer_object->env = ((PyObject *)__pyx_v_self);

    /* "javabridge/_javabridge.pyx":589
 *             safer_object.o = jbo.o
 *             safer_object.env = self
 *             self.defer_fn(safer_object)             # <<<<<<<<<<<<<<
 *         elif (jbo.env is not None) and self.env != NULL:
 *             self.env[0].DeleteGlobalRef(self.env, jbo.o)
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 589; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_safer_object));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_safer_object));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_safer_object));
    __pyx_t_4 = PyObject_Call(__pyx_v_self->defer_fn, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 589; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L3;
  }

  /* "javabridge/_javabridge.pyx":590
 *             safer_object.env = self
 *             self.defer_fn(safer_object)
 *         elif (jbo.env is not None) and self.env != NULL:             # <<<<<<<<<<<<<<
 *             self.env[0].DeleteGlobalRef(self.env, jbo.o)
 *             jbo.env = None
 */
  __pyx_t_1 = (__pyx_v_jbo->env != Py_None);
  if (__pyx_t_1) {
    __pyx_t_5 = (__pyx_v_self->env != NULL);
    __pyx_t_6 = __pyx_t_5;
  } else {
    __pyx_t_6 = __pyx_t_1;
  }
  if (__pyx_t_6) {

    /* "javabridge/_javabridge.pyx":591
 *             self.defer_fn(safer_object)
 *         elif (jbo.env is not None) and self.env != NULL:
 *             self.env[0].DeleteGlobalRef(self.env, jbo.o)             # <<<<<<<<<<<<<<
 *             jbo.env = None
 * 
 */
    (__pyx_v_self->env[0])->DeleteGlobalRef(__pyx_v_self->env, __pyx_v_jbo->o);

    /* "javabridge/_javabridge.pyx":592
 *         elif (jbo.env is not None) and self.env != NULL:
 *             self.env[0].DeleteGlobalRef(self.env, jbo.o)
 *             jbo.env = None             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_jbo->env);
    __Pyx_DECREF(__pyx_v_jbo->env);
    __pyx_v_jbo->env = Py_None;
    goto __pyx_L3;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.dealloc_jobject", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_safer_object);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_13get_version(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_12get_version[] = "Return the version number as a major / minor version tuple";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_13get_version(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_version (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_12get_version(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":595
 * 
 * 
 *     def get_version(self):             # <<<<<<<<<<<<<<
 *         '''Return the version number as a major / minor version tuple'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_12get_version(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self) {
  int __pyx_v_version;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_version", 0);

  /* "javabridge/_javabridge.pyx":599
 *         cdef:
 *             int version
 *         version = self.env[0].GetVersion(self.env)             # <<<<<<<<<<<<<<
 *         return (int(version / 65536), version % 65536)
 * 
 */
  __pyx_v_version = (__pyx_v_self->env[0])->GetVersion(__pyx_v_self->env);

  /* "javabridge/_javabridge.pyx":600
 *             int version
 *         version = self.env[0].GetVersion(self.env)
 *         return (int(version / 65536), version % 65536)             # <<<<<<<<<<<<<<
 * 
 *     def find_class(self, char *name):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__Pyx_div_long(__pyx_v_version, 65536)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 600; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 600; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 600; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromLong(__Pyx_mod_long(__pyx_v_version, 65536)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 600; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 600; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = ((PyObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_15find_class(PyObject *__pyx_v_self, PyObject *__pyx_arg_name); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_14find_class[] = "Find a Java class by name\n\n        name - the class name with \"/\" as the path separator, e.g. \"java/lang/String\"\n        Returns a wrapped class object\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_15find_class(PyObject *__pyx_v_self, PyObject *__pyx_arg_name) {
  char *__pyx_v_name;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_class (wrapper)", 0);
  assert(__pyx_arg_name); {
    __pyx_v_name = PyBytes_AsString(__pyx_arg_name); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 602; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.find_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_14find_class(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((char *)__pyx_v_name));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":602
 *         return (int(version / 65536), version % 65536)
 * 
 *     def find_class(self, char *name):             # <<<<<<<<<<<<<<
 *         '''Find a Java class by name
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_14find_class(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, char *__pyx_v_name) {
  jclass __pyx_v_c;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_class", 0);

  /* "javabridge/_javabridge.pyx":611
 *             jclass c
 *             JB_Class result
 *         c = self.env[0].FindClass(self.env, name)             # <<<<<<<<<<<<<<
 *         if c == NULL:
 *             print "Failed to get class "+name
 */
  __pyx_v_c = (__pyx_v_self->env[0])->FindClass(__pyx_v_self->env, __pyx_v_name);

  /* "javabridge/_javabridge.pyx":612
 *             JB_Class result
 *         c = self.env[0].FindClass(self.env, name)
 *         if c == NULL:             # <<<<<<<<<<<<<<
 *             print "Failed to get class "+name
 *             return
 */
  __pyx_t_1 = (__pyx_v_c == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":613
 *         c = self.env[0].FindClass(self.env, name)
 *         if c == NULL:
 *             print "Failed to get class "+name             # <<<<<<<<<<<<<<
 *             return
 *         result = JB_Class()
 */
    __pyx_t_2 = PyBytes_FromString(__pyx_v_name); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __pyx_t_3 = PyNumber_Add(((PyObject *)__pyx_kp_s_20), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    if (__Pyx_PrintOne(0, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "javabridge/_javabridge.pyx":614
 *         if c == NULL:
 *             print "Failed to get class "+name
 *             return             # <<<<<<<<<<<<<<
 *         result = JB_Class()
 *         result.c = c
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":615
 *             print "Failed to get class "+name
 *             return
 *         result = JB_Class()             # <<<<<<<<<<<<<<
 *         result.c = c
 *         return result
 */
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Class)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 615; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_result = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":616
 *             return
 *         result = JB_Class()
 *         result.c = c             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_v_result->c = __pyx_v_c;

  /* "javabridge/_javabridge.pyx":617
 *         result = JB_Class()
 *         result.c = c
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_object_class(self, JB_Object o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.find_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_17get_object_class(PyObject *__pyx_v_self, PyObject *__pyx_v_o); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_16get_object_class[] = "Return the class for an object\n        \n        o - a Java object\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_17get_object_class(PyObject *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_object_class (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 619; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_16get_object_class(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_o));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":619
 *         return result
 * 
 *     def get_object_class(self, JB_Object o):             # <<<<<<<<<<<<<<
 *         '''Return the class for an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_16get_object_class(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o) {
  jclass __pyx_v_c;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_object_class", 0);

  /* "javabridge/_javabridge.pyx":627
 *             jclass c
 *             JB_Class result
 *         c = self.env[0].GetObjectClass(self.env, o.o)             # <<<<<<<<<<<<<<
 *         result = JB_Class()
 *         result.c = c
 */
  __pyx_v_c = (__pyx_v_self->env[0])->GetObjectClass(__pyx_v_self->env, __pyx_v_o->o);

  /* "javabridge/_javabridge.pyx":628
 *             JB_Class result
 *         c = self.env[0].GetObjectClass(self.env, o.o)
 *         result = JB_Class()             # <<<<<<<<<<<<<<
 *         result.c = c
 *         return result
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Class)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 628; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":629
 *         c = self.env[0].GetObjectClass(self.env, o.o)
 *         result = JB_Class()
 *         result.c = c             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_v_result->c = __pyx_v_c;

  /* "javabridge/_javabridge.pyx":630
 *         result = JB_Class()
 *         result.c = c
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def is_instance_of(self, JB_Object o, JB_Class c):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_object_class", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_19is_instance_of(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_18is_instance_of[] = "Return True if object is instance of class\n        \n        o - a Java object\n        c - a Java class\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_19is_instance_of(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_instance_of (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__c,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("is_instance_of", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 632; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "is_instance_of") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 632; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_instance_of", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 632; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.is_instance_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 632; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 632; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_18is_instance_of(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_c);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":632
 *         return result
 * 
 *     def is_instance_of(self, JB_Object o, JB_Class c):             # <<<<<<<<<<<<<<
 *         '''Return True if object is instance of class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_18is_instance_of(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c) {
  jboolean __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_instance_of", 0);

  /* "javabridge/_javabridge.pyx":638
 *         c - a Java class
 *         '''
 *         result = self.env[0].IsInstanceOf(self.env, o.o, c.c)             # <<<<<<<<<<<<<<
 *         return result != 0
 * 
 */
  __pyx_v_result = (__pyx_v_self->env[0])->IsInstanceOf(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_c->c);

  /* "javabridge/_javabridge.pyx":639
 *         '''
 *         result = self.env[0].IsInstanceOf(self.env, o.o, c.c)
 *         return result != 0             # <<<<<<<<<<<<<<
 * 
 *     def exception_occurred(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_result != 0)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 639; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.is_instance_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_21exception_occurred(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_20exception_occurred[] = "Return a throwable if an exception occurred or None";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_21exception_occurred(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_occurred (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_20exception_occurred(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":641
 *         return result != 0
 * 
 *     def exception_occurred(self):             # <<<<<<<<<<<<<<
 *         '''Return a throwable if an exception occurred or None'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_20exception_occurred(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self) {
  jobject __pyx_v_t;
  PyObject *__pyx_v_o = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exception_occurred", 0);

  /* "javabridge/_javabridge.pyx":645
 *         cdef:
 *             jobject t
 *         t = self.env[0].ExceptionOccurred(self.env)             # <<<<<<<<<<<<<<
 *         if t == NULL:
 *             return
 */
  __pyx_v_t = (__pyx_v_self->env[0])->ExceptionOccurred(__pyx_v_self->env);

  /* "javabridge/_javabridge.pyx":646
 *             jobject t
 *         t = self.env[0].ExceptionOccurred(self.env)
 *         if t == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         o, e = make_jb_object(self, t)
 */
  __pyx_t_1 = (__pyx_v_t == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":647
 *         t = self.env[0].ExceptionOccurred(self.env)
 *         if t == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         o, e = make_jb_object(self, t)
 *         if e is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":648
 *         if t == NULL:
 *             return
 *         o, e = make_jb_object(self, t)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_2 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_t); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_o = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":649
 *             return
 *         o, e = make_jb_object(self, t)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return o
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":650
 *         o, e = make_jb_object(self, t)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return o
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":651
 *         if e is not None:
 *             raise e
 *         return o             # <<<<<<<<<<<<<<
 * 
 *     def exception_describe(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_o);
  __pyx_r = __pyx_v_o;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.exception_occurred", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_o);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_23exception_describe(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_22exception_describe[] = "Print a stack trace of the last exception to stderr";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_23exception_describe(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_describe (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_22exception_describe(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":653
 *         return o
 * 
 *     def exception_describe(self):             # <<<<<<<<<<<<<<
 *         '''Print a stack trace of the last exception to stderr'''
 *         self.env[0].ExceptionDescribe(self.env)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_22exception_describe(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_describe", 0);

  /* "javabridge/_javabridge.pyx":655
 *     def exception_describe(self):
 *         '''Print a stack trace of the last exception to stderr'''
 *         self.env[0].ExceptionDescribe(self.env)             # <<<<<<<<<<<<<<
 * 
 *     def exception_clear(self):
 */
  (__pyx_v_self->env[0])->ExceptionDescribe(__pyx_v_self->env);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_25exception_clear(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_24exception_clear[] = "Clear the current exception";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_25exception_clear(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_clear (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_24exception_clear(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":657
 *         self.env[0].ExceptionDescribe(self.env)
 * 
 *     def exception_clear(self):             # <<<<<<<<<<<<<<
 *         '''Clear the current exception'''
 *         self.env[0].ExceptionClear(self.env)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_24exception_clear(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exception_clear", 0);

  /* "javabridge/_javabridge.pyx":659
 *     def exception_clear(self):
 *         '''Clear the current exception'''
 *         self.env[0].ExceptionClear(self.env)             # <<<<<<<<<<<<<<
 * 
 *     def get_method_id(self, JB_Class c, char *name, char *sig):
 */
  (__pyx_v_self->env[0])->ExceptionClear(__pyx_v_self->env);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_27get_method_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_26get_method_id[] = "Find the method ID for a method on a class\n\n        c - a class retrieved by find_class or get_object_class\n        name - the method name\n        sig - the calling signature, e.g. \"(ILjava/lang/String;)D\" is\n              a function that returns a double and takes an integer,\n              a long and a string as arguments.\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_27get_method_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  char *__pyx_v_name;
  char *__pyx_v_sig;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_method_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__name,&__pyx_n_s__sig,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_method_id", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 661; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_method_id", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 661; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_method_id") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 661; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_name = PyBytes_AsString(values[1]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 661; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_sig = PyBytes_AsString(values[2]); if (unlikely((!__pyx_v_sig) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 661; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_method_id", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 661; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_method_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 661; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_26get_method_id(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_name, __pyx_v_sig);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":661
 *         self.env[0].ExceptionClear(self.env)
 * 
 *     def get_method_id(self, JB_Class c, char *name, char *sig):             # <<<<<<<<<<<<<<
 *         '''Find the method ID for a method on a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_26get_method_id(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, char *__pyx_v_name, char *__pyx_v_sig) {
  jmethodID __pyx_v_id;
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_method_id", 0);

  /* "javabridge/_javabridge.pyx":673
 *             jmethodID id
 *             __JB_MethodID result
 *         if c is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Class = None on call to get_method_id")
 *         id = self.env[0].GetMethodID(self.env, c.c, name, sig)
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_c) == Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":674
 *             __JB_MethodID result
 *         if c is None:
 *             raise ValueError("Class = None on call to get_method_id")             # <<<<<<<<<<<<<<
 *         id = self.env[0].GetMethodID(self.env, c.c, name, sig)
 *         if id == NULL:
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_22), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 674; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 674; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":675
 *         if c is None:
 *             raise ValueError("Class = None on call to get_method_id")
 *         id = self.env[0].GetMethodID(self.env, c.c, name, sig)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return
 */
  __pyx_v_id = (__pyx_v_self->env[0])->GetMethodID(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_name, __pyx_v_sig);

  /* "javabridge/_javabridge.pyx":676
 *             raise ValueError("Class = None on call to get_method_id")
 *         id = self.env[0].GetMethodID(self.env, c.c, name, sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  __pyx_t_1 = (__pyx_v_id == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":677
 *         id = self.env[0].GetMethodID(self.env, c.c, name, sig)
 *         if id == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result = __JB_MethodID()
 *         result.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "javabridge/_javabridge.pyx":678
 *         if id == NULL:
 *             return
 *         result = __JB_MethodID()             # <<<<<<<<<<<<<<
 *         result.id = id
 *         result.sig = sig
 */
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge___JB_MethodID)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 678; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":679
 *             return
 *         result = __JB_MethodID()
 *         result.id = id             # <<<<<<<<<<<<<<
 *         result.sig = sig
 *         result.is_static = False
 */
  __pyx_v_result->id = __pyx_v_id;

  /* "javabridge/_javabridge.pyx":680
 *         result = __JB_MethodID()
 *         result.id = id
 *         result.sig = sig             # <<<<<<<<<<<<<<
 *         result.is_static = False
 *         return result
 */
  __pyx_t_2 = PyBytes_FromString(__pyx_v_sig); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 680; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __Pyx_GOTREF(__pyx_v_result->sig);
  __Pyx_DECREF(__pyx_v_result->sig);
  __pyx_v_result->sig = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":681
 *         result.id = id
 *         result.sig = sig
 *         result.is_static = False             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_result->is_static);
  __Pyx_DECREF(__pyx_v_result->is_static);
  __pyx_v_result->is_static = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":682
 *         result.sig = sig
 *         result.is_static = False
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_static_method_id(self, JB_Class c, char *name, char *sig):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_method_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_29get_static_method_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_28get_static_method_id[] = "Find the method ID for a static method on a class\n\n        c - a class retrieved by find_class or get_object_class\n        name - the method name\n        sig - the calling signature, e.g. \"(ILjava/lang/String;)D\" is\n              a function that returns a double and takes an integer,\n              a long and a string as arguments.\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_29get_static_method_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  char *__pyx_v_name;
  char *__pyx_v_sig;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_method_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__name,&__pyx_n_s__sig,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_method_id", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_method_id", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_method_id") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_name = PyBytes_AsString(values[1]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_sig = PyBytes_AsString(values[2]); if (unlikely((!__pyx_v_sig) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_method_id", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_method_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_28get_static_method_id(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_name, __pyx_v_sig);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":684
 *         return result
 * 
 *     def get_static_method_id(self, JB_Class c, char *name, char *sig):             # <<<<<<<<<<<<<<
 *         '''Find the method ID for a static method on a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_28get_static_method_id(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, char *__pyx_v_name, char *__pyx_v_sig) {
  jmethodID __pyx_v_id;
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_method_id", 0);

  /* "javabridge/_javabridge.pyx":696
 *             jmethodID id
 *             __JB_MethodID result
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, name, sig)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return
 */
  __pyx_v_id = (__pyx_v_self->env[0])->GetStaticMethodID(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_name, __pyx_v_sig);

  /* "javabridge/_javabridge.pyx":697
 *             __JB_MethodID result
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, name, sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  __pyx_t_1 = (__pyx_v_id == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":698
 *         id = self.env[0].GetStaticMethodID(self.env, c.c, name, sig)
 *         if id == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result = __JB_MethodID()
 *         result.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":699
 *         if id == NULL:
 *             return
 *         result = __JB_MethodID()             # <<<<<<<<<<<<<<
 *         result.id = id
 *         result.sig = sig
 */
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge___JB_MethodID)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 699; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":700
 *             return
 *         result = __JB_MethodID()
 *         result.id = id             # <<<<<<<<<<<<<<
 *         result.sig = sig
 *         result.is_static = True
 */
  __pyx_v_result->id = __pyx_v_id;

  /* "javabridge/_javabridge.pyx":701
 *         result = __JB_MethodID()
 *         result.id = id
 *         result.sig = sig             # <<<<<<<<<<<<<<
 *         result.is_static = True
 *         return result
 */
  __pyx_t_2 = PyBytes_FromString(__pyx_v_sig); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 701; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __Pyx_GOTREF(__pyx_v_result->sig);
  __Pyx_DECREF(__pyx_v_result->sig);
  __pyx_v_result->sig = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":702
 *         result.id = id
 *         result.sig = sig
 *         result.is_static = True             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 702; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_result->is_static);
  __Pyx_DECREF(__pyx_v_result->is_static);
  __pyx_v_result->is_static = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":703
 *         result.sig = sig
 *         result.is_static = True
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def from_reflected_method(self, JB_Object method, char *sig, is_static):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_method_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_31from_reflected_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_30from_reflected_method[] = "Get a method_id given an instance of java.lang.reflect.Method\n        \n        method - a method, e.g. as retrieved from getDeclaredMethods\n        sig - signature of method\n        is_static - true if this is a static method\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_31from_reflected_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_method = 0;
  char *__pyx_v_sig;
  PyObject *__pyx_v_is_static = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_reflected_method (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__method,&__pyx_n_s__sig,&__pyx_n_s__is_static,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__method)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("from_reflected_method", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__is_static)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("from_reflected_method", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "from_reflected_method") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_method = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_sig = PyBytes_AsString(values[1]); if (unlikely((!__pyx_v_sig) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_is_static = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_reflected_method", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.from_reflected_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_method), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "method", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_30from_reflected_method(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_method, __pyx_v_sig, __pyx_v_is_static);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":705
 *         return result
 * 
 *     def from_reflected_method(self, JB_Object method, char *sig, is_static):             # <<<<<<<<<<<<<<
 *         '''Get a method_id given an instance of java.lang.reflect.Method
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_30from_reflected_method(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_method, char *__pyx_v_sig, PyObject *__pyx_v_is_static) {
  jmethodID __pyx_v_id;
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_reflected_method", 0);

  /* "javabridge/_javabridge.pyx":715
 *             jmethodID id
 *             __JB_MethodID result
 *         id = self.env[0].FromReflectedMethod(self.env, method.o)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return
 */
  __pyx_v_id = (__pyx_v_self->env[0])->FromReflectedMethod(__pyx_v_self->env, __pyx_v_method->o);

  /* "javabridge/_javabridge.pyx":716
 *             __JB_MethodID result
 *         id = self.env[0].FromReflectedMethod(self.env, method.o)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result = __JB_MethodID()
 */
  __pyx_t_1 = (__pyx_v_id == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":717
 *         id = self.env[0].FromReflectedMethod(self.env, method.o)
 *         if id == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result = __JB_MethodID()
 *         result.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":718
 *         if id == NULL:
 *             return
 *         result = __JB_MethodID()             # <<<<<<<<<<<<<<
 *         result.id = id
 *         result.sig = sig
 */
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge___JB_MethodID)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":719
 *             return
 *         result = __JB_MethodID()
 *         result.id = id             # <<<<<<<<<<<<<<
 *         result.sig = sig
 *         result.is_static = is_static
 */
  __pyx_v_result->id = __pyx_v_id;

  /* "javabridge/_javabridge.pyx":720
 *         result = __JB_MethodID()
 *         result.id = id
 *         result.sig = sig             # <<<<<<<<<<<<<<
 *         result.is_static = is_static
 *         return result
 */
  __pyx_t_2 = PyBytes_FromString(__pyx_v_sig); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __Pyx_GOTREF(__pyx_v_result->sig);
  __Pyx_DECREF(__pyx_v_result->sig);
  __pyx_v_result->sig = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":721
 *         result.id = id
 *         result.sig = sig
 *         result.is_static = is_static             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __Pyx_INCREF(__pyx_v_is_static);
  __Pyx_GIVEREF(__pyx_v_is_static);
  __Pyx_GOTREF(__pyx_v_result->is_static);
  __Pyx_DECREF(__pyx_v_result->is_static);
  __pyx_v_result->is_static = __pyx_v_is_static;

  /* "javabridge/_javabridge.pyx":722
 *         result.sig = sig
 *         result.is_static = is_static
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def call_method(self, JB_Object o, __JB_MethodID m, *args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.from_reflected_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_33call_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_32call_method[] = "Call a method on an object with arguments\n\n        o - object in question\n        m - the method ID\n        *args - the arguments to the method call. Arguments should\n                appear in the same order as the signature. Arguments will\n                be coerced into the type of the signature.\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_33call_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_method (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__m,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__m)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("call_method", 0, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 724; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "call_method") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 724; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_m = ((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_method", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 724; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.call_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 724; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_m), __pyx_ptype_10javabridge_11_javabridge___JB_MethodID, 1, "m", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 724; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_32call_method(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_m, __pyx_v_args);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":724
 *         return result
 * 
 *     def call_method(self, JB_Object o, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a method on an object with arguments
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_32call_method(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args) {
  jvalue *__pyx_v_values;
  jobject __pyx_v_oresult;
  JNIEnv *__pyx_v_jnienv;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_arg_end = NULL;
  PyObject *__pyx_v_arg_sig = NULL;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  JNIEnv *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("call_method", 0);

  /* "javabridge/_javabridge.pyx":736
 *             jvalue *values
 *             jobject oresult
 *             JNIEnv *jnienv = self.env             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_v_self->env;
  __pyx_v_jnienv = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":739
 * 
 * 
 *         if m is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_m) == Py_None);
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":740
 * 
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")             # <<<<<<<<<<<<<<
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use call_static_method instead")
 */
    __pyx_t_3 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_24), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 740; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 740; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":741
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:             # <<<<<<<<<<<<<<
 *             raise ValueError("call_method called with a static method. Use call_static_method instead")
 *         sig = m.sig
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_m->is_static); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 741; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":742
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use call_static_method instead")             # <<<<<<<<<<<<<<
 *         sig = m.sig
 *         if sig[0] != '(':
 */
    __pyx_t_3 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_26), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "javabridge/_javabridge.pyx":743
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use call_static_method instead")
 *         sig = m.sig             # <<<<<<<<<<<<<<
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_3 = __pyx_v_m->sig;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_sig = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":744
 *             raise ValueError("call_method called with a static method. Use call_static_method instead")
 *         sig = m.sig
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 744; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, ((PyObject *)__pyx_kp_s_27), Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 744; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 744; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":745
 *         sig = m.sig
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 */
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_28), __pyx_v_m->sig); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_4));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "javabridge/_javabridge.pyx":746
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_4 = PyObject_GetAttr(__pyx_v_sig, __pyx_n_s__find); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 746; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_k_tuple_30), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 746; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_arg_end = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":747
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_arg_end, __pyx_int_neg_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 747; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 747; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":748
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 */
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_28), __pyx_v_m->sig); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 748; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":749
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]             # <<<<<<<<<<<<<<
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 */
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_v_arg_end); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 749; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, __pyx_t_5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 749; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_arg_sig = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":750
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)             # <<<<<<<<<<<<<<
 *         if error is not None:
 *             raise error
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_fill_values(__pyx_v_arg_sig, ((PyObject *)__pyx_v_args), (&__pyx_v_values)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 750; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_error = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":751
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         sig = sig[arg_end+1:]
 */
  __pyx_t_2 = (__pyx_v_error != Py_None);
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":752
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 *             raise error             # <<<<<<<<<<<<<<
 *         sig = sig[arg_end+1:]
 *         #
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 752; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L7;
  }
  __pyx_L7:;

  /* "javabridge/_javabridge.pyx":753
 *         if error is not None:
 *             raise error
 *         sig = sig[arg_end+1:]             # <<<<<<<<<<<<<<
 *         #
 *         # Dispatch based on return code at end of sig
 */
  __pyx_t_3 = PyNumber_Add(__pyx_v_arg_end, __pyx_int_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 753; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 753; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PySequence_GetSlice(__pyx_v_sig, __pyx_t_5, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 753; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_v_sig);
  __pyx_v_sig = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":757
 *         # Dispatch based on return code at end of sig
 *         #
 *         if sig == 'Z':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallBooleanMethodA(self.env, o.o, m.id, values) != 0
 *         elif sig == 'B':
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__Z), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":758
 *         #
 *         if sig == 'Z':
 *             result = self.env[0].CallBooleanMethodA(self.env, o.o, m.id, values) != 0             # <<<<<<<<<<<<<<
 *         elif sig == 'B':
 *             result = self.env[0].CallByteMethodA(self.env, o.o, m.id, values)
 */
    __pyx_t_3 = __Pyx_PyBool_FromLong(((__pyx_v_self->env[0])->CallBooleanMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values) != 0)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_result = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":759
 *         if sig == 'Z':
 *             result = self.env[0].CallBooleanMethodA(self.env, o.o, m.id, values) != 0
 *         elif sig == 'B':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallByteMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'C':
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__B), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 759; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 759; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":760
 *             result = self.env[0].CallBooleanMethodA(self.env, o.o, m.id, values) != 0
 *         elif sig == 'B':
 *             result = self.env[0].CallByteMethodA(self.env, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'C':
 *             result = self.env[0].CallCharMethodA(self.env, o.o, m.id, values)
 */
    __pyx_t_3 = __Pyx_PyInt_to_py_jbyte((__pyx_v_self->env[0])->CallByteMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 760; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_result = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":761
 *         elif sig == 'B':
 *             result = self.env[0].CallByteMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'C':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallCharMethodA(self.env, o.o, m.id, values)
 *             result = str(unichr(result))
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__C), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":762
 *             result = self.env[0].CallByteMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'C':
 *             result = self.env[0].CallCharMethodA(self.env, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *             result = str(unichr(result))
 *         elif sig == 'S':
 */
    __pyx_t_3 = __Pyx_PyInt_to_py_jchar((__pyx_v_self->env[0])->CallCharMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 762; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_result = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "javabridge/_javabridge.pyx":763
 *         elif sig == 'C':
 *             result = self.env[0].CallCharMethodA(self.env, o.o, m.id, values)
 *             result = str(unichr(result))             # <<<<<<<<<<<<<<
 *         elif sig == 'S':
 *             result = self.env[0].CallShortMethodA(self.env, o.o, m.id, values)
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 763; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_result);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    __pyx_t_4 = PyObject_Call(__pyx_builtin_unichr, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 763; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 763; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyString_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 763; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_v_result);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":764
 *             result = self.env[0].CallCharMethodA(self.env, o.o, m.id, values)
 *             result = str(unichr(result))
 *         elif sig == 'S':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallShortMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'I':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__S), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":765
 *             result = str(unichr(result))
 *         elif sig == 'S':
 *             result = self.env[0].CallShortMethodA(self.env, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'I':
 *             result = self.env[0].CallIntMethodA(self.env, o.o, m.id, values)
 */
    __pyx_t_4 = __Pyx_PyInt_to_py_jshort((__pyx_v_self->env[0])->CallShortMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":766
 *         elif sig == 'S':
 *             result = self.env[0].CallShortMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'I':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallIntMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'J':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__I), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 766; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 766; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":767
 *             result = self.env[0].CallShortMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'I':
 *             result = self.env[0].CallIntMethodA(self.env, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'J':
 *             result = self.env[0].CallLongMethodA(self.env, o.o, m.id, values)
 */
    __pyx_t_4 = __Pyx_PyInt_to_py_jint((__pyx_v_self->env[0])->CallIntMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 767; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":768
 *         elif sig == 'I':
 *             result = self.env[0].CallIntMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'J':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallLongMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'F':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__J), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 768; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 768; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":769
 *             result = self.env[0].CallIntMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'J':
 *             result = self.env[0].CallLongMethodA(self.env, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'F':
 *             result = self.env[0].CallFloatMethodA(self.env, o.o, m.id, values)
 */
    __pyx_t_4 = __Pyx_PyInt_to_py_jlong((__pyx_v_self->env[0])->CallLongMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 769; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":770
 *         elif sig == 'J':
 *             result = self.env[0].CallLongMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'F':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallFloatMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'D':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__F), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 770; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 770; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":771
 *             result = self.env[0].CallLongMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'F':
 *             result = self.env[0].CallFloatMethodA(self.env, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'D':
 *             result = self.env[0].CallDoubleMethodA(self.env, o.o, m.id, values)
 */
    __pyx_t_4 = PyFloat_FromDouble((__pyx_v_self->env[0])->CallFloatMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 771; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":772
 *         elif sig == 'F':
 *             result = self.env[0].CallFloatMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'D':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallDoubleMethodA(self.env, o.o, m.id, values)
 *         elif sig[0] == 'L' or sig[0] == '[':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__D), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "javabridge/_javabridge.pyx":773
 *             result = self.env[0].CallFloatMethodA(self.env, o.o, m.id, values)
 *         elif sig == 'D':
 *             result = self.env[0].CallDoubleMethodA(self.env, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             oresult = jnienv[0].CallObjectMethodA(jnienv, o.o, m.id, values)
 */
    __pyx_t_4 = PyFloat_FromDouble((__pyx_v_self->env[0])->CallDoubleMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 773; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":774
 *         elif sig == 'D':
 *             result = self.env[0].CallDoubleMethodA(self.env, o.o, m.id, values)
 *         elif sig[0] == 'L' or sig[0] == '[':             # <<<<<<<<<<<<<<
 *             oresult = jnienv[0].CallObjectMethodA(jnienv, o.o, m.id, values)
 *             if oresult == NULL:
 */
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_4) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, ((PyObject *)__pyx_n_s__L), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!__pyx_t_2) {
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, ((PyObject *)__pyx_kp_s_7), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_7 = __pyx_t_6;
  } else {
    __pyx_t_7 = __pyx_t_2;
  }
  if (__pyx_t_7) {

    /* "javabridge/_javabridge.pyx":775
 *             result = self.env[0].CallDoubleMethodA(self.env, o.o, m.id, values)
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             oresult = jnienv[0].CallObjectMethodA(jnienv, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *             if oresult == NULL:
 *                 result = None
 */
    __pyx_v_oresult = (__pyx_v_jnienv[0])->CallObjectMethodA(__pyx_v_jnienv, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values);

    /* "javabridge/_javabridge.pyx":776
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             oresult = jnienv[0].CallObjectMethodA(jnienv, o.o, m.id, values)
 *             if oresult == NULL:             # <<<<<<<<<<<<<<
 *                 result = None
 *             else:
 */
    __pyx_t_7 = (__pyx_v_oresult == NULL);
    if (__pyx_t_7) {

      /* "javabridge/_javabridge.pyx":777
 *             oresult = jnienv[0].CallObjectMethodA(jnienv, o.o, m.id, values)
 *             if oresult == NULL:
 *                 result = None             # <<<<<<<<<<<<<<
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 */
      __Pyx_INCREF(Py_None);
      __pyx_v_result = Py_None;
      goto __pyx_L9;
    }
    /*else*/ {

      /* "javabridge/_javabridge.pyx":779
 *                 result = None
 *             else:
 *                 result, e = make_jb_object(self, oresult)             # <<<<<<<<<<<<<<
 *                 if e is not None:
 *                     raise e
 */
      __pyx_t_4 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_oresult); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
        PyObject* sequence = __pyx_t_4;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_8);
        #else
        __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        #endif
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
        index = 0; __pyx_t_3 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_3)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        index = 1; __pyx_t_8 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L11_unpacking_done;
        __pyx_L10_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L11_unpacking_done:;
      }
      __pyx_v_result = __pyx_t_3;
      __pyx_t_3 = 0;
      __pyx_v_e = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "javabridge/_javabridge.pyx":780
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *         elif sig == 'V':
 */
      __pyx_t_7 = (__pyx_v_e != Py_None);
      if (__pyx_t_7) {

        /* "javabridge/_javabridge.pyx":781
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:
 *                     raise e             # <<<<<<<<<<<<<<
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, o.o, m.id, values)
 */
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 781; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L12;
      }
      __pyx_L12:;
    }
    __pyx_L9:;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":782
 *                 if e is not None:
 *                     raise e
 *         elif sig == 'V':             # <<<<<<<<<<<<<<
 *             self.env[0].CallVoidMethodA(self.env, o.o, m.id, values)
 *             result = None
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__V), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 782; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 782; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_7) {

    /* "javabridge/_javabridge.pyx":783
 *                     raise e
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, o.o, m.id, values)             # <<<<<<<<<<<<<<
 *             result = None
 *         else:
 */
    (__pyx_v_self->env[0])->CallVoidMethodA(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_m->id, __pyx_v_values);

    /* "javabridge/_javabridge.pyx":784
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, o.o, m.id, values)
 *             result = None             # <<<<<<<<<<<<<<
 *         else:
 *             free(<void *>values)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_result = Py_None;
    goto __pyx_L8;
  }
  /*else*/ {

    /* "javabridge/_javabridge.pyx":786
 *             result = None
 *         else:
 *             free(<void *>values)             # <<<<<<<<<<<<<<
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)
 */
    free(((void *)__pyx_v_values));

    /* "javabridge/_javabridge.pyx":787
 *         else:
 *             free(<void *>values)
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)             # <<<<<<<<<<<<<<
 *         free(<void *>values)
 *         return result
 */
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_31), __pyx_v_m->sig); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_t_4));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_8), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L8:;

  /* "javabridge/_javabridge.pyx":788
 *             free(<void *>values)
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  free(((void *)__pyx_v_values));

  /* "javabridge/_javabridge.pyx":789
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def call_static_method(self, JB_Class c, __JB_MethodID m, *args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.call_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_arg_end);
  __Pyx_XDECREF(__pyx_v_arg_sig);
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_35call_static_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_34call_static_method[] = "Call a static method on a class with arguments\n\n        c - class holding the method\n        m - the method ID\n        *args - the arguments to the method call. Arguments should\n                appear in the same order as the signature. Arguments will\n                be coerced into the type of the signature.\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_35call_static_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_static_method (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__m,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__m)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("call_static_method", 0, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 791; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "call_static_method") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 791; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_m = ((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_static_method", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 791; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.call_static_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 791; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_m), __pyx_ptype_10javabridge_11_javabridge___JB_MethodID, 1, "m", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 791; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_34call_static_method(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_m, __pyx_v_args);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":791
 *         return result
 * 
 *     def call_static_method(self, JB_Class c, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a static method on a class with arguments
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_34call_static_method(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args) {
  jvalue *__pyx_v_values;
  jobject __pyx_v_oresult;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_arg_end = NULL;
  PyObject *__pyx_v_arg_sig = NULL;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("call_static_method", 0);

  /* "javabridge/_javabridge.pyx":804
 *             jobject oresult
 * 
 *         if m is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_m) == Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":805
 * 
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")             # <<<<<<<<<<<<<<
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_32), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":806
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:             # <<<<<<<<<<<<<<
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 *         sig = m.sig
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_m->is_static); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = (!__pyx_t_1);
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":807
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")             # <<<<<<<<<<<<<<
 *         sig = m.sig
 *         if sig[0] != '(':
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_34), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "javabridge/_javabridge.pyx":808
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 *         sig = m.sig             # <<<<<<<<<<<<<<
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_2 = __pyx_v_m->sig;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_sig = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":809
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 *         sig = m.sig
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, ((PyObject *)__pyx_kp_s_27), Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 809; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":810
 *         sig = m.sig
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 */
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_28), __pyx_v_m->sig); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_4));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "javabridge/_javabridge.pyx":811
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_4 = PyObject_GetAttr(__pyx_v_sig, __pyx_n_s__find); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_k_tuple_35), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_arg_end = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":812
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_arg_end, __pyx_int_neg_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":813
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 */
    __pyx_t_2 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_28), __pyx_v_m->sig); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_2));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":814
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]             # <<<<<<<<<<<<<<
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 */
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_v_arg_end); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, __pyx_t_5); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_arg_sig = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":815
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)             # <<<<<<<<<<<<<<
 *         if error is not None:
 *             raise error
 */
  __pyx_t_2 = __pyx_f_10javabridge_11_javabridge_fill_values(__pyx_v_arg_sig, ((PyObject *)__pyx_v_args), (&__pyx_v_values)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_error = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":816
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         sig = sig[arg_end+1:]
 */
  __pyx_t_3 = (__pyx_v_error != Py_None);
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":817
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 *             raise error             # <<<<<<<<<<<<<<
 *         sig = sig[arg_end+1:]
 *         #
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L7;
  }
  __pyx_L7:;

  /* "javabridge/_javabridge.pyx":818
 *         if error is not None:
 *             raise error
 *         sig = sig[arg_end+1:]             # <<<<<<<<<<<<<<
 *         #
 *         # Dispatch based on return code at end of sig
 */
  __pyx_t_2 = PyNumber_Add(__pyx_v_arg_end, __pyx_int_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 818; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_2); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 818; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PySequence_GetSlice(__pyx_v_sig, __pyx_t_5, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 818; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_v_sig);
  __pyx_v_sig = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":822
 *         # Dispatch based on return code at end of sig
 *         #
 *         if sig == 'Z':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallStaticBooleanMethodA(self.env, c.c, m.id, values) != 0
 *         elif sig == 'B':
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__Z), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 822; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 822; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":823
 *         #
 *         if sig == 'Z':
 *             result = self.env[0].CallStaticBooleanMethodA(self.env, c.c, m.id, values) != 0             # <<<<<<<<<<<<<<
 *         elif sig == 'B':
 *             result = self.env[0].CallStaticByteMethodA(self.env, c.c, m.id, values)
 */
    __pyx_t_2 = __Pyx_PyBool_FromLong(((__pyx_v_self->env[0])->CallStaticBooleanMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values) != 0)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":824
 *         if sig == 'Z':
 *             result = self.env[0].CallStaticBooleanMethodA(self.env, c.c, m.id, values) != 0
 *         elif sig == 'B':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallStaticByteMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'C':
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__B), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 824; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 824; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":825
 *             result = self.env[0].CallStaticBooleanMethodA(self.env, c.c, m.id, values) != 0
 *         elif sig == 'B':
 *             result = self.env[0].CallStaticByteMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'C':
 *             result = self.env[0].CallStaticCharMethodA(self.env, c.c, m.id, values)
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_jbyte((__pyx_v_self->env[0])->CallStaticByteMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":826
 *         elif sig == 'B':
 *             result = self.env[0].CallStaticByteMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'C':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallStaticCharMethodA(self.env, c.c, m.id, values)
 *             result = str(unichr(result))
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__C), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":827
 *             result = self.env[0].CallStaticByteMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'C':
 *             result = self.env[0].CallStaticCharMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *             result = str(unichr(result))
 *         elif sig == 'S':
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_jchar((__pyx_v_self->env[0])->CallStaticCharMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "javabridge/_javabridge.pyx":828
 *         elif sig == 'C':
 *             result = self.env[0].CallStaticCharMethodA(self.env, c.c, m.id, values)
 *             result = str(unichr(result))             # <<<<<<<<<<<<<<
 *         elif sig == 'S':
 *             result = self.env[0].CallShortMethodA(self.env, c.c, m.id, values)
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_result);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    __pyx_t_4 = PyObject_Call(__pyx_builtin_unichr, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyString_Type))), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_v_result);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":829
 *             result = self.env[0].CallStaticCharMethodA(self.env, c.c, m.id, values)
 *             result = str(unichr(result))
 *         elif sig == 'S':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallShortMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'I':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__S), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":830
 *             result = str(unichr(result))
 *         elif sig == 'S':
 *             result = self.env[0].CallShortMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'I':
 *             result = self.env[0].CallIntMethodA(self.env, c.c, m.id, values)
 */
    __pyx_t_4 = __Pyx_PyInt_to_py_jshort((__pyx_v_self->env[0])->CallShortMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":831
 *         elif sig == 'S':
 *             result = self.env[0].CallShortMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'I':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallIntMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'J':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__I), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":832
 *             result = self.env[0].CallShortMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'I':
 *             result = self.env[0].CallIntMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'J':
 *             result = self.env[0].CallLongMethodA(self.env, c.c, m.id, values)
 */
    __pyx_t_4 = __Pyx_PyInt_to_py_jint((__pyx_v_self->env[0])->CallIntMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":833
 *         elif sig == 'I':
 *             result = self.env[0].CallIntMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'J':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallLongMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'F':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__J), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":834
 *             result = self.env[0].CallIntMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'J':
 *             result = self.env[0].CallLongMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'F':
 *             result = self.env[0].CallFloatMethodA(self.env, c.c, m.id, values)
 */
    __pyx_t_4 = __Pyx_PyInt_to_py_jlong((__pyx_v_self->env[0])->CallLongMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":835
 *         elif sig == 'J':
 *             result = self.env[0].CallLongMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'F':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallFloatMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'D':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__F), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":836
 *             result = self.env[0].CallLongMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'F':
 *             result = self.env[0].CallFloatMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig == 'D':
 *             result = self.env[0].CallDoubleMethodA(self.env, c.c, m.id, values)
 */
    __pyx_t_4 = PyFloat_FromDouble((__pyx_v_self->env[0])->CallFloatMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":837
 *         elif sig == 'F':
 *             result = self.env[0].CallFloatMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'D':             # <<<<<<<<<<<<<<
 *             result = self.env[0].CallDoubleMethodA(self.env, c.c, m.id, values)
 *         elif sig[0] == 'L' or sig[0] == '[':
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__D), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":838
 *             result = self.env[0].CallFloatMethodA(self.env, c.c, m.id, values)
 *         elif sig == 'D':
 *             result = self.env[0].CallDoubleMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             oresult = self.env[0].CallObjectMethodA(self.env, c.c, m.id, values)
 */
    __pyx_t_4 = PyFloat_FromDouble((__pyx_v_self->env[0])->CallDoubleMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":839
 *         elif sig == 'D':
 *             result = self.env[0].CallDoubleMethodA(self.env, c.c, m.id, values)
 *         elif sig[0] == 'L' or sig[0] == '[':             # <<<<<<<<<<<<<<
 *             oresult = self.env[0].CallObjectMethodA(self.env, c.c, m.id, values)
 *             if oresult == NULL:
 */
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_4) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_4, ((PyObject *)__pyx_n_s__L), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_3) {
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, ((PyObject *)__pyx_kp_s_7), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __pyx_t_1;
  } else {
    __pyx_t_6 = __pyx_t_3;
  }
  if (__pyx_t_6) {

    /* "javabridge/_javabridge.pyx":840
 *             result = self.env[0].CallDoubleMethodA(self.env, c.c, m.id, values)
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             oresult = self.env[0].CallObjectMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *             if oresult == NULL:
 *                 result = None
 */
    __pyx_v_oresult = (__pyx_v_self->env[0])->CallObjectMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values);

    /* "javabridge/_javabridge.pyx":841
 *         elif sig[0] == 'L' or sig[0] == '[':
 *             oresult = self.env[0].CallObjectMethodA(self.env, c.c, m.id, values)
 *             if oresult == NULL:             # <<<<<<<<<<<<<<
 *                 result = None
 *             else:
 */
    __pyx_t_6 = (__pyx_v_oresult == NULL);
    if (__pyx_t_6) {

      /* "javabridge/_javabridge.pyx":842
 *             oresult = self.env[0].CallObjectMethodA(self.env, c.c, m.id, values)
 *             if oresult == NULL:
 *                 result = None             # <<<<<<<<<<<<<<
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 */
      __Pyx_INCREF(Py_None);
      __pyx_v_result = Py_None;
      goto __pyx_L9;
    }
    /*else*/ {

      /* "javabridge/_javabridge.pyx":844
 *                 result = None
 *             else:
 *                 result, e = make_jb_object(self, oresult)             # <<<<<<<<<<<<<<
 *                 if e is not None:
 *                     raise e
 */
      __pyx_t_4 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_oresult); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
        PyObject* sequence = __pyx_t_4;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        #else
        __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
        index = 0; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L11_unpacking_done;
        __pyx_L10_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L11_unpacking_done:;
      }
      __pyx_v_result = __pyx_t_2;
      __pyx_t_2 = 0;
      __pyx_v_e = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "javabridge/_javabridge.pyx":845
 *             else:
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *         elif sig == 'V':
 */
      __pyx_t_6 = (__pyx_v_e != Py_None);
      if (__pyx_t_6) {

        /* "javabridge/_javabridge.pyx":846
 *                 result, e = make_jb_object(self, oresult)
 *                 if e is not None:
 *                     raise e             # <<<<<<<<<<<<<<
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)
 */
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L12;
      }
      __pyx_L12:;
    }
    __pyx_L9:;
    goto __pyx_L8;
  }

  /* "javabridge/_javabridge.pyx":847
 *                 if e is not None:
 *                     raise e
 *         elif sig == 'V':             # <<<<<<<<<<<<<<
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)
 *             result = None
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, ((PyObject *)__pyx_n_s__V), Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 847; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 847; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_6) {

    /* "javabridge/_javabridge.pyx":848
 *                     raise e
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *             result = None
 *         else:
 */
    (__pyx_v_self->env[0])->CallVoidMethodA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values);

    /* "javabridge/_javabridge.pyx":849
 *         elif sig == 'V':
 *             self.env[0].CallVoidMethodA(self.env, c.c, m.id, values)
 *             result = None             # <<<<<<<<<<<<<<
 *         else:
 *             free(<void *>values)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_result = Py_None;
    goto __pyx_L8;
  }
  /*else*/ {

    /* "javabridge/_javabridge.pyx":851
 *             result = None
 *         else:
 *             free(<void *>values)             # <<<<<<<<<<<<<<
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)
 */
    free(((void *)__pyx_v_values));

    /* "javabridge/_javabridge.pyx":852
 *         else:
 *             free(<void *>values)
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)             # <<<<<<<<<<<<<<
 *         free(<void *>values)
 *         return result
 */
    __pyx_t_4 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_31), __pyx_v_m->sig); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_t_4));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L8:;

  /* "javabridge/_javabridge.pyx":853
 *             free(<void *>values)
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  free(((void *)__pyx_v_values));

  /* "javabridge/_javabridge.pyx":854
 *             raise ValueError("Unhandled return type. Signature = %s"%m.sig)
 *         free(<void *>values)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_field_id(self, JB_Class c, char *name, char *sig):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.call_static_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_arg_end);
  __Pyx_XDECREF(__pyx_v_arg_sig);
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_37get_field_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_36get_field_id[] = "Get a field ID for a class\n        \n        c - class (from find_class or similar)\n        name - name of field\n        sig - signature of field (e.g. Ljava/lang/String;)\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_37get_field_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  char *__pyx_v_name;
  char *__pyx_v_sig;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_field_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__name,&__pyx_n_s__sig,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_field_id", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_field_id", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_field_id") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_name = PyBytes_AsString(values[1]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_sig = PyBytes_AsString(values[2]); if (unlikely((!__pyx_v_sig) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_field_id", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_field_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 856; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_36get_field_id(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_name, __pyx_v_sig);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":856
 *         return result
 * 
 *     def get_field_id(self, JB_Class c, char *name, char *sig):             # <<<<<<<<<<<<<<
 *         '''Get a field ID for a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_36get_field_id(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, char *__pyx_v_name, char *__pyx_v_sig) {
  jfieldID __pyx_v_id;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_jbid = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_field_id", 0);

  /* "javabridge/_javabridge.pyx":867
 *             __JB_FieldID jbid
 * 
 *         id = self.env[0].GetFieldID(self.env, c.c, name, sig)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return None
 */
  __pyx_v_id = (__pyx_v_self->env[0])->GetFieldID(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_name, __pyx_v_sig);

  /* "javabridge/_javabridge.pyx":868
 * 
 *         id = self.env[0].GetFieldID(self.env, c.c, name, sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         jbid = __JB_FieldID()
 */
  __pyx_t_1 = (__pyx_v_id == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":869
 *         id = self.env[0].GetFieldID(self.env, c.c, name, sig)
 *         if id == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         jbid = __JB_FieldID()
 *         jbid.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":870
 *         if id == NULL:
 *             return None
 *         jbid = __JB_FieldID()             # <<<<<<<<<<<<<<
 *         jbid.id = id
 *         jbid.sig = sig
 */
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge___JB_FieldID)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 870; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_jbid = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":871
 *             return None
 *         jbid = __JB_FieldID()
 *         jbid.id = id             # <<<<<<<<<<<<<<
 *         jbid.sig = sig
 *         jbid.is_static = False
 */
  __pyx_v_jbid->id = __pyx_v_id;

  /* "javabridge/_javabridge.pyx":872
 *         jbid = __JB_FieldID()
 *         jbid.id = id
 *         jbid.sig = sig             # <<<<<<<<<<<<<<
 *         jbid.is_static = False
 *         return jbid
 */
  __pyx_t_2 = PyBytes_FromString(__pyx_v_sig); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 872; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __Pyx_GOTREF(__pyx_v_jbid->sig);
  __Pyx_DECREF(__pyx_v_jbid->sig);
  __pyx_v_jbid->sig = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":873
 *         jbid.id = id
 *         jbid.sig = sig
 *         jbid.is_static = False             # <<<<<<<<<<<<<<
 *         return jbid
 * 
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_jbid->is_static);
  __Pyx_DECREF(__pyx_v_jbid->is_static);
  __pyx_v_jbid->is_static = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":874
 *         jbid.sig = sig
 *         jbid.is_static = False
 *         return jbid             # <<<<<<<<<<<<<<
 * 
 *     def get_object_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jbid));
  __pyx_r = ((PyObject *)__pyx_v_jbid);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_field_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbid);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_39get_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_38get_object_field[] = "Return an object field";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_39get_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_object_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_object_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 876; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_object_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 876; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_object_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 876; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 876; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 876; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_38get_object_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":876
 *         return jbid
 * 
 *     def get_object_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an object field'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_38get_object_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  jobject __pyx_v_subo;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_object_field", 0);

  /* "javabridge/_javabridge.pyx":880
 *         cdef:
 *             jobject subo
 *         subo = self.env[0].GetObjectField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 *         if subo == NULL:
 *             return
 */
  __pyx_v_subo = (__pyx_v_self->env[0])->GetObjectField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id);

  /* "javabridge/_javabridge.pyx":881
 *             jobject subo
 *         subo = self.env[0].GetObjectField(self.env, o.o, field.id)
 *         if subo == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, subo)
 */
  __pyx_t_1 = (__pyx_v_subo == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":882
 *         subo = self.env[0].GetObjectField(self.env, o.o, field.id)
 *         if subo == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, subo)
 *         if e is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":883
 *         if subo == NULL:
 *             return
 *         result, e = make_jb_object(self, subo)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_2 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_subo); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 883; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 883; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 883; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 883; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 883; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 883; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 883; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":884
 *             return
 *         result, e = make_jb_object(self, subo)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":885
 *         result, e = make_jb_object(self, subo)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":886
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_boolean_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_41get_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_40get_boolean_field[] = "Return a boolean field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_41get_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_boolean_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_boolean_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_boolean_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_boolean_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_40get_boolean_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":888
 *         return result
 * 
 *     def get_boolean_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a boolean field's value'''
 *         return self.env[0].GetBooleanField(self.env, o.o, field.id) != 0
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_40get_boolean_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_boolean_field", 0);

  /* "javabridge/_javabridge.pyx":890
 *     def get_boolean_field(self, JB_Object o, __JB_FieldID field):
 *         '''Return a boolean field's value'''
 *         return self.env[0].GetBooleanField(self.env, o.o, field.id) != 0             # <<<<<<<<<<<<<<
 * 
 *     def get_byte_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(((__pyx_v_self->env[0])->GetBooleanField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id) != 0)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 890; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_43get_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_42get_byte_field[] = "Return a byte field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_43get_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_byte_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_byte_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_byte_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_byte_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 892; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_42get_byte_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":892
 *         return self.env[0].GetBooleanField(self.env, o.o, field.id) != 0
 * 
 *     def get_byte_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a byte field's value'''
 *         return self.env[0].GetByteField(self.env, o.o, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_42get_byte_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_byte_field", 0);

  /* "javabridge/_javabridge.pyx":894
 *     def get_byte_field(self, JB_Object o, __JB_FieldID field):
 *         '''Return a byte field's value'''
 *         return self.env[0].GetByteField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_short_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jbyte((__pyx_v_self->env[0])->GetByteField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 894; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_45get_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_44get_short_field[] = "Return a short field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_45get_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_short_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_short_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_short_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_short_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_44get_short_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":896
 *         return self.env[0].GetByteField(self.env, o.o, field.id)
 * 
 *     def get_short_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a short field's value'''
 *         return self.env[0].GetShortField(self.env, o.o, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_44get_short_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_short_field", 0);

  /* "javabridge/_javabridge.pyx":898
 *     def get_short_field(self, JB_Object o, __JB_FieldID field):
 *         '''Return a short field's value'''
 *         return self.env[0].GetShortField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_int_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jshort((__pyx_v_self->env[0])->GetShortField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_47get_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_46get_int_field[] = "Return an int field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_47get_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_int_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_int_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_int_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_int_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_46get_int_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":900
 *         return self.env[0].GetShortField(self.env, o.o, field.id)
 * 
 *     def get_int_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an int field's value'''
 *         return self.env[0].GetIntField(self.env, o.o, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_46get_int_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_int_field", 0);

  /* "javabridge/_javabridge.pyx":902
 *     def get_int_field(self, JB_Object o, __JB_FieldID field):
 *         '''Return an int field's value'''
 *         return self.env[0].GetIntField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_long_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jint((__pyx_v_self->env[0])->GetIntField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_49get_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_48get_long_field[] = "Return a long field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_49get_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_long_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_long_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_long_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_long_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_48get_long_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":904
 *         return self.env[0].GetIntField(self.env, o.o, field.id)
 * 
 *     def get_long_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a long field's value'''
 *         return self.env[0].GetLongField(self.env, o.o, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_48get_long_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_long_field", 0);

  /* "javabridge/_javabridge.pyx":906
 *     def get_long_field(self, JB_Object o, __JB_FieldID field):
 *         '''Return a long field's value'''
 *         return self.env[0].GetLongField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_float_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jlong((__pyx_v_self->env[0])->GetLongField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 906; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_51get_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_50get_float_field[] = "Return a float field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_51get_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_float_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_float_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 908; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_float_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 908; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_float_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 908; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 908; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 908; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_50get_float_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":908
 *         return self.env[0].GetLongField(self.env, o.o, field.id)
 * 
 *     def get_float_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a float field's value'''
 *         return self.env[0].GetFloatField(self.env, o.o, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_50get_float_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_float_field", 0);

  /* "javabridge/_javabridge.pyx":910
 *     def get_float_field(self, JB_Object o, __JB_FieldID field):
 *         '''Return a float field's value'''
 *         return self.env[0].GetFloatField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_double_field(self, JB_Object o, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->env[0])->GetFloatField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 910; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_53get_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_52get_double_field[] = "Return a double field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_53get_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_double_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_double_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 912; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_double_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 912; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_double_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 912; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 912; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 912; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_52get_double_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":912
 *         return self.env[0].GetFloatField(self.env, o.o, field.id)
 * 
 *     def get_double_field(self, JB_Object o, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a double field's value'''
 *         return self.env[0].GetDoubleField(self.env, o.o, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_52get_double_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_double_field", 0);

  /* "javabridge/_javabridge.pyx":914
 *     def get_double_field(self, JB_Object o, __JB_FieldID field):
 *         '''Return a double field's value'''
 *         return self.env[0].GetDoubleField(self.env, o.o, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def set_object_field(self, JB_Object o, __JB_FieldID field, JB_Object value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->env[0])->GetDoubleField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 914; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_55set_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_54set_object_field[] = "Set a static object field in an object\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - the object that will become the field's new value\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_55set_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_object_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_object_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_object_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_object_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_object_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_value), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "value", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_54set_object_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":916
 *         return self.env[0].GetDoubleField(self.env, o.o, field.id)
 * 
 *     def set_object_field(self, JB_Object o, __JB_FieldID field, JB_Object value):             # <<<<<<<<<<<<<<
 *         '''Set a static object field in an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_54set_object_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_object_field", 0);

  /* "javabridge/_javabridge.pyx":923
 *         value - the object that will become the field's new value
 *         '''
 *         self.env[0].SetObjectField(self.env, o.o, field.id, value.o)             # <<<<<<<<<<<<<<
 * 
 *     def set_boolean_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetObjectField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_value->o);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_57set_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_56set_boolean_field[] = "Set a boolean field in an object\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - a value whose truth value determines the field's value\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_57set_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_boolean_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_boolean_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 925; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_boolean_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 925; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_boolean_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 925; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_boolean_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 925; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 925; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 925; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_56set_boolean_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":925
 *         self.env[0].SetObjectField(self.env, o.o, field.id, value.o)
 * 
 *     def set_boolean_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a boolean field in an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_56set_boolean_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jboolean __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_boolean_field", 0);

  /* "javabridge/_javabridge.pyx":933
 *         '''
 *         cdef:
 *             jboolean jvalue = 1 if value else 0             # <<<<<<<<<<<<<<
 *         self.env[0].SetBooleanField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_v_jvalue = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":934
 *         cdef:
 *             jboolean jvalue = 1 if value else 0
 *         self.env[0].SetBooleanField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_byte_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetBooleanField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_59set_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_58set_byte_field[] = "Set a byte field in an object\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - a value suitable for int() conversion\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_59set_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_byte_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_byte_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_byte_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_byte_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_byte_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_58set_byte_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":936
 *         self.env[0].SetBooleanField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_byte_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a byte field in an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_58set_byte_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jbyte __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jbyte __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_byte_field", 0);

  /* "javabridge/_javabridge.pyx":944
 *         '''
 *         cdef:
 *             jbyte jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetByteField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_from_py_jbyte(__pyx_t_2); if (unlikely((__pyx_t_3 == (jbyte)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_jvalue = __pyx_t_3;

  /* "javabridge/_javabridge.pyx":945
 *         cdef:
 *             jbyte jvalue = int(value)
 *         self.env[0].SetByteField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_char_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetByteField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_61set_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_60set_char_field[] = "Set a char field in an object\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - should be convertible to unicode and at least 1 char long\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_61set_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_char_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_char_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_char_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_char_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_char_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_60set_char_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":947
 *         self.env[0].SetByteField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_char_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a char field in an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_60set_char_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jchar __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_char_field", 0);

  /* "javabridge/_javabridge.pyx":955
 *         '''
 *         cdef:
 *             jchar jvalue = PyUnicode_AS_UNICODE(unicode(value))[0]             # <<<<<<<<<<<<<<
 *         self.env[0].SetCharField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 955; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 955; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_v_jvalue = (PyUnicode_AS_UNICODE(__pyx_t_2)[0]);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":956
 *         cdef:
 *             jchar jvalue = PyUnicode_AS_UNICODE(unicode(value))[0]
 *         self.env[0].SetCharField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_short_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetCharField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_63set_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_62set_short_field[] = "Set a static short field in a class\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_63set_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_short_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_short_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_short_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_short_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_short_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_62set_short_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":958
 *         self.env[0].SetCharField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_short_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static short field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_62set_short_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jshort __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jshort __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_short_field", 0);

  /* "javabridge/_javabridge.pyx":966
 *         '''
 *         cdef:
 *             jshort jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetShortField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_from_py_jshort(__pyx_t_2); if (unlikely((__pyx_t_3 == (jshort)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_jvalue = __pyx_t_3;

  /* "javabridge/_javabridge.pyx":967
 *         cdef:
 *             jshort jvalue = int(value)
 *         self.env[0].SetShortField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_int_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetShortField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_65set_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_64set_int_field[] = "Set an int field in an object\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_65set_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_int_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_int_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_int_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_int_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_int_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_64set_int_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":969
 *         self.env[0].SetShortField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_int_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set an int field in an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_64set_int_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jint __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jint __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_int_field", 0);

  /* "javabridge/_javabridge.pyx":977
 *         '''
 *         cdef:
 *             jint jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetIntField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_from_py_jint(__pyx_t_2); if (unlikely((__pyx_t_3 == (jint)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_jvalue = __pyx_t_3;

  /* "javabridge/_javabridge.pyx":978
 *         cdef:
 *             jint jvalue = int(value)
 *         self.env[0].SetIntField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_long_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetIntField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_67set_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_66set_long_field[] = "Set a long field in an object\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_67set_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_long_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_long_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_long_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_long_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_long_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_66set_long_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":980
 *         self.env[0].SetIntField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_long_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a long field in an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_66set_long_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jlong __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jlong __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_long_field", 0);

  /* "javabridge/_javabridge.pyx":988
 *         '''
 *         cdef:
 *             jlong jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetLongField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 988; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 988; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_from_py_jlong(__pyx_t_2); if (unlikely((__pyx_t_3 == (jlong)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 988; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_jvalue = __pyx_t_3;

  /* "javabridge/_javabridge.pyx":989
 *         cdef:
 *             jlong jvalue = int(value)
 *         self.env[0].SetLongField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_float_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetLongField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_69set_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_68set_float_field[] = "Set a float field in an object\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using float()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_69set_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_float_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_float_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_float_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_float_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_float_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 991; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_68set_float_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":991
 *         self.env[0].SetLongField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_float_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a float field in an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_68set_float_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jfloat __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_float_field", 0);

  /* "javabridge/_javabridge.pyx":999
 *         '''
 *         cdef:
 *             jfloat jvalue = float(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetFloatField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_1 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 999; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_jvalue = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":1000
 *         cdef:
 *             jfloat jvalue = float(value)
 *         self.env[0].SetFloatField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_double_field(self, JB_Object o, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetFloatField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_71set_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_70set_double_field[] = "Set a double field in an object\n        \n        o - object in question\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using float()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_71set_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_double_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__o,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_double_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_double_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_double_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_double_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_70set_double_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_o, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1002
 *         self.env[0].SetFloatField(self.env, o.o, field.id, jvalue)
 * 
 *     def set_double_field(self, JB_Object o, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a double field in an object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_70set_double_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jdouble __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_double_field", 0);

  /* "javabridge/_javabridge.pyx":1010
 *         '''
 *         cdef:
 *             jdouble jvalue = float(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetDoubleField(self.env, o.o, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_1 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1010; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_jvalue = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":1011
 *         cdef:
 *             jdouble jvalue = float(value)
 *         self.env[0].SetDoubleField(self.env, o.o, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_field_id(self, JB_Class c, char *name, char *sig):
 */
  (__pyx_v_self->env[0])->SetDoubleField(__pyx_v_self->env, __pyx_v_o->o, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_73get_static_field_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_72get_static_field_id[] = "Look up a static field ID on a class";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_73get_static_field_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  char *__pyx_v_name;
  char *__pyx_v_sig;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_field_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__name,&__pyx_n_s__sig,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_field_id", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__sig)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_field_id", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_field_id") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_name = PyBytes_AsString(values[1]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_sig = PyBytes_AsString(values[2]); if (unlikely((!__pyx_v_sig) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_field_id", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_field_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_72get_static_field_id(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_name, __pyx_v_sig);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1013
 *         self.env[0].SetDoubleField(self.env, o.o, field.id, jvalue)
 * 
 *     def get_static_field_id(self, JB_Class c, char *name, char *sig):             # <<<<<<<<<<<<<<
 *         '''Look up a static field ID on a class'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_72get_static_field_id(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, char *__pyx_v_name, char *__pyx_v_sig) {
  jfieldID __pyx_v_id;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_jbid = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_field_id", 0);

  /* "javabridge/_javabridge.pyx":1019
 *             __JB_FieldID jbid
 * 
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, name, sig)             # <<<<<<<<<<<<<<
 *         if id == NULL:
 *             return None
 */
  __pyx_v_id = (__pyx_v_self->env[0])->GetStaticFieldID(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_name, __pyx_v_sig);

  /* "javabridge/_javabridge.pyx":1020
 * 
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, name, sig)
 *         if id == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         jbid = __JB_FieldID()
 */
  __pyx_t_1 = (__pyx_v_id == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1021
 *         id = self.env[0].GetStaticFieldID(self.env, c.c, name, sig)
 *         if id == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         jbid = __JB_FieldID()
 *         jbid.id = id
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1022
 *         if id == NULL:
 *             return None
 *         jbid = __JB_FieldID()             # <<<<<<<<<<<<<<
 *         jbid.id = id
 *         jbid.sig = sig
 */
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge___JB_FieldID)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1022; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_jbid = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":1023
 *             return None
 *         jbid = __JB_FieldID()
 *         jbid.id = id             # <<<<<<<<<<<<<<
 *         jbid.sig = sig
 *         jbid.is_static = False
 */
  __pyx_v_jbid->id = __pyx_v_id;

  /* "javabridge/_javabridge.pyx":1024
 *         jbid = __JB_FieldID()
 *         jbid.id = id
 *         jbid.sig = sig             # <<<<<<<<<<<<<<
 *         jbid.is_static = False
 *         return jbid
 */
  __pyx_t_2 = PyBytes_FromString(__pyx_v_sig); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1024; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __Pyx_GOTREF(__pyx_v_jbid->sig);
  __Pyx_DECREF(__pyx_v_jbid->sig);
  __pyx_v_jbid->sig = ((PyObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":1025
 *         jbid.id = id
 *         jbid.sig = sig
 *         jbid.is_static = False             # <<<<<<<<<<<<<<
 *         return jbid
 * 
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1025; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_jbid->is_static);
  __Pyx_DECREF(__pyx_v_jbid->is_static);
  __pyx_v_jbid->is_static = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":1026
 *         jbid.sig = sig
 *         jbid.is_static = False
 *         return jbid             # <<<<<<<<<<<<<<
 * 
 *     def get_static_object_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jbid));
  __pyx_r = ((PyObject *)__pyx_v_jbid);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_field_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbid);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_75get_static_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_74get_static_object_field[] = "Return an object field on a class";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_75get_static_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_object_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_object_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_object_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_object_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_74get_static_object_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1028
 *         return jbid
 * 
 *     def get_static_object_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an object field on a class'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_74get_static_object_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  jobject __pyx_v_o;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_object_field", 0);

  /* "javabridge/_javabridge.pyx":1032
 *         cdef:
 *             jobject o
 *         o = self.env[0].GetStaticObjectField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             return
 */
  __pyx_v_o = (__pyx_v_self->env[0])->GetStaticObjectField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id);

  /* "javabridge/_javabridge.pyx":1033
 *             jobject o
 *         o = self.env[0].GetStaticObjectField(self.env, c.c, field.id)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, o)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1034
 *         o = self.env[0].GetStaticObjectField(self.env, c.c, field.id)
 *         if o == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1035
 *         if o == NULL:
 *             return
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_2 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1036
 *             return
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1037
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1037; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1038
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_static_boolean_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_77get_static_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_76get_static_boolean_field[] = "Return a boolean static field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_77get_static_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_boolean_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_boolean_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_boolean_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_boolean_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_76get_static_boolean_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1040
 *         return result
 * 
 *     def get_static_boolean_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a boolean static field's value'''
 *         return self.env[0].GetStaticBooleanField(self.env, c.c, field.id) != 0
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_76get_static_boolean_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_boolean_field", 0);

  /* "javabridge/_javabridge.pyx":1042
 *     def get_static_boolean_field(self, JB_Class c, __JB_FieldID field):
 *         '''Return a boolean static field's value'''
 *         return self.env[0].GetStaticBooleanField(self.env, c.c, field.id) != 0             # <<<<<<<<<<<<<<
 * 
 *     def get_static_byte_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(((__pyx_v_self->env[0])->GetStaticBooleanField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id) != 0)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1042; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_79get_static_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_78get_static_byte_field[] = "Return a byte static field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_79get_static_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_byte_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_byte_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_byte_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_byte_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_78get_static_byte_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1044
 *         return self.env[0].GetStaticBooleanField(self.env, c.c, field.id) != 0
 * 
 *     def get_static_byte_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a byte static field's value'''
 *         return self.env[0].GetStaticByteField(self.env, c.c, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_78get_static_byte_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_byte_field", 0);

  /* "javabridge/_javabridge.pyx":1046
 *     def get_static_byte_field(self, JB_Class c, __JB_FieldID field):
 *         '''Return a byte static field's value'''
 *         return self.env[0].GetStaticByteField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_short_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jbyte((__pyx_v_self->env[0])->GetStaticByteField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1046; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_81get_static_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_80get_static_short_field[] = "Return a short static field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_81get_static_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_short_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_short_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1048; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_short_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1048; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_short_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1048; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1048; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1048; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_80get_static_short_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1048
 *         return self.env[0].GetStaticByteField(self.env, c.c, field.id)
 * 
 *     def get_static_short_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a short static field's value'''
 *         return self.env[0].GetStaticShortField(self.env, c.c, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_80get_static_short_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_short_field", 0);

  /* "javabridge/_javabridge.pyx":1050
 *     def get_static_short_field(self, JB_Class c, __JB_FieldID field):
 *         '''Return a short static field's value'''
 *         return self.env[0].GetStaticShortField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_int_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jshort((__pyx_v_self->env[0])->GetStaticShortField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_83get_static_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_82get_static_int_field[] = "Return an int field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_83get_static_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_int_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_int_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1052; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_int_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1052; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_int_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1052; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1052; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1052; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_82get_static_int_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1052
 *         return self.env[0].GetStaticShortField(self.env, c.c, field.id)
 * 
 *     def get_static_int_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return an int field's value'''
 *         return self.env[0].GetStaticIntField(self.env, c.c, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_82get_static_int_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_int_field", 0);

  /* "javabridge/_javabridge.pyx":1054
 *     def get_static_int_field(self, JB_Class c, __JB_FieldID field):
 *         '''Return an int field's value'''
 *         return self.env[0].GetStaticIntField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_long_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jint((__pyx_v_self->env[0])->GetStaticIntField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1054; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_85get_static_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_84get_static_long_field[] = "Return a long field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_85get_static_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_long_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_long_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1056; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_long_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1056; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_long_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1056; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1056; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1056; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_84get_static_long_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1056
 *         return self.env[0].GetStaticIntField(self.env, c.c, field.id)
 * 
 *     def get_static_long_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a long field's value'''
 *         return self.env[0].GetStaticLongField(self.env, c.c, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_84get_static_long_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_long_field", 0);

  /* "javabridge/_javabridge.pyx":1058
 *     def get_static_long_field(self, JB_Class c, __JB_FieldID field):
 *         '''Return a long field's value'''
 *         return self.env[0].GetStaticLongField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_float_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jlong((__pyx_v_self->env[0])->GetStaticLongField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1058; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_87get_static_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_86get_static_float_field[] = "Return a float field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_87get_static_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_float_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_float_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1060; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_float_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1060; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_float_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1060; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1060; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1060; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_86get_static_float_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1060
 *         return self.env[0].GetStaticLongField(self.env, c.c, field.id)
 * 
 *     def get_static_float_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a float field's value'''
 *         return self.env[0].GetStaticFloatField(self.env, c.c, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_86get_static_float_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_float_field", 0);

  /* "javabridge/_javabridge.pyx":1062
 *     def get_static_float_field(self, JB_Class c, __JB_FieldID field):
 *         '''Return a float field's value'''
 *         return self.env[0].GetStaticFloatField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def get_static_double_field(self, JB_Class c, __JB_FieldID field):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->env[0])->GetStaticFloatField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1062; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_89get_static_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_88get_static_double_field[] = "Return a double field's value";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_89get_static_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_static_double_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_static_double_field", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1064; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_static_double_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1064; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_static_double_field", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1064; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1064; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1064; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_88get_static_double_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1064
 *         return self.env[0].GetStaticFloatField(self.env, c.c, field.id)
 * 
 *     def get_static_double_field(self, JB_Class c, __JB_FieldID field):             # <<<<<<<<<<<<<<
 *         '''Return a double field's value'''
 *         return self.env[0].GetStaticDoubleField(self.env, c.c, field.id)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_88get_static_double_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_static_double_field", 0);

  /* "javabridge/_javabridge.pyx":1066
 *     def get_static_double_field(self, JB_Class c, __JB_FieldID field):
 *         '''Return a double field's value'''
 *         return self.env[0].GetStaticDoubleField(self.env, c.c, field.id)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_object_field(self, JB_Class c, __JB_FieldID field, JB_Object o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->env[0])->GetStaticDoubleField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1066; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_static_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_91set_static_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_90set_static_object_field[] = "Set a static object field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        o - the object that will become the field's new value\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_91set_static_object_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_object_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__o,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_object_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__o)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_object_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_object_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_o = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_object_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_object_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_90set_static_object_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_o);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1068
 *         return self.env[0].GetStaticDoubleField(self.env, c.c, field.id)
 * 
 *     def set_static_object_field(self, JB_Class c, __JB_FieldID field, JB_Object o):             # <<<<<<<<<<<<<<
 *         '''Set a static object field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_90set_static_object_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_object_field", 0);

  /* "javabridge/_javabridge.pyx":1075
 *         o - the object that will become the field's new value
 *         '''
 *         self.env[0].SetStaticObjectField(self.env, c.c, field.id, o.o)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_boolean_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticObjectField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_o->o);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_93set_static_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_92set_static_boolean_field[] = "Set a static object field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        value - a value whose truth value determines the field's value\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_93set_static_boolean_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_boolean_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_boolean_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1077; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_boolean_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1077; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_boolean_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1077; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_boolean_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1077; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1077; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1077; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_92set_static_boolean_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1077
 *         self.env[0].SetStaticObjectField(self.env, c.c, field.id, o.o)
 * 
 *     def set_static_boolean_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static object field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_92set_static_boolean_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jboolean __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_static_boolean_field", 0);

  /* "javabridge/_javabridge.pyx":1085
 *         '''
 *         cdef:
 *             jboolean jvalue = 1 if value else 0             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticBooleanField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1085; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_v_jvalue = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":1086
 *         cdef:
 *             jboolean jvalue = 1 if value else 0
 *         self.env[0].SetStaticBooleanField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_byte_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticBooleanField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_boolean_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_95set_static_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_94set_static_byte_field[] = "Set a static byte field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        value - a value suitable for int() conversion\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_95set_static_byte_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_byte_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_byte_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_byte_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_byte_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_byte_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_94set_static_byte_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1088
 *         self.env[0].SetStaticBooleanField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_byte_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static byte field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_94set_static_byte_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jbyte __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jbyte __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_static_byte_field", 0);

  /* "javabridge/_javabridge.pyx":1096
 *         '''
 *         cdef:
 *             jbyte jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticByteField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1096; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1096; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_from_py_jbyte(__pyx_t_2); if (unlikely((__pyx_t_3 == (jbyte)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1096; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_jvalue = __pyx_t_3;

  /* "javabridge/_javabridge.pyx":1097
 *         cdef:
 *             jbyte jvalue = int(value)
 *         self.env[0].SetStaticByteField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_char_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticByteField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_byte_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_97set_static_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_96set_static_char_field[] = "Set a static object field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        value - should be convertible to unicode and at least 1 char long\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_97set_static_char_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_char_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_char_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_char_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_96set_static_char_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1099
 *         self.env[0].SetStaticByteField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_char_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static object field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_96set_static_char_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jchar __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_static_char_field", 0);

  /* "javabridge/_javabridge.pyx":1107
 *         '''
 *         cdef:
 *             jchar jvalue = PyUnicode_AS_UNICODE(unicode(value))[0]             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_v_jvalue = (PyUnicode_AS_UNICODE(__pyx_t_2)[0]);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":1108
 *         cdef:
 *             jchar jvalue = PyUnicode_AS_UNICODE(unicode(value))[0]
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_short_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticCharField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_char_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_99set_static_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_98set_static_short_field[] = "Set a static short field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_99set_static_short_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_short_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_short_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1110; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_short_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1110; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_short_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1110; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_short_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1110; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_98set_static_short_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1110
 *         self.env[0].SetStaticCharField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_short_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static short field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_98set_static_short_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jshort __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jshort __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_static_short_field", 0);

  /* "javabridge/_javabridge.pyx":1118
 *         '''
 *         cdef:
 *             jshort jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticShortField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_from_py_jshort(__pyx_t_2); if (unlikely((__pyx_t_3 == (jshort)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_jvalue = __pyx_t_3;

  /* "javabridge/_javabridge.pyx":1119
 *         cdef:
 *             jshort jvalue = int(value)
 *         self.env[0].SetStaticShortField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_int_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticShortField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_short_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_101set_static_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_100set_static_int_field[] = "Set a static int field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_101set_static_int_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_int_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_int_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1121; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_int_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1121; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_int_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1121; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_int_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1121; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_100set_static_int_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1121
 *         self.env[0].SetStaticShortField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_int_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static int field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_100set_static_int_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jint __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jint __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_static_int_field", 0);

  /* "javabridge/_javabridge.pyx":1129
 *         '''
 *         cdef:
 *             jint jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticIntField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_from_py_jint(__pyx_t_2); if (unlikely((__pyx_t_3 == (jint)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_jvalue = __pyx_t_3;

  /* "javabridge/_javabridge.pyx":1130
 *         cdef:
 *             jint jvalue = int(value)
 *         self.env[0].SetStaticIntField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_long_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticIntField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_int_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_103set_static_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_102set_static_long_field[] = "Set a static long field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using int()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_103set_static_long_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_long_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_long_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_long_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_long_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_long_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_102set_static_long_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1132
 *         self.env[0].SetStaticIntField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_long_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static long field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_102set_static_long_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jlong __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  jlong __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_static_long_field", 0);

  /* "javabridge/_javabridge.pyx":1140
 *         '''
 *         cdef:
 *             jlong jvalue = int(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticLongField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_from_py_jlong(__pyx_t_2); if (unlikely((__pyx_t_3 == (jlong)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_jvalue = __pyx_t_3;

  /* "javabridge/_javabridge.pyx":1141
 *         cdef:
 *             jlong jvalue = int(value)
 *         self.env[0].SetStaticLongField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_float_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticLongField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_long_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_105set_static_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_104set_static_float_field[] = "Set a static float field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using float()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_105set_static_float_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_float_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_float_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_float_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_float_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_float_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_104set_static_float_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1143
 *         self.env[0].SetStaticLongField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_float_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static float field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_104set_static_float_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jfloat __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_static_float_field", 0);

  /* "javabridge/_javabridge.pyx":1151
 *         '''
 *         cdef:
 *             jfloat jvalue = float(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticFloatField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_1 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_jvalue = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":1152
 *         cdef:
 *             jfloat jvalue = float(value)
 *         self.env[0].SetStaticFloatField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def set_static_double_field(self, JB_Class c, __JB_FieldID field, value):
 */
  (__pyx_v_self->env[0])->SetStaticFloatField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_float_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_107set_static_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_106set_static_double_field[] = "Set a static double field in a class\n        \n        c - class in question, e.g. as retrieved from find_class\n        field - a field id retrieved from get_static_field_id\n        value - the value to set, should be castable using float()\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_107set_static_double_field(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_static_double_field (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__field,&__pyx_n_s__value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__field)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_double_field", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_static_double_field", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_static_double_field") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_field = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)values[1]);
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_static_double_field", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field), __pyx_ptype_10javabridge_11_javabridge___JB_FieldID, 1, "field", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_106set_static_double_field(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_field, __pyx_v_value);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1154
 *         self.env[0].SetStaticFloatField(self.env, c.c, field.id, jvalue)
 * 
 *     def set_static_double_field(self, JB_Class c, __JB_FieldID field, value):             # <<<<<<<<<<<<<<
 *         '''Set a static double field in a class
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_106set_static_double_field(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *__pyx_v_field, PyObject *__pyx_v_value) {
  jdouble __pyx_v_jvalue;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_static_double_field", 0);

  /* "javabridge/_javabridge.pyx":1162
 *         '''
 *         cdef:
 *             jdouble jvalue = float(value)             # <<<<<<<<<<<<<<
 *         self.env[0].SetStaticDoubleField(self.env, c.c, field.id, jvalue)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsDouble(__pyx_v_value); if (unlikely(__pyx_t_1 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_jvalue = __pyx_t_1;

  /* "javabridge/_javabridge.pyx":1163
 *         cdef:
 *             jdouble jvalue = float(value)
 *         self.env[0].SetStaticDoubleField(self.env, c.c, field.id, jvalue)             # <<<<<<<<<<<<<<
 * 
 *     def new_object(self, JB_Class c, __JB_MethodID m, *args):
 */
  (__pyx_v_self->env[0])->SetStaticDoubleField(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_field->id, __pyx_v_jvalue);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_static_double_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_109new_object(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_108new_object[] = "Call a class constructor with arguments\n\n        c - class in question\n        m - the method ID. You can get this by calling get_method_id with a\n            name of \"<init>\" and a return type of V\n        *args - the arguments to the method call. Arguments should\n                appear in the same order as the signature. Arguments will\n                be coerced into the type of the signature.\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_109new_object(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c = 0;
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new_object (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__c,&__pyx_n_s__m,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__c)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__m)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("new_object", 0, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "new_object") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_c = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[0]);
    __pyx_v_m = ((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("new_object", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.new_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_m), __pyx_ptype_10javabridge_11_javabridge___JB_MethodID, 1, "m", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_108new_object(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_c, __pyx_v_m, __pyx_v_args);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1165
 *         self.env[0].SetStaticDoubleField(self.env, c.c, field.id, jvalue)
 * 
 *     def new_object(self, JB_Class c, __JB_MethodID m, *args):             # <<<<<<<<<<<<<<
 *         '''Call a class constructor with arguments
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_108new_object(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_c, struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *__pyx_v_m, PyObject *__pyx_v_args) {
  jvalue *__pyx_v_values;
  jobject __pyx_v_oresult;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_arg_end = NULL;
  PyObject *__pyx_v_arg_sig = NULL;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("new_object", 0);

  /* "javabridge/_javabridge.pyx":1179
 *             jobject oresult
 * 
 *         sig = m.sig             # <<<<<<<<<<<<<<
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_1 = __pyx_v_m->sig;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_sig = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":1180
 * 
 *         sig = m.sig
 *         if sig[0] != '(':             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_sig, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, ((PyObject *)__pyx_kp_s_27), Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":1181
 *         sig = m.sig
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 */
    __pyx_t_2 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_28), __pyx_v_m->sig); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_2));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1182
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_t_2 = PyObject_GetAttr(__pyx_v_sig, __pyx_n_s__find); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_k_tuple_36), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_arg_end = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":1183
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')
 *         if arg_end == -1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_arg_end, __pyx_int_neg_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":1184
 *         arg_end = sig.find(')')
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)             # <<<<<<<<<<<<<<
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 */
    __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_28), __pyx_v_m->sig); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_1));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "javabridge/_javabridge.pyx":1185
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]             # <<<<<<<<<<<<<<
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 */
  __pyx_t_4 = __Pyx_PyIndex_AsSsize_t(__pyx_v_arg_end); if (unlikely((__pyx_t_4 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __Pyx_PySequence_GetSlice(__pyx_v_sig, 1, __pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_arg_sig = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":1186
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)             # <<<<<<<<<<<<<<
 *         if error is not None:
 *             raise error
 */
  __pyx_t_1 = __pyx_f_10javabridge_11_javabridge_fill_values(__pyx_v_arg_sig, ((PyObject *)__pyx_v_args), (&__pyx_v_values)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_error = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":1187
 *         arg_sig = sig[1:arg_end]
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:             # <<<<<<<<<<<<<<
 *             raise error
 *         oresult = self.env[0].NewObjectA(self.env, c.c, m.id, values)
 */
  __pyx_t_3 = (__pyx_v_error != Py_None);
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":1188
 *         error = fill_values(arg_sig, args, &values)
 *         if error is not None:
 *             raise error             # <<<<<<<<<<<<<<
 *         oresult = self.env[0].NewObjectA(self.env, c.c, m.id, values)
 *         free(values)
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "javabridge/_javabridge.pyx":1189
 *         if error is not None:
 *             raise error
 *         oresult = self.env[0].NewObjectA(self.env, c.c, m.id, values)             # <<<<<<<<<<<<<<
 *         free(values)
 *         if oresult == NULL:
 */
  __pyx_v_oresult = (__pyx_v_self->env[0])->NewObjectA(__pyx_v_self->env, __pyx_v_c->c, __pyx_v_m->id, __pyx_v_values);

  /* "javabridge/_javabridge.pyx":1190
 *             raise error
 *         oresult = self.env[0].NewObjectA(self.env, c.c, m.id, values)
 *         free(values)             # <<<<<<<<<<<<<<
 *         if oresult == NULL:
 *             return
 */
  free(__pyx_v_values);

  /* "javabridge/_javabridge.pyx":1191
 *         oresult = self.env[0].NewObjectA(self.env, c.c, m.id, values)
 *         free(values)
 *         if oresult == NULL:             # <<<<<<<<<<<<<<
 *             return
 *         result, e = make_jb_object(self, oresult)
 */
  __pyx_t_3 = (__pyx_v_oresult == NULL);
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":1192
 *         free(values)
 *         if oresult == NULL:
 *             return             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, oresult)
 *         if e is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1193
 *         if oresult == NULL:
 *             return
 *         result, e = make_jb_object(self, oresult)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_1 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_oresult); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L7_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L8_unpacking_done;
    __pyx_L7_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L8_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "javabridge/_javabridge.pyx":1194
 *             return
 *         result, e = make_jb_object(self, oresult)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_3 = (__pyx_v_e != Py_None);
  if (__pyx_t_3) {

    /* "javabridge/_javabridge.pyx":1195
 *         result, e = make_jb_object(self, oresult)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L9;
  }
  __pyx_L9:;

  /* "javabridge/_javabridge.pyx":1196
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def new_string_utf(self, char *s):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.new_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_arg_end);
  __Pyx_XDECREF(__pyx_v_arg_sig);
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_111new_string_utf(PyObject *__pyx_v_self, PyObject *__pyx_arg_s); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_110new_string_utf[] = "Turn a Python string into a Java string object";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_111new_string_utf(PyObject *__pyx_v_self, PyObject *__pyx_arg_s) {
  char *__pyx_v_s;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new_string_utf (wrapper)", 0);
  assert(__pyx_arg_s); {
    __pyx_v_s = PyBytes_AsString(__pyx_arg_s); if (unlikely((!__pyx_v_s) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1198; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.new_string_utf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_110new_string_utf(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((char *)__pyx_v_s));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1198
 *         return result
 * 
 *     def new_string_utf(self, char *s):             # <<<<<<<<<<<<<<
 *         '''Turn a Python string into a Java string object'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_110new_string_utf(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, char *__pyx_v_s) {
  jobject __pyx_v_o;
  PyObject *__pyx_v_jbo = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("new_string_utf", 0);

  /* "javabridge/_javabridge.pyx":1202
 *         cdef:
 *             jobject o
 *         o = self.env[0].NewStringUTF(self.env, s)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewStringUTF(__pyx_v_self->env, __pyx_v_s);

  /* "javabridge/_javabridge.pyx":1203
 *             jobject o
 *         o = self.env[0].NewStringUTF(self.env, s)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1204
 *         o = self.env[0].NewStringUTF(self.env, s)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")             # <<<<<<<<<<<<<<
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_k_tuple_38), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1205
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *              raise e
 */
  __pyx_t_2 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_jbo = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1206
 *             raise MemoryError("Failed to allocate string")
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *              raise e
 *         return jbo
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1207
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 *              raise e             # <<<<<<<<<<<<<<
 *         return jbo
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1207; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1208
 *         if e is not None:
 *              raise e
 *         return jbo             # <<<<<<<<<<<<<<
 * 
 *     def get_string_utf(self, JB_Object s):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_jbo);
  __pyx_r = __pyx_v_jbo;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.new_string_utf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_jbo);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_113get_string_utf(PyObject *__pyx_v_self, PyObject *__pyx_v_s); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_112get_string_utf[] = "Turn a Java string object into a Python string";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_113get_string_utf(PyObject *__pyx_v_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_string_utf (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "s", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1210; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_112get_string_utf(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_s));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1210
 *         return jbo
 * 
 *     def get_string_utf(self, JB_Object s):             # <<<<<<<<<<<<<<
 *         '''Turn a Java string object into a Python string'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_112get_string_utf(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_s) {
  char *__pyx_v_chars;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_string_utf", 0);

  /* "javabridge/_javabridge.pyx":1214
 *         cdef:
 *             char *chars
 *         if <int> s.o == 0:             # <<<<<<<<<<<<<<
 *            return None
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 */
  __pyx_t_1 = (((int)__pyx_v_s->o) == 0);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1215
 *             char *chars
 *         if <int> s.o == 0:
 *            return None             # <<<<<<<<<<<<<<
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 *         result = str(chars)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1216
 *         if <int> s.o == 0:
 *            return None
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)             # <<<<<<<<<<<<<<
 *         result = str(chars)
 *         self.env[0].ReleaseStringUTFChars(self.env, s.o, chars)
 */
  __pyx_v_chars = (__pyx_v_self->env[0])->GetStringUTFChars(__pyx_v_self->env, __pyx_v_s->o, NULL);

  /* "javabridge/_javabridge.pyx":1217
 *            return None
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 *         result = str(chars)             # <<<<<<<<<<<<<<
 *         self.env[0].ReleaseStringUTFChars(self.env, s.o, chars)
 *         return result
 */
  __pyx_t_2 = PyBytes_FromString(__pyx_v_chars); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1217; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1217; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyString_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1217; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":1218
 *         chars = self.env[0].GetStringUTFChars(self.env, s.o, NULL)
 *         result = str(chars)
 *         self.env[0].ReleaseStringUTFChars(self.env, s.o, chars)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->ReleaseStringUTFChars(__pyx_v_self->env, __pyx_v_s->o, __pyx_v_chars);

  /* "javabridge/_javabridge.pyx":1219
 *         result = str(chars)
 *         self.env[0].ReleaseStringUTFChars(self.env, s.o, chars)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_array_length(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_string_utf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_115get_array_length(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_114get_array_length[] = "Return the length of an array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_115get_array_length(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_array_length (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1221; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_114get_array_length(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1221
 *         return result
 * 
 *     def get_array_length(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the length of an array'''
 *         return self.env[0].GetArrayLength(self.env, array.o)
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_114get_array_length(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_array_length", 0);

  /* "javabridge/_javabridge.pyx":1223
 *     def get_array_length(self, JB_Object array):
 *         '''Return the length of an array'''
 *         return self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *     def get_boolean_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_jint((__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1223; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_array_length", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_117get_boolean_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_116get_boolean_array_elements[] = "Return the contents of a Java boolean array as a numpy array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_117get_boolean_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_boolean_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1225; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_116get_boolean_array_elements(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1225
 *         return self.env[0].GetArrayLength(self.env, array.o)
 * 
 *     def get_boolean_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java boolean array as a numpy array'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_116get_boolean_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_boolean_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "javabridge/_javabridge.pyx":1230
 *             np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "javabridge/_javabridge.pyx":1232
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetBooleanArrayRegion(self.env, array.o, 0, alen, <jboolean *>data)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__zeros); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_3 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__shape), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__uint8); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1233
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetBooleanArrayRegion(self.env, array.o, 0, alen, <jboolean *>data)
 *         return result.astype(np.bool8)
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "javabridge/_javabridge.pyx":1234
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 *         data = result.data
 *         self.env[0].GetBooleanArrayRegion(self.env, array.o, 0, alen, <jboolean *>data)             # <<<<<<<<<<<<<<
 *         return result.astype(np.bool8)
 * 
 */
  (__pyx_v_self->env[0])->GetBooleanArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jboolean *)__pyx_v_data));

  /* "javabridge/_javabridge.pyx":1235
 *         data = result.data
 *         self.env[0].GetBooleanArrayRegion(self.env, array.o, 0, alen, <jboolean *>data)
 *         return result.astype(np.bool8)             # <<<<<<<<<<<<<<
 * 
 *     def get_byte_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_result), __pyx_n_s__astype); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__bool8); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_boolean_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_119get_byte_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_118get_byte_array_elements[] = "Return the contents of a Java byte array as a numpy array\n\n        array - a Java \"byte []\" array\n        returns a 1-d numpy array of np.uint8s\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_119get_byte_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_byte_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_118get_byte_array_elements(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1237
 *         return result.astype(np.bool8)
 * 
 *     def get_byte_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java byte array as a numpy array
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_118get_byte_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_byte_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "javabridge/_javabridge.pyx":1246
 *             np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "javabridge/_javabridge.pyx":1248
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetByteArrayRegion(self.env, array.o, 0, alen, <jbyte *>data)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__zeros); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_3 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__shape), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__uint8); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1249
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetByteArrayRegion(self.env, array.o, 0, alen, <jbyte *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "javabridge/_javabridge.pyx":1250
 *         result = np.zeros(shape=(alen,),dtype=np.uint8)
 *         data = result.data
 *         self.env[0].GetByteArrayRegion(self.env, array.o, 0, alen, <jbyte *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetByteArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jbyte *)__pyx_v_data));

  /* "javabridge/_javabridge.pyx":1251
 *         data = result.data
 *         self.env[0].GetByteArrayRegion(self.env, array.o, 0, alen, <jbyte *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_short_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_byte_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_121get_short_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_120get_short_array_elements[] = "Return the contents of a Java short array as a numpy array\n        \n        array - a Java \"short []\" array\n        returns a 1-d numpy array of np.int16s\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_121get_short_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_short_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_120get_short_array_elements(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1253
 *         return result
 * 
 *     def get_short_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java short array as a numpy array
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_120get_short_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_short_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "javabridge/_javabridge.pyx":1262
 *             np.ndarray[dtype=np.int16_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int16)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "javabridge/_javabridge.pyx":1264
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int16)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetShortArrayRegion(self.env, array.o, 0, alen, <jshort *>data)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__zeros); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_3 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__shape), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__int16); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1265
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int16)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetShortArrayRegion(self.env, array.o, 0, alen, <jshort *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "javabridge/_javabridge.pyx":1266
 *         result = np.zeros(shape=(alen,),dtype=np.int16)
 *         data = result.data
 *         self.env[0].GetShortArrayRegion(self.env, array.o, 0, alen, <jshort *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetShortArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jshort *)__pyx_v_data));

  /* "javabridge/_javabridge.pyx":1267
 *         data = result.data
 *         self.env[0].GetShortArrayRegion(self.env, array.o, 0, alen, <jshort *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_int_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_short_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_123get_int_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_122get_int_array_elements[] = "Return the contents of a Java byte array as a numpy array\n        \n        array - a Java \"int []\" array\n        returns a 1-d numpy array of np.int32s\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_123get_int_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_int_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1269; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_122get_int_array_elements(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1269
 *         return result
 * 
 *     def get_int_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java byte array as a numpy array
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_122get_int_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_int_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "javabridge/_javabridge.pyx":1278
 *             np.ndarray[dtype=np.int32_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int32)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "javabridge/_javabridge.pyx":1280
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int32)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetIntArrayRegion(self.env, array.o, 0, alen, <jint *>data)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__zeros); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_3 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__shape), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__int32); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1281
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int32)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetIntArrayRegion(self.env, array.o, 0, alen, <jint *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "javabridge/_javabridge.pyx":1282
 *         result = np.zeros(shape=(alen,),dtype=np.int32)
 *         data = result.data
 *         self.env[0].GetIntArrayRegion(self.env, array.o, 0, alen, <jint *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetIntArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jint *)__pyx_v_data));

  /* "javabridge/_javabridge.pyx":1283
 *         data = result.data
 *         self.env[0].GetIntArrayRegion(self.env, array.o, 0, alen, <jint *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_long_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_int_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_125get_long_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_124get_long_array_elements[] = "Return the contents of a Java long array as a numpy array\n        \n        array - a Java \"long []\" array\n        returns a 1-d numpy array of np.int64s\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_125get_long_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_long_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_124get_long_array_elements(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1285
 *         return result
 * 
 *     def get_long_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java long array as a numpy array
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_124get_long_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_long_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "javabridge/_javabridge.pyx":1294
 *             np.ndarray[dtype=np.int64_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int64)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "javabridge/_javabridge.pyx":1296
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int64)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetLongArrayRegion(self.env, array.o, 0, alen, <jlong *>data)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__zeros); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_3 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__shape), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__int64); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1297
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.int64)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetLongArrayRegion(self.env, array.o, 0, alen, <jlong *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "javabridge/_javabridge.pyx":1298
 *         result = np.zeros(shape=(alen,),dtype=np.int64)
 *         data = result.data
 *         self.env[0].GetLongArrayRegion(self.env, array.o, 0, alen, <jlong *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetLongArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jlong *)__pyx_v_data));

  /* "javabridge/_javabridge.pyx":1299
 *         data = result.data
 *         self.env[0].GetLongArrayRegion(self.env, array.o, 0, alen, <jlong *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_float_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_long_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_127get_float_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_126get_float_array_elements[] = "Return the contents of a Java float array as a numpy array\n        \n        array - a Java \"float []\" array\n        returns a 1-d numpy array of np.int32s\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_127get_float_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_float_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_126get_float_array_elements(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1301
 *         return result
 * 
 *     def get_float_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java float array as a numpy array
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_126get_float_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_float_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "javabridge/_javabridge.pyx":1310
 *             np.ndarray[dtype=np.float32_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float32)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "javabridge/_javabridge.pyx":1312
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float32)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetFloatArrayRegion(self.env, array.o, 0, alen, <jfloat *>data)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__zeros); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_3 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__shape), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__float32); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1313
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float32)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetFloatArrayRegion(self.env, array.o, 0, alen, <jfloat *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "javabridge/_javabridge.pyx":1314
 *         result = np.zeros(shape=(alen,),dtype=np.float32)
 *         data = result.data
 *         self.env[0].GetFloatArrayRegion(self.env, array.o, 0, alen, <jfloat *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetFloatArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jfloat *)__pyx_v_data));

  /* "javabridge/_javabridge.pyx":1315
 *         data = result.data
 *         self.env[0].GetFloatArrayRegion(self.env, array.o, 0, alen, <jfloat *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_double_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_float_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_129get_double_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_128get_double_array_elements[] = "Return the contents of a Java double array as a numpy array\n        \n        array - a Java \"int []\" array\n        returns a 1-d numpy array of np.int32s\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_129get_double_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_double_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1317; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_128get_double_array_elements(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1317
 *         return result
 * 
 *     def get_double_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java double array as a numpy array
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_128get_double_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  PyArrayObject *__pyx_v_result = 0;
  char *__pyx_v_data;
  jsize __pyx_v_alen;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyArrayObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  char *__pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_double_array_elements", 0);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "javabridge/_javabridge.pyx":1326
 *             np.ndarray[dtype=np.float64_t, ndim=1, negative_indices=False, mode='c'] result
 *             char *data
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float64)
 */
  __pyx_v_alen = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "javabridge/_javabridge.pyx":1328
 *             jsize alen = self.env[0].GetArrayLength(self.env, array.o)
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float64)             # <<<<<<<<<<<<<<
 *         data = result.data
 *         self.env[0].GetDoubleArrayRegion(self.env, array.o, 0, alen, <jdouble *>data)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__zeros); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_3 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__shape), ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__float64); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_5, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1329
 * 
 *         result = np.zeros(shape=(alen,),dtype=np.float64)
 *         data = result.data             # <<<<<<<<<<<<<<
 *         self.env[0].GetDoubleArrayRegion(self.env, array.o, 0, alen, <jdouble *>data)
 *         return result
 */
  __pyx_t_10 = __pyx_v_result->data;
  __pyx_v_data = __pyx_t_10;

  /* "javabridge/_javabridge.pyx":1330
 *         result = np.zeros(shape=(alen,),dtype=np.float64)
 *         data = result.data
 *         self.env[0].GetDoubleArrayRegion(self.env, array.o, 0, alen, <jdouble *>data)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  (__pyx_v_self->env[0])->GetDoubleArrayRegion(__pyx_v_self->env, __pyx_v_array->o, 0, __pyx_v_alen, ((jdouble *)__pyx_v_data));

  /* "javabridge/_javabridge.pyx":1331
 *         data = result.data
 *         self.env[0].GetDoubleArrayRegion(self.env, array.o, 0, alen, <jdouble *>data)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_object_array_elements(self, JB_Object array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_double_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_131get_object_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_130get_object_array_elements[] = "Return the contents of a Java object array as a list of wrapped objects";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_131get_object_array_elements(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_object_array_elements (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_130get_object_array_elements(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1333
 *         return result
 * 
 *     def get_object_array_elements(self, JB_Object array):             # <<<<<<<<<<<<<<
 *         '''Return the contents of a Java object array as a list of wrapped objects'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_130get_object_array_elements(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_nobjects;
  int __pyx_v_i;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_sub = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  jsize __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_object_array_elements", 0);

  /* "javabridge/_javabridge.pyx":1337
 *         cdef:
 *             jobject o
 *             jsize nobjects = self.env[0].GetArrayLength(self.env, array.o)             # <<<<<<<<<<<<<<
 *             int i
 *         result = []
 */
  __pyx_v_nobjects = (__pyx_v_self->env[0])->GetArrayLength(__pyx_v_self->env, __pyx_v_array->o);

  /* "javabridge/_javabridge.pyx":1339
 *             jsize nobjects = self.env[0].GetArrayLength(self.env, array.o)
 *             int i
 *         result = []             # <<<<<<<<<<<<<<
 *         for i in range(nobjects):
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1339; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":1340
 *             int i
 *         result = []
 *         for i in range(nobjects):             # <<<<<<<<<<<<<<
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 *             if o == NULL:
 */
  __pyx_t_2 = __pyx_v_nobjects;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "javabridge/_javabridge.pyx":1341
 *         result = []
 *         for i in range(nobjects):
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)             # <<<<<<<<<<<<<<
 *             if o == NULL:
 *                 result.append(None)
 */
    __pyx_v_o = (__pyx_v_self->env[0])->GetObjectArrayElement(__pyx_v_self->env, __pyx_v_array->o, __pyx_v_i);

    /* "javabridge/_javabridge.pyx":1342
 *         for i in range(nobjects):
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 *             if o == NULL:             # <<<<<<<<<<<<<<
 *                 result.append(None)
 *             else:
 */
    __pyx_t_4 = (__pyx_v_o == NULL);
    if (__pyx_t_4) {

      /* "javabridge/_javabridge.pyx":1343
 *             o = self.env[0].GetObjectArrayElement(self.env, array.o, i)
 *             if o == NULL:
 *                 result.append(None)             # <<<<<<<<<<<<<<
 *             else:
 *                 sub, e = make_jb_object(self, o)
 */
      __pyx_t_5 = PyList_Append(__pyx_v_result, Py_None); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L5;
    }
    /*else*/ {

      /* "javabridge/_javabridge.pyx":1345
 *                 result.append(None)
 *             else:
 *                 sub, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *                 if e is not None:
 *                     raise e
 */
      __pyx_t_1 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
        index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_unpacking_done;
        __pyx_L6_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L7_unpacking_done:;
      }
      __Pyx_XDECREF(__pyx_v_sub);
      __pyx_v_sub = __pyx_t_6;
      __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_v_e);
      __pyx_v_e = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "javabridge/_javabridge.pyx":1346
 *             else:
 *                 sub, e = make_jb_object(self, o)
 *                 if e is not None:             # <<<<<<<<<<<<<<
 *                     raise e
 *                 result.append(sub)
 */
      __pyx_t_4 = (__pyx_v_e != Py_None);
      if (__pyx_t_4) {

        /* "javabridge/_javabridge.pyx":1347
 *                 sub, e = make_jb_object(self, o)
 *                 if e is not None:
 *                     raise e             # <<<<<<<<<<<<<<
 *                 result.append(sub)
 *         return result
 */
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1347; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L8;
      }
      __pyx_L8:;

      /* "javabridge/_javabridge.pyx":1348
 *                 if e is not None:
 *                     raise e
 *                 result.append(sub)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
      __pyx_t_5 = PyList_Append(__pyx_v_result, __pyx_v_sub); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L5:;
  }

  /* "javabridge/_javabridge.pyx":1349
 *                     raise e
 *                 result.append(sub)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_boolean_array(self, array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.get_object_array_elements", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_sub);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_133make_boolean_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_132make_boolean_array[] = "Create a java boolean [] array from the contents of a numpy array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_133make_boolean_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_boolean_array (wrapper)", 0);
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_132make_boolean_array(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((PyObject *)__pyx_v_array));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1351
 *         return result
 * 
 *     def make_boolean_array(self, array):             # <<<<<<<<<<<<<<
 *         '''Create a java boolean [] array from the contents of a numpy array'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_132make_boolean_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyObject *__pyx_v_array) {
  PyArrayObject *__pyx_v_barray = 0;
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jboolean *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_barray;
  __Pyx_Buffer __pyx_pybuffer_barray;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyArrayObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_boolean_array", 0);
  __pyx_pybuffer_barray.pybuffer.buf = NULL;
  __pyx_pybuffer_barray.refcount = 0;
  __pyx_pybuffernd_barray.data = NULL;
  __pyx_pybuffernd_barray.rcbuffer = &__pyx_pybuffer_barray;

  /* "javabridge/_javabridge.pyx":1354
 *         '''Create a java boolean [] array from the contents of a numpy array'''
 *         cdef:
 *             np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] barray = array.astype(np.bool8).astype(np.uint8)             # <<<<<<<<<<<<<<
 *             jobject o
 *             jsize alen = barray.shape[0]
 */
  __pyx_t_1 = PyObject_GetAttr(__pyx_v_array, __pyx_n_s__astype); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__bool8); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__astype); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__uint8); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_barray.rcbuffer->pybuffer, (PyObject*)__pyx_t_4, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_barray = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_barray.rcbuffer->pybuffer.buf = NULL;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    } else {__pyx_pybuffernd_barray.diminfo[0].strides = __pyx_pybuffernd_barray.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_barray.diminfo[0].shape = __pyx_pybuffernd_barray.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_4 = 0;
  __pyx_v_barray = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":1356
 *             np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] barray = array.astype(np.bool8).astype(np.uint8)
 *             jobject o
 *             jsize alen = barray.shape[0]             # <<<<<<<<<<<<<<
 *             jboolean *data = <jboolean *>(barray.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_barray->dimensions[0]);

  /* "javabridge/_javabridge.pyx":1357
 *             jobject o
 *             jsize alen = barray.shape[0]
 *             jboolean *data = <jboolean *>(barray.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewBooleanArray(self.env, alen)
 */
  __pyx_v_data = ((jboolean *)__pyx_v_barray->data);

  /* "javabridge/_javabridge.pyx":1359
 *             jboolean *data = <jboolean *>(barray.data)
 * 
 *         o = self.env[0].NewBooleanArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewBooleanArray(__pyx_v_self->env, __pyx_v_alen);

  /* "javabridge/_javabridge.pyx":1360
 * 
 *         o = self.env[0].NewBooleanArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_5 = (__pyx_v_o == NULL);
  if (__pyx_t_5) {

    /* "javabridge/_javabridge.pyx":1361
 *         o = self.env[0].NewBooleanArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_1 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_39), __pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1362
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetBooleanArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "javabridge/_javabridge.pyx":1363
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_e = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "javabridge/_javabridge.pyx":1364
 *         self.env[0].SetBooleanArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_5 = (__pyx_v_e != Py_None);
  if (__pyx_t_5) {

    /* "javabridge/_javabridge.pyx":1365
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1365; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1366
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_byte_array(self, np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_barray.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_boolean_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_barray.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_barray);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_135make_byte_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_134make_byte_array[] = "Create a java byte [] array from the contents of a numpy array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_135make_byte_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_byte_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1368; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_134make_byte_array(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1368
 *         return result
 * 
 *     def make_byte_array(self, np.ndarray[dtype=np.uint8_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java byte [] array from the contents of a numpy array'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_134make_byte_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jbyte *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_byte_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1368; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "javabridge/_javabridge.pyx":1372
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jbyte *data = <jbyte *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "javabridge/_javabridge.pyx":1373
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jbyte *data = <jbyte *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewByteArray(self.env, alen)
 */
  __pyx_v_data = ((jbyte *)__pyx_v_array->data);

  /* "javabridge/_javabridge.pyx":1375
 *             jbyte *data = <jbyte *>(array.data)
 * 
 *         o = self.env[0].NewByteArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewByteArray(__pyx_v_self->env, __pyx_v_alen);

  /* "javabridge/_javabridge.pyx":1376
 * 
 *         o = self.env[0].NewByteArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1377
 *         o = self.env[0].NewByteArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1377; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_39), __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1377; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1377; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1377; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1377; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1378
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetByteArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "javabridge/_javabridge.pyx":1379
 *             raise MemoryError("Failed to allocate byte array of size %d"%alen)
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1380
 *         self.env[0].SetByteArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1381
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1381; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1382
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_short_array(self, np.ndarray[dtype=np.int16_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_byte_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_137make_short_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_136make_short_array[] = "Create a java short [] array from the contents of a numpy array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_137make_short_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_short_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1384; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_136make_short_array(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1384
 *         return result
 * 
 *     def make_short_array(self, np.ndarray[dtype=np.int16_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java short [] array from the contents of a numpy array'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_136make_short_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jshort *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_short_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1384; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "javabridge/_javabridge.pyx":1388
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jshort *data = <jshort *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "javabridge/_javabridge.pyx":1389
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jshort *data = <jshort *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewShortArray(self.env, alen)
 */
  __pyx_v_data = ((jshort *)__pyx_v_array->data);

  /* "javabridge/_javabridge.pyx":1391
 *             jshort *data = <jshort *>(array.data)
 * 
 *         o = self.env[0].NewShortArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewShortArray(__pyx_v_self->env, __pyx_v_alen);

  /* "javabridge/_javabridge.pyx":1392
 * 
 *         o = self.env[0].NewShortArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1393
 *         o = self.env[0].NewShortArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_40), __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1394
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetShortArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "javabridge/_javabridge.pyx":1395
 *             raise MemoryError("Failed to allocate short array of size %d"%alen)
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1396
 *         self.env[0].SetShortArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1397
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1398
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_int_array(self, np.ndarray[dtype=np.int32_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_short_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_139make_int_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_138make_int_array[] = "Create a java int [] array from the contents of a numpy array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_139make_int_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_int_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1400; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_138make_int_array(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1400
 *         return result
 * 
 *     def make_int_array(self, np.ndarray[dtype=np.int32_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java int [] array from the contents of a numpy array'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_138make_int_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jint *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_int_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1400; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "javabridge/_javabridge.pyx":1404
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jint *data = <jint *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "javabridge/_javabridge.pyx":1405
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jint *data = <jint *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewIntArray(self.env, alen)
 */
  __pyx_v_data = ((jint *)__pyx_v_array->data);

  /* "javabridge/_javabridge.pyx":1407
 *             jint *data = <jint *>(array.data)
 * 
 *         o = self.env[0].NewIntArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewIntArray(__pyx_v_self->env, __pyx_v_alen);

  /* "javabridge/_javabridge.pyx":1408
 * 
 *         o = self.env[0].NewIntArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1409
 *         o = self.env[0].NewIntArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_41), __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1410
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetIntArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "javabridge/_javabridge.pyx":1411
 *             raise MemoryError("Failed to allocate int array of size %d"%alen)
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1412
 *         self.env[0].SetIntArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1413
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1414
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_long_array(self, np.ndarray[dtype=np.int64_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_int_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_141make_long_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_140make_long_array[] = "Create a java long [] array from the contents of a numpy array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_141make_long_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_long_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_140make_long_array(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1416
 *         return result
 * 
 *     def make_long_array(self, np.ndarray[dtype=np.int64_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java long [] array from the contents of a numpy array'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_140make_long_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jlong *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_long_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "javabridge/_javabridge.pyx":1420
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jlong *data = <jlong *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "javabridge/_javabridge.pyx":1421
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jlong *data = <jlong *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewLongArray(self.env, alen)
 */
  __pyx_v_data = ((jlong *)__pyx_v_array->data);

  /* "javabridge/_javabridge.pyx":1423
 *             jlong *data = <jlong *>(array.data)
 * 
 *         o = self.env[0].NewLongArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewLongArray(__pyx_v_self->env, __pyx_v_alen);

  /* "javabridge/_javabridge.pyx":1424
 * 
 *         o = self.env[0].NewLongArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1425
 *         o = self.env[0].NewLongArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_42), __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1426
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetLongArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "javabridge/_javabridge.pyx":1427
 *             raise MemoryError("Failed to allocate long array of size %d"%alen)
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1428
 *         self.env[0].SetLongArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1429
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1429; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1430
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_float_array(self, np.ndarray[dtype=np.float32_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_long_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_143make_float_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_142make_float_array[] = "Create a java float [] array from the contents of a numpy array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_143make_float_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_float_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1432; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_142make_float_array(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1432
 *         return result
 * 
 *     def make_float_array(self, np.ndarray[dtype=np.float32_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java float [] array from the contents of a numpy array'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_142make_float_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jfloat *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_float_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1432; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "javabridge/_javabridge.pyx":1436
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jfloat *data = <jfloat *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "javabridge/_javabridge.pyx":1437
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jfloat *data = <jfloat *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewFloatArray(self.env, alen)
 */
  __pyx_v_data = ((jfloat *)__pyx_v_array->data);

  /* "javabridge/_javabridge.pyx":1439
 *             jfloat *data = <jfloat *>(array.data)
 * 
 *         o = self.env[0].NewFloatArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewFloatArray(__pyx_v_self->env, __pyx_v_alen);

  /* "javabridge/_javabridge.pyx":1440
 * 
 *         o = self.env[0].NewFloatArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1441
 *         o = self.env[0].NewFloatArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_43), __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1442
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetFloatArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "javabridge/_javabridge.pyx":1443
 *             raise MemoryError("Failed to allocate float array of size %d"%alen)
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1444
 *         self.env[0].SetFloatArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1445
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1445; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1446
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_double_array(self, np.ndarray[dtype=np.float64_t, ndim=1, negative_indices=False, mode='c'] array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_float_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_145make_double_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_144make_double_array[] = "Create a java double [] array from the contents of a numpy array";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_145make_double_array(PyObject *__pyx_v_self, PyObject *__pyx_v_array) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_double_array (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_array), __pyx_ptype_5numpy_ndarray, 1, "array", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1448; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_144make_double_array(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((PyArrayObject *)__pyx_v_array));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1448
 *         return result
 * 
 *     def make_double_array(self, np.ndarray[dtype=np.float64_t, ndim=1, negative_indices=False, mode='c'] array):             # <<<<<<<<<<<<<<
 *         '''Create a java double [] array from the contents of a numpy array'''
 *         cdef:
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_144make_double_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, PyArrayObject *__pyx_v_array) {
  jobject __pyx_v_o;
  jsize __pyx_v_alen;
  jdouble *__pyx_v_data;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_array;
  __Pyx_Buffer __pyx_pybuffer_array;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_double_array", 0);
  __pyx_pybuffer_array.pybuffer.buf = NULL;
  __pyx_pybuffer_array.refcount = 0;
  __pyx_pybuffernd_array.data = NULL;
  __pyx_pybuffernd_array.rcbuffer = &__pyx_pybuffer_array;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_array.rcbuffer->pybuffer, (PyObject*)__pyx_v_array, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1448; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_array.diminfo[0].strides = __pyx_pybuffernd_array.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_array.diminfo[0].shape = __pyx_pybuffernd_array.rcbuffer->pybuffer.shape[0];

  /* "javabridge/_javabridge.pyx":1452
 *         cdef:
 *             jobject o
 *             jsize alen = array.shape[0]             # <<<<<<<<<<<<<<
 *             jdouble *data = <jdouble *>(array.data)
 * 
 */
  __pyx_v_alen = (__pyx_v_array->dimensions[0]);

  /* "javabridge/_javabridge.pyx":1453
 *             jobject o
 *             jsize alen = array.shape[0]
 *             jdouble *data = <jdouble *>(array.data)             # <<<<<<<<<<<<<<
 * 
 *         o = self.env[0].NewDoubleArray(self.env, alen)
 */
  __pyx_v_data = ((jdouble *)__pyx_v_array->data);

  /* "javabridge/_javabridge.pyx":1455
 *             jdouble *data = <jdouble *>(array.data)
 * 
 *         o = self.env[0].NewDoubleArray(self.env, alen)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewDoubleArray(__pyx_v_self->env, __pyx_v_alen);

  /* "javabridge/_javabridge.pyx":1456
 * 
 *         o = self.env[0].NewDoubleArray(self.env, alen)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1457
 *         o = self.env[0].NewDoubleArray(self.env, alen)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)             # <<<<<<<<<<<<<<
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_jint(__pyx_v_alen); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_44), __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1458
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
  (__pyx_v_self->env[0])->SetDoubleArrayRegion(__pyx_v_self->env, __pyx_v_o, 0, __pyx_v_alen, __pyx_v_data);

  /* "javabridge/_javabridge.pyx":1459
 *             raise MemoryError("Failed to allocate double array of size %d"%alen)
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1460
 *         self.env[0].SetDoubleArrayRegion(self.env, o, 0, alen, data)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1461
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1461; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1462
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def make_object_array(self, int len, JB_Class klass):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_double_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_array.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_147make_object_array(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_146make_object_array[] = "Create a java object [] array filled with all nulls\n        \n        len - # of elements in array\n        klass - class of objects that will be stored\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_147make_object_array(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_len;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_klass = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_object_array (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__len,&__pyx_n_s__klass,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__len)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__klass)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("make_object_array", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1464; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "make_object_array") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1464; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_len = __Pyx_PyInt_AsInt(values[0]); if (unlikely((__pyx_v_len == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1464; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_klass = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Class *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_object_array", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1464; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_object_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_klass), __pyx_ptype_10javabridge_11_javabridge_JB_Class, 1, "klass", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_146make_object_array(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_len, __pyx_v_klass);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1464
 *         return result
 * 
 *     def make_object_array(self, int len, JB_Class klass):             # <<<<<<<<<<<<<<
 *         '''Create a java object [] array filled with all nulls
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_146make_object_array(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, int __pyx_v_len, struct __pyx_obj_10javabridge_11_javabridge_JB_Class *__pyx_v_klass) {
  jobject __pyx_v_o;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_object_array", 0);

  /* "javabridge/_javabridge.pyx":1472
 *         cdef:
 *             jobject o
 *         o = self.env[0].NewObjectArray(self.env, len, klass.c, NULL)             # <<<<<<<<<<<<<<
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 */
  __pyx_v_o = (__pyx_v_self->env[0])->NewObjectArray(__pyx_v_self->env, __pyx_v_len, __pyx_v_klass->c, NULL);

  /* "javabridge/_javabridge.pyx":1473
 *             jobject o
 *         o = self.env[0].NewObjectArray(self.env, len, klass.c, NULL)
 *         if o == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 *         result, e = make_jb_object(self, o)
 */
  __pyx_t_1 = (__pyx_v_o == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1474
 *         o = self.env[0].NewObjectArray(self.env, len, klass.c, NULL)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate object array of size %d" % len)             # <<<<<<<<<<<<<<
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 */
    __pyx_t_2 = PyInt_FromLong(__pyx_v_len); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_45), __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1475
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 *         result, e = make_jb_object(self, o)             # <<<<<<<<<<<<<<
 *         if e is not None:
 *             raise e
 */
  __pyx_t_3 = __pyx_f_10javabridge_11_javabridge_make_jb_object(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_e = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "javabridge/_javabridge.pyx":1476
 *             raise MemoryError("Failed to allocate object array of size %d" % len)
 *         result, e = make_jb_object(self, o)
 *         if e is not None:             # <<<<<<<<<<<<<<
 *             raise e
 *         return result
 */
  __pyx_t_1 = (__pyx_v_e != Py_None);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1477
 *         result, e = make_jb_object(self, o)
 *         if e is not None:
 *             raise e             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __Pyx_Raise(__pyx_v_e, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1477; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "javabridge/_javabridge.pyx":1478
 *         if e is not None:
 *             raise e
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def set_object_array_element(self, JB_Object jbo, int index, JB_Object v):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_object_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_149set_object_array_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_148set_object_array_element[] = "Set an element within an object array\n        \n        jbo - the object array\n        index - the zero-based index of the element to set\n        v - the value to be inserted\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_149set_object_array_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_jbo = 0;
  int __pyx_v_index;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_v = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_object_array_element (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__jbo,&__pyx_n_s__index,&__pyx_n_s__v,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__jbo)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__index)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_object_array_element", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1480; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__v)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_object_array_element", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1480; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_object_array_element") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1480; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_jbo = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[0]);
    __pyx_v_index = __Pyx_PyInt_AsInt(values[1]); if (unlikely((__pyx_v_index == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1480; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_v = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_object_array_element", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1480; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.set_object_array_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_jbo), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "jbo", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1480; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_v), __pyx_ptype_10javabridge_11_javabridge_JB_Object, 1, "v", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1480; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_148set_object_array_element(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), __pyx_v_jbo, __pyx_v_index, __pyx_v_v);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1480
 *         return result
 * 
 *     def set_object_array_element(self, JB_Object jbo, int index, JB_Object v):             # <<<<<<<<<<<<<<
 *         '''Set an element within an object array
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_148set_object_array_element(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_jbo, int __pyx_v_index, struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_v) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_object_array_element", 0);

  /* "javabridge/_javabridge.pyx":1487
 *         v - the value to be inserted
 *         '''
 *         self.env[0].SetObjectArrayElement(self.env, jbo.o, index, v.o)             # <<<<<<<<<<<<<<
 * 
 *     def make_jb_object(self, char *address):
 */
  (__pyx_v_self->env[0])->SetObjectArrayElement(__pyx_v_self->env, __pyx_v_jbo->o, __pyx_v_index, __pyx_v_v->o);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_151make_jb_object(PyObject *__pyx_v_self, PyObject *__pyx_arg_address); /*proto*/
static char __pyx_doc_10javabridge_11_javabridge_6JB_Env_150make_jb_object[] = "Wrap a java object in a javabridge object\n        \n        address - integer representation of the memory address, as a string\n        ";
static PyObject *__pyx_pw_10javabridge_11_javabridge_6JB_Env_151make_jb_object(PyObject *__pyx_v_self, PyObject *__pyx_arg_address) {
  char *__pyx_v_address;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_jb_object (wrapper)", 0);
  assert(__pyx_arg_address); {
    __pyx_v_address = PyBytes_AsString(__pyx_arg_address); if (unlikely((!__pyx_v_address) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1489; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_jb_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10javabridge_11_javabridge_6JB_Env_150make_jb_object(((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)__pyx_v_self), ((char *)__pyx_v_address));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1489
 *         self.env[0].SetObjectArrayElement(self.env, jbo.o, index, v.o)
 * 
 *     def make_jb_object(self, char *address):             # <<<<<<<<<<<<<<
 *         '''Wrap a java object in a javabridge object
 * 
 */

static PyObject *__pyx_pf_10javabridge_11_javabridge_6JB_Env_150make_jb_object(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_self, char *__pyx_v_address) {
  jobject __pyx_v_jobj;
  size_t *__pyx_v_p_addr;
  size_t __pyx_v_c_addr;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_jbo = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_jb_object", 0);

  /* "javabridge/_javabridge.pyx":1497
 *             jobject jobj
 *             size_t  *p_addr
 *             size_t c_addr = strtoull(address, NULL, 0)             # <<<<<<<<<<<<<<
 *             JB_Object jbo
 *         p_addr = <size_t *>&jobj
 */
  __pyx_v_c_addr = strtoull(__pyx_v_address, NULL, 0);

  /* "javabridge/_javabridge.pyx":1499
 *             size_t c_addr = strtoull(address, NULL, 0)
 *             JB_Object jbo
 *         p_addr = <size_t *>&jobj             # <<<<<<<<<<<<<<
 *         p_addr[0] = c_addr
 *         jbo = JB_Object()
 */
  __pyx_v_p_addr = ((size_t *)(&__pyx_v_jobj));

  /* "javabridge/_javabridge.pyx":1500
 *             JB_Object jbo
 *         p_addr = <size_t *>&jobj
 *         p_addr[0] = c_addr             # <<<<<<<<<<<<<<
 *         jbo = JB_Object()
 *         jbo.o = jobj
 */
  (__pyx_v_p_addr[0]) = __pyx_v_c_addr;

  /* "javabridge/_javabridge.pyx":1501
 *         p_addr = <size_t *>&jobj
 *         p_addr[0] = c_addr
 *         jbo = JB_Object()             # <<<<<<<<<<<<<<
 *         jbo.o = jobj
 *         jbo.env = self
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Object)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1501; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_jbo = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":1502
 *         p_addr[0] = c_addr
 *         jbo = JB_Object()
 *         jbo.o = jobj             # <<<<<<<<<<<<<<
 *         jbo.env = self
 *         return jbo
 */
  __pyx_v_jbo->o = __pyx_v_jobj;

  /* "javabridge/_javabridge.pyx":1503
 *         jbo = JB_Object()
 *         jbo.o = jobj
 *         jbo.env = self             # <<<<<<<<<<<<<<
 *         return jbo
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __Pyx_GOTREF(__pyx_v_jbo->env);
  __Pyx_DECREF(__pyx_v_jbo->env);
  __pyx_v_jbo->env = ((PyObject *)__pyx_v_self);

  /* "javabridge/_javabridge.pyx":1504
 *         jbo.o = jobj
 *         jbo.env = self
 *         return jbo             # <<<<<<<<<<<<<<
 * 
 * cdef make_jb_object(JB_Env env, jobject o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_jbo));
  __pyx_r = ((PyObject *)__pyx_v_jbo);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("javabridge._javabridge.JB_Env.make_jb_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "javabridge/_javabridge.pyx":1506
 *         return jbo
 * 
 * cdef make_jb_object(JB_Env env, jobject o):             # <<<<<<<<<<<<<<
 *     '''Wrap a Java object in a JB_Object with appropriate reference handling
 * 
 */

static PyObject *__pyx_f_10javabridge_11_javabridge_make_jb_object(struct __pyx_obj_10javabridge_11_javabridge_JB_Env *__pyx_v_env, jobject __pyx_v_o) {
  jobject __pyx_v_oref;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *__pyx_v_jbo = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_jb_object", 0);

  /* "javabridge/_javabridge.pyx":1517
 *         JB_Object jbo
 * 
 *     oref = env.env[0].NewGlobalRef(env.env, o)             # <<<<<<<<<<<<<<
 *     if oref == NULL:
 *         return (None, MemoryError("Failed to make new global reference"))
 */
  __pyx_v_oref = (__pyx_v_env->env[0])->NewGlobalRef(__pyx_v_env->env, __pyx_v_o);

  /* "javabridge/_javabridge.pyx":1518
 * 
 *     oref = env.env[0].NewGlobalRef(env.env, o)
 *     if oref == NULL:             # <<<<<<<<<<<<<<
 *         return (None, MemoryError("Failed to make new global reference"))
 *     env.env[0].DeleteLocalRef(env.env, o)
 */
  __pyx_t_1 = (__pyx_v_oref == NULL);
  if (__pyx_t_1) {

    /* "javabridge/_javabridge.pyx":1519
 *     oref = env.env[0].NewGlobalRef(env.env, o)
 *     if oref == NULL:
 *         return (None, MemoryError("Failed to make new global reference"))             # <<<<<<<<<<<<<<
 *     env.env[0].DeleteLocalRef(env.env, o)
 *     jbo = JB_Object()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyObject_Call(__pyx_builtin_MemoryError, ((PyObject *)__pyx_k_tuple_47), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_3, 0, Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_r = ((PyObject *)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "javabridge/_javabridge.pyx":1520
 *     if oref == NULL:
 *         return (None, MemoryError("Failed to make new global reference"))
 *     env.env[0].DeleteLocalRef(env.env, o)             # <<<<<<<<<<<<<<
 *     jbo = JB_Object()
 *     jbo.o = oref
 */
  (__pyx_v_env->env[0])->DeleteLocalRef(__pyx_v_env->env, __pyx_v_o);

  /* "javabridge/_javabridge.pyx":1521
 *         return (None, MemoryError("Failed to make new global reference"))
 *     env.env[0].DeleteLocalRef(env.env, o)
 *     jbo = JB_Object()             # <<<<<<<<<<<<<<
 *     jbo.o = oref
 *     jbo.env = env
 */
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_10javabridge_11_javabridge_JB_Object)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1521; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_jbo = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1522
 *     env.env[0].DeleteLocalRef(env.env, o)
 *     jbo = JB_Object()
 *     jbo.o = oref             # <<<<<<<<<<<<<<
 *     jbo.env = env
 *     jbo.gc_collect = True
 */
  __pyx_v_jbo->o = __pyx_v_oref;

  /* "javabridge/_javabridge.pyx":1523
 *     jbo = JB_Object()
 *     jbo.o = oref
 *     jbo.env = env             # <<<<<<<<<<<<<<
 *     jbo.gc_collect = True
 *     return (jbo, None)
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_env));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_env));
  __Pyx_GOTREF(__pyx_v_jbo->env);
  __Pyx_DECREF(__pyx_v_jbo->env);
  __pyx_v_jbo->env = ((PyObject *)__pyx_v_env);

  /* "javabridge/_javabridge.pyx":1524
 *     jbo.o = oref
 *     jbo.env = env
 *     jbo.gc_collect = True             # <<<<<<<<<<<<<<
 *     return (jbo, None)
 */
  __pyx_t_3 = __Pyx_PyBool_FromLong(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1524; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_jbo->gc_collect);
  __Pyx_DECREF(__pyx_v_jbo->gc_collect);
  __pyx_v_jbo->gc_collect = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "javabridge/_javabridge.pyx":1525
 *     jbo.env = env
 *     jbo.gc_collect = True
 *     return (jbo, None)             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1525; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_v_jbo));
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_jbo));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_jbo));
  __Pyx_INCREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_3, 1, Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_r = ((PyObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("javabridge._javabridge.make_jb_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_jbo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5numpy_7ndarray___getbuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":194
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_copy_shape;
  int __pyx_v_i;
  int __pyx_v_ndim;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  int __pyx_v_t;
  char *__pyx_v_f;
  PyArray_Descr *__pyx_v_descr = 0;
  int __pyx_v_offset;
  int __pyx_v_hasfields;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  if (__pyx_v_info != NULL) {
    __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(__pyx_v_info->obj);
  }

  /* "numpy.pxd":200
 *             # of flags
 * 
 *             if info == NULL: return             # <<<<<<<<<<<<<<
 * 
 *             cdef int copy_shape, i, ndim
 */
  __pyx_t_1 = (__pyx_v_info == NULL);
  if (__pyx_t_1) {
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "numpy.pxd":203
 * 
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 */
  __pyx_v_endian_detector = 1;

  /* "numpy.pxd":204
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 * 
 *             ndim = PyArray_NDIM(self)
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "numpy.pxd":206
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 *             ndim = PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_v_ndim = PyArray_NDIM(__pyx_v_self);

  /* "numpy.pxd":208
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
  __pyx_t_1 = ((sizeof(npy_intp)) != (sizeof(Py_ssize_t)));
  if (__pyx_t_1) {

    /* "numpy.pxd":209
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 copy_shape = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 copy_shape = 0
 */
    __pyx_v_copy_shape = 1;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "numpy.pxd":211
 *                 copy_shape = 1
 *             else:
 *                 copy_shape = 0             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 */
    __pyx_v_copy_shape = 0;
  }
  __pyx_L4:;

  /* "numpy.pxd":213
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_C_CONTIGUOUS) == PyBUF_C_CONTIGUOUS);
  if (__pyx_t_1) {

    /* "numpy.pxd":214
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 */
    __pyx_t_2 = (!PyArray_CHKFLAGS(__pyx_v_self, NPY_C_CONTIGUOUS));
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = __pyx_t_1;
  }
  if (__pyx_t_3) {

    /* "numpy.pxd":215
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_49), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 215; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 215; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "numpy.pxd":217
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  __pyx_t_3 = ((__pyx_v_flags & PyBUF_F_CONTIGUOUS) == PyBUF_F_CONTIGUOUS);
  if (__pyx_t_3) {

    /* "numpy.pxd":218
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 */
    __pyx_t_1 = (!PyArray_CHKFLAGS(__pyx_v_self, NPY_F_CONTIGUOUS));
    __pyx_t_2 = __pyx_t_1;
  } else {
    __pyx_t_2 = __pyx_t_3;
  }
  if (__pyx_t_2) {

    /* "numpy.pxd":219
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_51), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "numpy.pxd":221
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 *             info.buf = PyArray_DATA(self)             # <<<<<<<<<<<<<<
 *             info.ndim = ndim
 *             if copy_shape:
 */
  __pyx_v_info->buf = PyArray_DATA(__pyx_v_self);

  /* "numpy.pxd":222
 * 
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim             # <<<<<<<<<<<<<<
 *             if copy_shape:
 *                 # Allocate new buffer for strides and shape info.
 */
  __pyx_v_info->ndim = __pyx_v_ndim;

  /* "numpy.pxd":223
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
  if (__pyx_v_copy_shape) {

    /* "numpy.pxd":226
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)             # <<<<<<<<<<<<<<
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 */
    __pyx_v_info->strides = ((Py_ssize_t *)malloc((((sizeof(Py_ssize_t)) * ((size_t)__pyx_v_ndim)) * 2)));

    /* "numpy.pxd":227
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim             # <<<<<<<<<<<<<<
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 */
    __pyx_v_info->shape = (__pyx_v_info->strides + __pyx_v_ndim);

    /* "numpy.pxd":228
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):             # <<<<<<<<<<<<<<
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 */
    __pyx_t_5 = __pyx_v_ndim;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "numpy.pxd":229
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]             # <<<<<<<<<<<<<<
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 */
      (__pyx_v_info->strides[__pyx_v_i]) = (PyArray_STRIDES(__pyx_v_self)[__pyx_v_i]);

      /* "numpy.pxd":230
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 */
      (__pyx_v_info->shape[__pyx_v_i]) = (PyArray_DIMS(__pyx_v_self)[__pyx_v_i]);
    }
    goto __pyx_L7;
  }
  /*else*/ {

    /* "numpy.pxd":232
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 */
    __pyx_v_info->strides = ((Py_ssize_t *)PyArray_STRIDES(__pyx_v_self));

    /* "numpy.pxd":233
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 */
    __pyx_v_info->shape = ((Py_ssize_t *)PyArray_DIMS(__pyx_v_self));
  }
  __pyx_L7:;

  /* "numpy.pxd":234
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 */
  __pyx_v_info->suboffsets = NULL;

  /* "numpy.pxd":235
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)             # <<<<<<<<<<<<<<
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 * 
 */
  __pyx_v_info->itemsize = PyArray_ITEMSIZE(__pyx_v_self);

  /* "numpy.pxd":236
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)             # <<<<<<<<<<<<<<
 * 
 *             cdef int t
 */
  __pyx_v_info->readonly = (!PyArray_ISWRITEABLE(__pyx_v_self));

  /* "numpy.pxd":239
 * 
 *             cdef int t
 *             cdef char* f = NULL             # <<<<<<<<<<<<<<
 *             cdef dtype descr = self.descr
 *             cdef list stack
 */
  __pyx_v_f = NULL;

  /* "numpy.pxd":240
 *             cdef int t
 *             cdef char* f = NULL
 *             cdef dtype descr = self.descr             # <<<<<<<<<<<<<<
 *             cdef list stack
 *             cdef int offset
 */
  __pyx_t_4 = ((PyObject *)__pyx_v_self->descr);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_descr = ((PyArray_Descr *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "numpy.pxd":244
 *             cdef int offset
 * 
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields and not copy_shape:
 */
  __pyx_v_hasfields = PyDataType_HASFIELDS(__pyx_v_descr);

  /* "numpy.pxd":246
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
  __pyx_t_2 = (!__pyx_v_hasfields);
  if (__pyx_t_2) {
    __pyx_t_3 = (!__pyx_v_copy_shape);
    __pyx_t_1 = __pyx_t_3;
  } else {
    __pyx_t_1 = __pyx_t_2;
  }
  if (__pyx_t_1) {

    /* "numpy.pxd":248
 *             if not hasfields and not copy_shape:
 *                 # do not call releasebuffer
 *                 info.obj = None             # <<<<<<<<<<<<<<
 *             else:
 *                 # need to call releasebuffer
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = Py_None;
    goto __pyx_L10;
  }
  /*else*/ {

    /* "numpy.pxd":251
 *             else:
 *                 # need to call releasebuffer
 *                 info.obj = self             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields:
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = ((PyObject *)__pyx_v_self);
  }
  __pyx_L10:;

  /* "numpy.pxd":253
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  __pyx_t_1 = (!__pyx_v_hasfields);
  if (__pyx_t_1) {

    /* "numpy.pxd":254
 * 
 *             if not hasfields:
 *                 t = descr.type_num             # <<<<<<<<<<<<<<
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 */
    __pyx_t_5 = __pyx_v_descr->type_num;
    __pyx_v_t = __pyx_t_5;

    /* "numpy.pxd":255
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_1 = (__pyx_v_descr->byteorder == '>');
    if (__pyx_t_1) {
      __pyx_t_2 = __pyx_v_little_endian;
    } else {
      __pyx_t_2 = __pyx_t_1;
    }
    if (!__pyx_t_2) {

      /* "numpy.pxd":256
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 */
      __pyx_t_1 = (__pyx_v_descr->byteorder == '<');
      if (__pyx_t_1) {
        __pyx_t_3 = (!__pyx_v_little_endian);
        __pyx_t_7 = __pyx_t_3;
      } else {
        __pyx_t_7 = __pyx_t_1;
      }
      __pyx_t_1 = __pyx_t_7;
    } else {
      __pyx_t_1 = __pyx_t_2;
    }
    if (__pyx_t_1) {

      /* "numpy.pxd":257
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
      __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_53), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L12;
    }
    __pyx_L12:;

    /* "numpy.pxd":258
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_BYTE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__b;
      goto __pyx_L13;
    }

    /* "numpy.pxd":259
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_UBYTE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__B;
      goto __pyx_L13;
    }

    /* "numpy.pxd":260
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_SHORT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__h;
      goto __pyx_L13;
    }

    /* "numpy.pxd":261
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_USHORT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__H;
      goto __pyx_L13;
    }

    /* "numpy.pxd":262
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_INT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__i;
      goto __pyx_L13;
    }

    /* "numpy.pxd":263
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_UINT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__I;
      goto __pyx_L13;
    }

    /* "numpy.pxd":264
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__l;
      goto __pyx_L13;
    }

    /* "numpy.pxd":265
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_ULONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__L;
      goto __pyx_L13;
    }

    /* "numpy.pxd":266
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONGLONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__q;
      goto __pyx_L13;
    }

    /* "numpy.pxd":267
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_ULONGLONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Q;
      goto __pyx_L13;
    }

    /* "numpy.pxd":268
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_FLOAT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__f;
      goto __pyx_L13;
    }

    /* "numpy.pxd":269
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_DOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__d;
      goto __pyx_L13;
    }

    /* "numpy.pxd":270
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONGDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__g;
      goto __pyx_L13;
    }

    /* "numpy.pxd":271
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CFLOAT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zf;
      goto __pyx_L13;
    }

    /* "numpy.pxd":272
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zd;
      goto __pyx_L13;
    }

    /* "numpy.pxd":273
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CLONGDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zg;
      goto __pyx_L13;
    }

    /* "numpy.pxd":274
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
    __pyx_t_1 = (__pyx_v_t == NPY_OBJECT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__O;
      goto __pyx_L13;
    }
    /*else*/ {

      /* "numpy.pxd":276
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *                 info.format = f
 *                 return
 */
      __pyx_t_4 = PyInt_FromLong(__pyx_v_t); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_54), __pyx_t_4); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_8));
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_8));
      __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
      __pyx_t_8 = 0;
      __pyx_t_8 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L13:;

    /* "numpy.pxd":277
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
    __pyx_v_info->format = __pyx_v_f;

    /* "numpy.pxd":278
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L11;
  }
  /*else*/ {

    /* "numpy.pxd":280
 *                 return
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)             # <<<<<<<<<<<<<<
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 */
    __pyx_v_info->format = ((char *)malloc(255));

    /* "numpy.pxd":281
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment             # <<<<<<<<<<<<<<
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,
 */
    (__pyx_v_info->format[0]) = '^';

    /* "numpy.pxd":282
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0             # <<<<<<<<<<<<<<
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 */
    __pyx_v_offset = 0;

    /* "numpy.pxd":285
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)             # <<<<<<<<<<<<<<
 *                 f[0] = c'\0' # Terminate format string
 * 
 */
    __pyx_t_9 = __pyx_f_5numpy__util_dtypestring(__pyx_v_descr, (__pyx_v_info->format + 1), (__pyx_v_info->format + 255), (&__pyx_v_offset)); if (unlikely(__pyx_t_9 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_f = __pyx_t_9;

    /* "numpy.pxd":286
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 *                 f[0] = c'\0' # Terminate format string             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 */
    (__pyx_v_f[0]) = '\x00';
  }
  __pyx_L11:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.ndarray.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info != NULL && __pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = NULL;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info != NULL && __pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(Py_None);
    __Pyx_DECREF(Py_None); __pyx_v_info->obj = NULL;
  }
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_descr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_5numpy_7ndarray_2__releasebuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));
  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":288
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 */

static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);

  /* "numpy.pxd":289
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_t_1 = PyArray_HASFIELDS(__pyx_v_self);
  if (__pyx_t_1) {

    /* "numpy.pxd":290
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)             # <<<<<<<<<<<<<<
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)
 */
    free(__pyx_v_info->format);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "numpy.pxd":291
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  __pyx_t_1 = ((sizeof(npy_intp)) != (sizeof(Py_ssize_t)));
  if (__pyx_t_1) {

    /* "numpy.pxd":292
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)             # <<<<<<<<<<<<<<
 *                 # info.shape was stored after info.strides in the same block
 * 
 */
    free(__pyx_v_info->strides);
    goto __pyx_L4;
  }
  __pyx_L4:;

  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":768
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "numpy.pxd":769
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 769; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":771
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "numpy.pxd":772
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":774
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "numpy.pxd":775
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":777
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "numpy.pxd":778
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 778; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":780
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "numpy.pxd":781
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 781; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":783
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *__pyx_v_descr, char *__pyx_v_f, char *__pyx_v_end, int *__pyx_v_offset) {
  PyArray_Descr *__pyx_v_child = 0;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  PyObject *__pyx_v_fields = 0;
  PyObject *__pyx_v_childname = NULL;
  PyObject *__pyx_v_new_offset = NULL;
  PyObject *__pyx_v_t = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  long __pyx_t_11;
  char *__pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_util_dtypestring", 0);

  /* "numpy.pxd":790
 *     cdef int delta_offset
 *     cdef tuple i
 *     cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 *     cdef tuple fields
 */
  __pyx_v_endian_detector = 1;

  /* "numpy.pxd":791
 *     cdef tuple i
 *     cdef int endian_detector = 1
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 *     cdef tuple fields
 * 
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "numpy.pxd":794
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  if (unlikely(((PyObject *)__pyx_v_descr->names) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_descr->names); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_childname);
    __pyx_v_childname = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "numpy.pxd":795
 * 
 *     for childname in descr.names:
 *         fields = descr.fields[childname]             # <<<<<<<<<<<<<<
 *         child, new_offset = fields
 * 
 */
    __pyx_t_3 = PyObject_GetItem(__pyx_v_descr->fields, __pyx_v_childname); if (!__pyx_t_3) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(PyTuple_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_t_3)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF(((PyObject *)__pyx_v_fields));
    __pyx_v_fields = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "numpy.pxd":796
 *     for childname in descr.names:
 *         fields = descr.fields[childname]
 *         child, new_offset = fields             # <<<<<<<<<<<<<<
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 */
    if (likely(PyTuple_CheckExact(((PyObject *)__pyx_v_fields)))) {
      PyObject* sequence = ((PyObject *)__pyx_v_fields);
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      #endif
    } else if (1) {
      __Pyx_RaiseNoneNotIterableError(); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    } else
    {
      Py_ssize_t index = -1;
      __pyx_t_5 = PyObject_GetIter(((PyObject *)__pyx_v_fields)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_6 = NULL;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L6_unpacking_done:;
    }
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF(((PyObject *)__pyx_v_child));
    __pyx_v_child = ((PyArray_Descr *)__pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_v_new_offset);
    __pyx_v_new_offset = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "numpy.pxd":798
 *         child, new_offset = fields
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    __pyx_t_4 = PyInt_FromLong((__pyx_v_end - __pyx_v_f)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyInt_FromLong((__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Subtract(__pyx_v_new_offset, __pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Subtract(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_int_15, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "numpy.pxd":799
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
      __pyx_t_5 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_k_tuple_56), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }
    __pyx_L7:;

    /* "numpy.pxd":801
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_7 = (__pyx_v_child->byteorder == '>');
    if (__pyx_t_7) {
      __pyx_t_8 = __pyx_v_little_endian;
    } else {
      __pyx_t_8 = __pyx_t_7;
    }
    if (!__pyx_t_8) {

      /* "numpy.pxd":802
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *             raise ValueError(u"Non-native byte order not supported")
 *             # One could encode it in the format string and have Cython
 */
      __pyx_t_7 = (__pyx_v_child->byteorder == '<');
      if (__pyx_t_7) {
        __pyx_t_9 = (!__pyx_v_little_endian);
        __pyx_t_10 = __pyx_t_9;
      } else {
        __pyx_t_10 = __pyx_t_7;
      }
      __pyx_t_7 = __pyx_t_10;
    } else {
      __pyx_t_7 = __pyx_t_8;
    }
    if (__pyx_t_7) {

      /* "numpy.pxd":803
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
      __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_57), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "numpy.pxd":813
 * 
 *         # Output padding bytes
 *         while offset[0] < new_offset:             # <<<<<<<<<<<<<<
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 */
    while (1) {
      __pyx_t_5 = PyInt_FromLong((__pyx_v_offset[0])); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_v_new_offset, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!__pyx_t_7) break;

      /* "numpy.pxd":814
 *         # Output padding bytes
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte             # <<<<<<<<<<<<<<
 *             f += 1
 *             offset[0] += 1
 */
      (__pyx_v_f[0]) = 120;

      /* "numpy.pxd":815
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte
 *             f += 1             # <<<<<<<<<<<<<<
 *             offset[0] += 1
 * 
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "numpy.pxd":816
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 *             offset[0] += 1             # <<<<<<<<<<<<<<
 * 
 *         offset[0] += child.itemsize
 */
      __pyx_t_11 = 0;
      (__pyx_v_offset[__pyx_t_11]) = ((__pyx_v_offset[__pyx_t_11]) + 1);
    }

    /* "numpy.pxd":818
 *             offset[0] += 1
 * 
 *         offset[0] += child.itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not PyDataType_HASFIELDS(child):
 */
    __pyx_t_11 = 0;
    (__pyx_v_offset[__pyx_t_11]) = ((__pyx_v_offset[__pyx_t_11]) + __pyx_v_child->elsize);

    /* "numpy.pxd":820
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
    __pyx_t_7 = (!PyDataType_HASFIELDS(__pyx_v_child));
    if (__pyx_t_7) {

      /* "numpy.pxd":821
 * 
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num             # <<<<<<<<<<<<<<
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")
 */
      __pyx_t_3 = PyInt_FromLong(__pyx_v_child->type_num); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_v_t);
      __pyx_v_t = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "numpy.pxd":822
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      __pyx_t_7 = ((__pyx_v_end - __pyx_v_f) < 5);
      if (__pyx_t_7) {

        /* "numpy.pxd":823
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
        __pyx_t_3 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_k_tuple_59), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L12;
      }
      __pyx_L12:;

      /* "numpy.pxd":826
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_BYTE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 98;
        goto __pyx_L13;
      }

      /* "numpy.pxd":827
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"             # <<<<<<<<<<<<<<
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_UBYTE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 66;
        goto __pyx_L13;
      }

      /* "numpy.pxd":828
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"             # <<<<<<<<<<<<<<
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_SHORT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 104;
        goto __pyx_L13;
      }

      /* "numpy.pxd":829
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"             # <<<<<<<<<<<<<<
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_USHORT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 72;
        goto __pyx_L13;
      }

      /* "numpy.pxd":830
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_INT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 105;
        goto __pyx_L13;
      }

      /* "numpy.pxd":831
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_UINT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 73;
        goto __pyx_L13;
      }

      /* "numpy.pxd":832
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONG); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 108;
        goto __pyx_L13;
      }

      /* "numpy.pxd":833
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_ULONG); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 76;
        goto __pyx_L13;
      }

      /* "numpy.pxd":834
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONGLONG); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 113;
        goto __pyx_L13;
      }

      /* "numpy.pxd":835
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_ULONGLONG); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 81;
        goto __pyx_L13;
      }

      /* "numpy.pxd":836
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"             # <<<<<<<<<<<<<<
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_FLOAT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 102;
        goto __pyx_L13;
      }

      /* "numpy.pxd":837
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 */
      __pyx_t_5 = PyInt_FromLong(NPY_DOUBLE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 100;
        goto __pyx_L13;
      }

      /* "numpy.pxd":838
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"             # <<<<<<<<<<<<<<
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONGDOUBLE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 103;
        goto __pyx_L13;
      }

      /* "numpy.pxd":839
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf             # <<<<<<<<<<<<<<
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 */
      __pyx_t_5 = PyInt_FromLong(NPY_CFLOAT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 102;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L13;
      }

      /* "numpy.pxd":840
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd             # <<<<<<<<<<<<<<
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_CDOUBLE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 100;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L13;
      }

      /* "numpy.pxd":841
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg             # <<<<<<<<<<<<<<
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 */
      __pyx_t_5 = PyInt_FromLong(NPY_CLONGDOUBLE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 103;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L13;
      }

      /* "numpy.pxd":842
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      __pyx_t_3 = PyInt_FromLong(NPY_OBJECT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 79;
        goto __pyx_L13;
      }
      /*else*/ {

        /* "numpy.pxd":844
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *             f += 1
 *         else:
 */
        __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_54), __pyx_v_t); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_5));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L13:;

      /* "numpy.pxd":845
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *             f += 1             # <<<<<<<<<<<<<<
 *         else:
 *             # Cython ignores struct boundary information ("T{...}"),
 */
      __pyx_v_f = (__pyx_v_f + 1);
      goto __pyx_L11;
    }
    /*else*/ {

      /* "numpy.pxd":849
 *             # Cython ignores struct boundary information ("T{...}"),
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
      __pyx_t_12 = __pyx_f_5numpy__util_dtypestring(__pyx_v_child, __pyx_v_f, __pyx_v_end, __pyx_v_offset); if (unlikely(__pyx_t_12 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_f = __pyx_t_12;
    }
    __pyx_L11:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "numpy.pxd":850
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("numpy._util_dtypestring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_childname);
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":965
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  PyObject *__pyx_v_baseptr;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "numpy.pxd":967
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
  __pyx_t_1 = (__pyx_v_base == Py_None);
  if (__pyx_t_1) {

    /* "numpy.pxd":968
 *      cdef PyObject* baseptr
 *      if base is None:
 *          baseptr = NULL             # <<<<<<<<<<<<<<
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 */
    __pyx_v_baseptr = NULL;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "numpy.pxd":970
 *          baseptr = NULL
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!             # <<<<<<<<<<<<<<
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 */
    Py_INCREF(__pyx_v_base);

    /* "numpy.pxd":971
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base             # <<<<<<<<<<<<<<
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr
 */
    __pyx_v_baseptr = ((PyObject *)__pyx_v_base);
  }
  __pyx_L3:;

  /* "numpy.pxd":972
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)             # <<<<<<<<<<<<<<
 *      arr.base = baseptr
 * 
 */
  Py_XDECREF(__pyx_v_arr->base);

  /* "numpy.pxd":973
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_v_arr->base = __pyx_v_baseptr;

  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":975
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "numpy.pxd":976
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  __pyx_t_1 = (__pyx_v_arr->base == NULL);
  if (__pyx_t_1) {

    /* "numpy.pxd":977
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     else:
 *         return <object>arr.base
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "numpy.pxd":979
 *         return None
 *     else:
 *         return <object>arr.base             # <<<<<<<<<<<<<<
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_arr->base));
    __pyx_r = ((PyObject *)__pyx_v_arr->base);
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_10javabridge_11_javabridge_JB_Object(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)o);
  p->env = Py_None; Py_INCREF(Py_None);
  p->gc_collect = Py_None; Py_INCREF(Py_None);
  if (__pyx_pw_10javabridge_11_javabridge_9JB_Object_1__cinit__(o, __pyx_empty_tuple, NULL) < 0) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10javabridge_11_javabridge_JB_Object(PyObject *o) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *p = (struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)o;
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_10javabridge_11_javabridge_9JB_Object_5__dealloc__(o);
    if (PyErr_Occurred()) PyErr_WriteUnraisable(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->env);
  Py_CLEAR(p->gc_collect);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_10javabridge_11_javabridge_JB_Object(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *p = (struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)o;
  if (p->env) {
    e = (*v)(p->env, a); if (e) return e;
  }
  if (p->gc_collect) {
    e = (*v)(p->gc_collect, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10javabridge_11_javabridge_JB_Object(PyObject *o) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Object *p = (struct __pyx_obj_10javabridge_11_javabridge_JB_Object *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->env);
  p->env = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->gc_collect);
  p->gc_collect = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_10javabridge_11_javabridge_JB_Object[] = {
  {__Pyx_NAMESTR("addr"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_9JB_Object_7addr, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_9JB_Object_6addr)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_JB_Object = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_JB_Object = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_JB_Object = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_JB_Object = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_10javabridge_11_javabridge_JB_Object = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("javabridge._javabridge.JB_Object"), /*tp_name*/
  sizeof(struct __pyx_obj_10javabridge_11_javabridge_JB_Object), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10javabridge_11_javabridge_JB_Object, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_10javabridge_11_javabridge_9JB_Object_3__repr__, /*tp_repr*/
  &__pyx_tp_as_number_JB_Object, /*tp_as_number*/
  &__pyx_tp_as_sequence_JB_Object, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_JB_Object, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_JB_Object, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("A Java object"), /*tp_doc*/
  __pyx_tp_traverse_10javabridge_11_javabridge_JB_Object, /*tp_traverse*/
  __pyx_tp_clear_10javabridge_11_javabridge_JB_Object, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_10javabridge_11_javabridge_JB_Object, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10javabridge_11_javabridge_JB_Object, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_10javabridge_11_javabridge_JB_Class(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  if (__pyx_pw_10javabridge_11_javabridge_8JB_Class_1__cinit__(o, __pyx_empty_tuple, NULL) < 0) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10javabridge_11_javabridge_JB_Class(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_10javabridge_11_javabridge_JB_Class[] = {
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_JB_Class = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_JB_Class = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_JB_Class = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_JB_Class = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_10javabridge_11_javabridge_JB_Class = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("javabridge._javabridge.JB_Class"), /*tp_name*/
  sizeof(struct __pyx_obj_10javabridge_11_javabridge_JB_Class), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10javabridge_11_javabridge_JB_Class, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_10javabridge_11_javabridge_8JB_Class_3__repr__, /*tp_repr*/
  &__pyx_tp_as_number_JB_Class, /*tp_as_number*/
  &__pyx_tp_as_sequence_JB_Class, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_JB_Class, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_JB_Class, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("A Java class"), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_10javabridge_11_javabridge_JB_Class, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10javabridge_11_javabridge_JB_Class, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_10javabridge_11_javabridge___JB_MethodID(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)o);
  p->sig = Py_None; Py_INCREF(Py_None);
  p->is_static = Py_None; Py_INCREF(Py_None);
  if (__pyx_pw_10javabridge_11_javabridge_13__JB_MethodID_1__cinit__(o, __pyx_empty_tuple, NULL) < 0) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10javabridge_11_javabridge___JB_MethodID(PyObject *o) {
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *p = (struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->sig);
  Py_CLEAR(p->is_static);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_10javabridge_11_javabridge___JB_MethodID(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *p = (struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)o;
  if (p->sig) {
    e = (*v)(p->sig, a); if (e) return e;
  }
  if (p->is_static) {
    e = (*v)(p->is_static, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10javabridge_11_javabridge___JB_MethodID(PyObject *o) {
  struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *p = (struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->sig);
  p->sig = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->is_static);
  p->is_static = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_10javabridge_11_javabridge___JB_MethodID[] = {
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number___JB_MethodID = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence___JB_MethodID = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping___JB_MethodID = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer___JB_MethodID = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_10javabridge_11_javabridge___JB_MethodID = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("javabridge._javabridge.__JB_MethodID"), /*tp_name*/
  sizeof(struct __pyx_obj_10javabridge_11_javabridge___JB_MethodID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10javabridge_11_javabridge___JB_MethodID, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_10javabridge_11_javabridge_13__JB_MethodID_3__repr__, /*tp_repr*/
  &__pyx_tp_as_number___JB_MethodID, /*tp_as_number*/
  &__pyx_tp_as_sequence___JB_MethodID, /*tp_as_sequence*/
  &__pyx_tp_as_mapping___JB_MethodID, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer___JB_MethodID, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("A method ID as returned by get_method_id"), /*tp_doc*/
  __pyx_tp_traverse_10javabridge_11_javabridge___JB_MethodID, /*tp_traverse*/
  __pyx_tp_clear_10javabridge_11_javabridge___JB_MethodID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_10javabridge_11_javabridge___JB_MethodID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10javabridge_11_javabridge___JB_MethodID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_10javabridge_11_javabridge___JB_FieldID(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)o);
  p->sig = Py_None; Py_INCREF(Py_None);
  p->is_static = Py_None; Py_INCREF(Py_None);
  if (__pyx_pw_10javabridge_11_javabridge_12__JB_FieldID_1__cinit__(o, __pyx_empty_tuple, NULL) < 0) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10javabridge_11_javabridge___JB_FieldID(PyObject *o) {
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *p = (struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->sig);
  Py_CLEAR(p->is_static);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_10javabridge_11_javabridge___JB_FieldID(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *p = (struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)o;
  if (p->sig) {
    e = (*v)(p->sig, a); if (e) return e;
  }
  if (p->is_static) {
    e = (*v)(p->is_static, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10javabridge_11_javabridge___JB_FieldID(PyObject *o) {
  struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *p = (struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->sig);
  p->sig = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->is_static);
  p->is_static = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_10javabridge_11_javabridge___JB_FieldID[] = {
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number___JB_FieldID = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence___JB_FieldID = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping___JB_FieldID = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer___JB_FieldID = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_10javabridge_11_javabridge___JB_FieldID = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("javabridge._javabridge.__JB_FieldID"), /*tp_name*/
  sizeof(struct __pyx_obj_10javabridge_11_javabridge___JB_FieldID), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10javabridge_11_javabridge___JB_FieldID, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_10javabridge_11_javabridge_12__JB_FieldID_3__repr__, /*tp_repr*/
  &__pyx_tp_as_number___JB_FieldID, /*tp_as_number*/
  &__pyx_tp_as_sequence___JB_FieldID, /*tp_as_sequence*/
  &__pyx_tp_as_mapping___JB_FieldID, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer___JB_FieldID, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("A field ID as returned by get_field_id"), /*tp_doc*/
  __pyx_tp_traverse_10javabridge_11_javabridge___JB_FieldID, /*tp_traverse*/
  __pyx_tp_clear_10javabridge_11_javabridge___JB_FieldID, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_10javabridge_11_javabridge___JB_FieldID, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10javabridge_11_javabridge___JB_FieldID, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_10javabridge_11_javabridge_JB_VM(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  return o;
}

static void __pyx_tp_dealloc_10javabridge_11_javabridge_JB_VM(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_10javabridge_11_javabridge_JB_VM[] = {
  {__Pyx_NAMESTR("create"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_5JB_VM_1create, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_5JB_VM_create)},
  {__Pyx_NAMESTR("create_mac"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_5JB_VM_3create_mac, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_5JB_VM_2create_mac)},
  {__Pyx_NAMESTR("attach"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_5JB_VM_5attach, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_5JB_VM_4attach)},
  {__Pyx_NAMESTR("attach_as_daemon"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_5JB_VM_7attach_as_daemon, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_5JB_VM_6attach_as_daemon)},
  {__Pyx_NAMESTR("detach"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_5JB_VM_9detach, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_5JB_VM_8detach)},
  {__Pyx_NAMESTR("destroy"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_5JB_VM_11destroy, METH_NOARGS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_JB_VM = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_JB_VM = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_JB_VM = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_JB_VM = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_10javabridge_11_javabridge_JB_VM = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("javabridge._javabridge.JB_VM"), /*tp_name*/
  sizeof(struct __pyx_obj_10javabridge_11_javabridge_JB_VM), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10javabridge_11_javabridge_JB_VM, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_JB_VM, /*tp_as_number*/
  &__pyx_tp_as_sequence_JB_VM, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_JB_VM, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_JB_VM, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("Represents the Java virtual machine"), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_10javabridge_11_javabridge_JB_VM, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10javabridge_11_javabridge_JB_VM, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_10javabridge_11_javabridge_JB_Env(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Env *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)o);
  p->defer_fn = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_10javabridge_11_javabridge_JB_Env(PyObject *o) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Env *p = (struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)o;
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_10javabridge_11_javabridge_6JB_Env_7__dealloc__(o);
    if (PyErr_Occurred()) PyErr_WriteUnraisable(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->defer_fn);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_10javabridge_11_javabridge_JB_Env(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10javabridge_11_javabridge_JB_Env *p = (struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)o;
  if (p->defer_fn) {
    e = (*v)(p->defer_fn, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10javabridge_11_javabridge_JB_Env(PyObject *o) {
  struct __pyx_obj_10javabridge_11_javabridge_JB_Env *p = (struct __pyx_obj_10javabridge_11_javabridge_JB_Env *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->defer_fn);
  p->defer_fn = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_10javabridge_11_javabridge_JB_Env[] = {
  {__Pyx_NAMESTR("set_env"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_5set_env, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_4set_env)},
  {__Pyx_NAMESTR("set_defer_fn"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_9set_defer_fn, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_8set_defer_fn)},
  {__Pyx_NAMESTR("dealloc_jobject"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_11dealloc_jobject, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_10dealloc_jobject)},
  {__Pyx_NAMESTR("get_version"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_13get_version, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_12get_version)},
  {__Pyx_NAMESTR("find_class"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_15find_class, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_14find_class)},
  {__Pyx_NAMESTR("get_object_class"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_17get_object_class, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_16get_object_class)},
  {__Pyx_NAMESTR("is_instance_of"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_19is_instance_of, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_18is_instance_of)},
  {__Pyx_NAMESTR("exception_occurred"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_21exception_occurred, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_20exception_occurred)},
  {__Pyx_NAMESTR("exception_describe"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_23exception_describe, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_22exception_describe)},
  {__Pyx_NAMESTR("exception_clear"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_25exception_clear, METH_NOARGS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_24exception_clear)},
  {__Pyx_NAMESTR("get_method_id"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_27get_method_id, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_26get_method_id)},
  {__Pyx_NAMESTR("get_static_method_id"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_29get_static_method_id, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_28get_static_method_id)},
  {__Pyx_NAMESTR("from_reflected_method"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_31from_reflected_method, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_30from_reflected_method)},
  {__Pyx_NAMESTR("call_method"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_33call_method, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_32call_method)},
  {__Pyx_NAMESTR("call_static_method"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_35call_static_method, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_34call_static_method)},
  {__Pyx_NAMESTR("get_field_id"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_37get_field_id, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_36get_field_id)},
  {__Pyx_NAMESTR("get_object_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_39get_object_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_38get_object_field)},
  {__Pyx_NAMESTR("get_boolean_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_41get_boolean_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_40get_boolean_field)},
  {__Pyx_NAMESTR("get_byte_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_43get_byte_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_42get_byte_field)},
  {__Pyx_NAMESTR("get_short_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_45get_short_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_44get_short_field)},
  {__Pyx_NAMESTR("get_int_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_47get_int_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_46get_int_field)},
  {__Pyx_NAMESTR("get_long_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_49get_long_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_48get_long_field)},
  {__Pyx_NAMESTR("get_float_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_51get_float_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_50get_float_field)},
  {__Pyx_NAMESTR("get_double_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_53get_double_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_52get_double_field)},
  {__Pyx_NAMESTR("set_object_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_55set_object_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_54set_object_field)},
  {__Pyx_NAMESTR("set_boolean_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_57set_boolean_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_56set_boolean_field)},
  {__Pyx_NAMESTR("set_byte_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_59set_byte_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_58set_byte_field)},
  {__Pyx_NAMESTR("set_char_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_61set_char_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_60set_char_field)},
  {__Pyx_NAMESTR("set_short_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_63set_short_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_62set_short_field)},
  {__Pyx_NAMESTR("set_int_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_65set_int_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_64set_int_field)},
  {__Pyx_NAMESTR("set_long_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_67set_long_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_66set_long_field)},
  {__Pyx_NAMESTR("set_float_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_69set_float_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_68set_float_field)},
  {__Pyx_NAMESTR("set_double_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_71set_double_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_70set_double_field)},
  {__Pyx_NAMESTR("get_static_field_id"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_73get_static_field_id, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_72get_static_field_id)},
  {__Pyx_NAMESTR("get_static_object_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_75get_static_object_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_74get_static_object_field)},
  {__Pyx_NAMESTR("get_static_boolean_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_77get_static_boolean_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_76get_static_boolean_field)},
  {__Pyx_NAMESTR("get_static_byte_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_79get_static_byte_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_78get_static_byte_field)},
  {__Pyx_NAMESTR("get_static_short_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_81get_static_short_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_80get_static_short_field)},
  {__Pyx_NAMESTR("get_static_int_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_83get_static_int_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_82get_static_int_field)},
  {__Pyx_NAMESTR("get_static_long_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_85get_static_long_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_84get_static_long_field)},
  {__Pyx_NAMESTR("get_static_float_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_87get_static_float_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_86get_static_float_field)},
  {__Pyx_NAMESTR("get_static_double_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_89get_static_double_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_88get_static_double_field)},
  {__Pyx_NAMESTR("set_static_object_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_91set_static_object_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_90set_static_object_field)},
  {__Pyx_NAMESTR("set_static_boolean_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_93set_static_boolean_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_92set_static_boolean_field)},
  {__Pyx_NAMESTR("set_static_byte_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_95set_static_byte_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_94set_static_byte_field)},
  {__Pyx_NAMESTR("set_static_char_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_97set_static_char_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_96set_static_char_field)},
  {__Pyx_NAMESTR("set_static_short_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_99set_static_short_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_98set_static_short_field)},
  {__Pyx_NAMESTR("set_static_int_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_101set_static_int_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_100set_static_int_field)},
  {__Pyx_NAMESTR("set_static_long_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_103set_static_long_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_102set_static_long_field)},
  {__Pyx_NAMESTR("set_static_float_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_105set_static_float_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_104set_static_float_field)},
  {__Pyx_NAMESTR("set_static_double_field"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_107set_static_double_field, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_106set_static_double_field)},
  {__Pyx_NAMESTR("new_object"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_109new_object, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_108new_object)},
  {__Pyx_NAMESTR("new_string_utf"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_111new_string_utf, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_110new_string_utf)},
  {__Pyx_NAMESTR("get_string_utf"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_113get_string_utf, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_112get_string_utf)},
  {__Pyx_NAMESTR("get_array_length"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_115get_array_length, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_114get_array_length)},
  {__Pyx_NAMESTR("get_boolean_array_elements"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_117get_boolean_array_elements, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_116get_boolean_array_elements)},
  {__Pyx_NAMESTR("get_byte_array_elements"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_119get_byte_array_elements, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_118get_byte_array_elements)},
  {__Pyx_NAMESTR("get_short_array_elements"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_121get_short_array_elements, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_120get_short_array_elements)},
  {__Pyx_NAMESTR("get_int_array_elements"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_123get_int_array_elements, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_122get_int_array_elements)},
  {__Pyx_NAMESTR("get_long_array_elements"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_125get_long_array_elements, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_124get_long_array_elements)},
  {__Pyx_NAMESTR("get_float_array_elements"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_127get_float_array_elements, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_126get_float_array_elements)},
  {__Pyx_NAMESTR("get_double_array_elements"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_129get_double_array_elements, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_128get_double_array_elements)},
  {__Pyx_NAMESTR("get_object_array_elements"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_131get_object_array_elements, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_130get_object_array_elements)},
  {__Pyx_NAMESTR("make_boolean_array"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_133make_boolean_array, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_132make_boolean_array)},
  {__Pyx_NAMESTR("make_byte_array"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_135make_byte_array, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_134make_byte_array)},
  {__Pyx_NAMESTR("make_short_array"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_137make_short_array, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_136make_short_array)},
  {__Pyx_NAMESTR("make_int_array"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_139make_int_array, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_138make_int_array)},
  {__Pyx_NAMESTR("make_long_array"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_141make_long_array, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_140make_long_array)},
  {__Pyx_NAMESTR("make_float_array"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_143make_float_array, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_142make_float_array)},
  {__Pyx_NAMESTR("make_double_array"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_145make_double_array, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_144make_double_array)},
  {__Pyx_NAMESTR("make_object_array"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_147make_object_array, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_146make_object_array)},
  {__Pyx_NAMESTR("set_object_array_element"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_149set_object_array_element, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_148set_object_array_element)},
  {__Pyx_NAMESTR("make_jb_object"), (PyCFunction)__pyx_pw_10javabridge_11_javabridge_6JB_Env_151make_jb_object, METH_O, __Pyx_DOCSTR(__pyx_doc_10javabridge_11_javabridge_6JB_Env_150make_jb_object)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_JB_Env = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_JB_Env = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_JB_Env = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_JB_Env = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_10javabridge_11_javabridge_JB_Env = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("javabridge._javabridge.JB_Env"), /*tp_name*/
  sizeof(struct __pyx_obj_10javabridge_11_javabridge_JB_Env), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10javabridge_11_javabridge_JB_Env, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_10javabridge_11_javabridge_6JB_Env_3__repr__, /*tp_repr*/
  &__pyx_tp_as_number_JB_Env, /*tp_as_number*/
  &__pyx_tp_as_sequence_JB_Env, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_JB_Env, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_JB_Env, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("Represents the Java VM and the Java execution environment"), /*tp_doc*/
  __pyx_tp_traverse_10javabridge_11_javabridge_JB_Env, /*tp_traverse*/
  __pyx_tp_clear_10javabridge_11_javabridge_JB_Env, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_10javabridge_11_javabridge_JB_Env, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_10javabridge_11_javabridge_6JB_Env_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10javabridge_11_javabridge_JB_Env, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    __Pyx_NAMESTR("_javabridge"),
    __Pyx_DOCSTR(__pyx_k_60), /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 0},
  {&__pyx_kp_s_10, __pyx_k_10, sizeof(__pyx_k_10), 0, 0, 1, 0},
  {&__pyx_kp_s_12, __pyx_k_12, sizeof(__pyx_k_12), 0, 0, 1, 0},
  {&__pyx_kp_s_13, __pyx_k_13, sizeof(__pyx_k_13), 0, 0, 1, 0},
  {&__pyx_kp_s_14, __pyx_k_14, sizeof(__pyx_k_14), 0, 0, 1, 0},
  {&__pyx_kp_s_16, __pyx_k_16, sizeof(__pyx_k_16), 0, 0, 1, 0},
  {&__pyx_kp_s_18, __pyx_k_18, sizeof(__pyx_k_18), 0, 0, 1, 0},
  {&__pyx_kp_s_19, __pyx_k_19, sizeof(__pyx_k_19), 0, 0, 1, 0},
  {&__pyx_kp_s_2, __pyx_k_2, sizeof(__pyx_k_2), 0, 0, 1, 0},
  {&__pyx_kp_s_20, __pyx_k_20, sizeof(__pyx_k_20), 0, 0, 1, 0},
  {&__pyx_kp_s_21, __pyx_k_21, sizeof(__pyx_k_21), 0, 0, 1, 0},
  {&__pyx_kp_s_23, __pyx_k_23, sizeof(__pyx_k_23), 0, 0, 1, 0},
  {&__pyx_kp_s_25, __pyx_k_25, sizeof(__pyx_k_25), 0, 0, 1, 0},
  {&__pyx_kp_s_27, __pyx_k_27, sizeof(__pyx_k_27), 0, 0, 1, 0},
  {&__pyx_kp_s_28, __pyx_k_28, sizeof(__pyx_k_28), 0, 0, 1, 0},
  {&__pyx_kp_s_29, __pyx_k_29, sizeof(__pyx_k_29), 0, 0, 1, 0},
  {&__pyx_kp_s_3, __pyx_k_3, sizeof(__pyx_k_3), 0, 0, 1, 0},
  {&__pyx_kp_s_31, __pyx_k_31, sizeof(__pyx_k_31), 0, 0, 1, 0},
  {&__pyx_kp_s_33, __pyx_k_33, sizeof(__pyx_k_33), 0, 0, 1, 0},
  {&__pyx_kp_s_37, __pyx_k_37, sizeof(__pyx_k_37), 0, 0, 1, 0},
  {&__pyx_kp_s_39, __pyx_k_39, sizeof(__pyx_k_39), 0, 0, 1, 0},
  {&__pyx_kp_s_4, __pyx_k_4, sizeof(__pyx_k_4), 0, 0, 1, 0},
  {&__pyx_kp_s_40, __pyx_k_40, sizeof(__pyx_k_40), 0, 0, 1, 0},
  {&__pyx_kp_s_41, __pyx_k_41, sizeof(__pyx_k_41), 0, 0, 1, 0},
  {&__pyx_kp_s_42, __pyx_k_42, sizeof(__pyx_k_42), 0, 0, 1, 0},
  {&__pyx_kp_s_43, __pyx_k_43, sizeof(__pyx_k_43), 0, 0, 1, 0},
  {&__pyx_kp_s_44, __pyx_k_44, sizeof(__pyx_k_44), 0, 0, 1, 0},
  {&__pyx_kp_s_45, __pyx_k_45, sizeof(__pyx_k_45), 0, 0, 1, 0},
  {&__pyx_kp_s_46, __pyx_k_46, sizeof(__pyx_k_46), 0, 0, 1, 0},
  {&__pyx_kp_u_48, __pyx_k_48, sizeof(__pyx_k_48), 0, 1, 0, 0},
  {&__pyx_kp_s_5, __pyx_k_5, sizeof(__pyx_k_5), 0, 0, 1, 0},
  {&__pyx_kp_u_50, __pyx_k_50, sizeof(__pyx_k_50), 0, 1, 0, 0},
  {&__pyx_kp_u_52, __pyx_k_52, sizeof(__pyx_k_52), 0, 1, 0, 0},
  {&__pyx_kp_u_54, __pyx_k_54, sizeof(__pyx_k_54), 0, 1, 0, 0},
  {&__pyx_kp_u_55, __pyx_k_55, sizeof(__pyx_k_55), 0, 1, 0, 0},
  {&__pyx_kp_u_58, __pyx_k_58, sizeof(__pyx_k_58), 0, 1, 0, 0},
  {&__pyx_kp_s_6, __pyx_k_6, sizeof(__pyx_k_6), 0, 0, 1, 0},
  {&__pyx_n_s_63, __pyx_k_63, sizeof(__pyx_k_63), 0, 0, 1, 1},
  {&__pyx_kp_s_64, __pyx_k_64, sizeof(__pyx_k_64), 0, 0, 1, 0},
  {&__pyx_n_s_65, __pyx_k_65, sizeof(__pyx_k_65), 0, 0, 1, 1},
  {&__pyx_kp_s_7, __pyx_k_7, sizeof(__pyx_k_7), 0, 0, 1, 0},
  {&__pyx_kp_s_8, __pyx_k_8, sizeof(__pyx_k_8), 0, 0, 1, 0},
  {&__pyx_kp_s_9, __pyx_k_9, sizeof(__pyx_k_9), 0, 0, 1, 0},
  {&__pyx_n_s__B, __pyx_k__B, sizeof(__pyx_k__B), 0, 0, 1, 1},
  {&__pyx_n_s__C, __pyx_k__C, sizeof(__pyx_k__C), 0, 0, 1, 1},
  {&__pyx_n_s__D, __pyx_k__D, sizeof(__pyx_k__D), 0, 0, 1, 1},
  {&__pyx_n_s__F, __pyx_k__F, sizeof(__pyx_k__F), 0, 0, 1, 1},
  {&__pyx_n_s__I, __pyx_k__I, sizeof(__pyx_k__I), 0, 0, 1, 1},
  {&__pyx_n_s__J, __pyx_k__J, sizeof(__pyx_k__J), 0, 0, 1, 1},
  {&__pyx_n_s__L, __pyx_k__L, sizeof(__pyx_k__L), 0, 0, 1, 1},
  {&__pyx_n_s__MemoryError, __pyx_k__MemoryError, sizeof(__pyx_k__MemoryError), 0, 0, 1, 1},
  {&__pyx_n_s__RuntimeError, __pyx_k__RuntimeError, sizeof(__pyx_k__RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s__S, __pyx_k__S, sizeof(__pyx_k__S), 0, 0, 1, 1},
  {&__pyx_n_s__V, __pyx_k__V, sizeof(__pyx_k__V), 0, 0, 1, 1},
  {&__pyx_n_s__ValueError, __pyx_k__ValueError, sizeof(__pyx_k__ValueError), 0, 0, 1, 1},
  {&__pyx_n_s__Z, __pyx_k__Z, sizeof(__pyx_k__Z), 0, 0, 1, 1},
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {&__pyx_n_s__args, __pyx_k__args, sizeof(__pyx_k__args), 0, 0, 1, 1},
  {&__pyx_n_s__astype, __pyx_k__astype, sizeof(__pyx_k__astype), 0, 0, 1, 1},
  {&__pyx_n_s__bool8, __pyx_k__bool8, sizeof(__pyx_k__bool8), 0, 0, 1, 1},
  {&__pyx_n_s__c, __pyx_k__c, sizeof(__pyx_k__c), 0, 0, 1, 1},
  {&__pyx_n_s__class_name, __pyx_k__class_name, sizeof(__pyx_k__class_name), 0, 0, 1, 1},
  {&__pyx_n_s__dealloc_jobject, __pyx_k__dealloc_jobject, sizeof(__pyx_k__dealloc_jobject), 0, 0, 1, 1},
  {&__pyx_n_s__dtype, __pyx_k__dtype, sizeof(__pyx_k__dtype), 0, 0, 1, 1},
  {&__pyx_n_s__enumerate, __pyx_k__enumerate, sizeof(__pyx_k__enumerate), 0, 0, 1, 1},
  {&__pyx_n_s__field, __pyx_k__field, sizeof(__pyx_k__field), 0, 0, 1, 1},
  {&__pyx_n_s__find, __pyx_k__find, sizeof(__pyx_k__find), 0, 0, 1, 1},
  {&__pyx_n_s__float32, __pyx_k__float32, sizeof(__pyx_k__float32), 0, 0, 1, 1},
  {&__pyx_n_s__float64, __pyx_k__float64, sizeof(__pyx_k__float64), 0, 0, 1, 1},
  {&__pyx_n_s__i, __pyx_k__i, sizeof(__pyx_k__i), 0, 0, 1, 1},
  {&__pyx_n_s__index, __pyx_k__index, sizeof(__pyx_k__index), 0, 0, 1, 1},
  {&__pyx_n_s__int16, __pyx_k__int16, sizeof(__pyx_k__int16), 0, 0, 1, 1},
  {&__pyx_n_s__int32, __pyx_k__int32, sizeof(__pyx_k__int32), 0, 0, 1, 1},
  {&__pyx_n_s__int64, __pyx_k__int64, sizeof(__pyx_k__int64), 0, 0, 1, 1},
  {&__pyx_n_s__is_static, __pyx_k__is_static, sizeof(__pyx_k__is_static), 0, 0, 1, 1},
  {&__pyx_n_s__jbo, __pyx_k__jbo, sizeof(__pyx_k__jbo), 0, 0, 1, 1},
  {&__pyx_n_s__klass, __pyx_k__klass, sizeof(__pyx_k__klass), 0, 0, 1, 1},
  {&__pyx_n_s__len, __pyx_k__len, sizeof(__pyx_k__len), 0, 0, 1, 1},
  {&__pyx_n_s__m, __pyx_k__m, sizeof(__pyx_k__m), 0, 0, 1, 1},
  {&__pyx_n_s__method, __pyx_k__method, sizeof(__pyx_k__method), 0, 0, 1, 1},
  {&__pyx_n_s__name, __pyx_k__name, sizeof(__pyx_k__name), 0, 0, 1, 1},
  {&__pyx_n_s__np, __pyx_k__np, sizeof(__pyx_k__np), 0, 0, 1, 1},
  {&__pyx_n_s__numpy, __pyx_k__numpy, sizeof(__pyx_k__numpy), 0, 0, 1, 1},
  {&__pyx_n_s__o, __pyx_k__o, sizeof(__pyx_k__o), 0, 0, 1, 1},
  {&__pyx_n_s__options, __pyx_k__options, sizeof(__pyx_k__options), 0, 0, 1, 1},
  {&__pyx_n_s__range, __pyx_k__range, sizeof(__pyx_k__range), 0, 0, 1, 1},
  {&__pyx_n_s__result, __pyx_k__result, sizeof(__pyx_k__result), 0, 0, 1, 1},
  {&__pyx_n_s__shape, __pyx_k__shape, sizeof(__pyx_k__shape), 0, 0, 1, 1},
  {&__pyx_n_s__sig, __pyx_k__sig, sizeof(__pyx_k__sig), 0, 0, 1, 1},
  {&__pyx_n_s__sys, __pyx_k__sys, sizeof(__pyx_k__sys), 0, 0, 1, 1},
  {&__pyx_n_s__uint8, __pyx_k__uint8, sizeof(__pyx_k__uint8), 0, 0, 1, 1},
  {&__pyx_n_s__unichr, __pyx_k__unichr, sizeof(__pyx_k__unichr), 0, 0, 1, 1},
  {&__pyx_n_s__v, __pyx_k__v, sizeof(__pyx_k__v), 0, 0, 1, 1},
  {&__pyx_n_s__value, __pyx_k__value, sizeof(__pyx_k__value), 0, 0, 1, 1},
  {&__pyx_n_s__zeros, __pyx_k__zeros, sizeof(__pyx_k__zeros), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetName(__pyx_b, __pyx_n_s__range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_enumerate = __Pyx_GetName(__pyx_b, __pyx_n_s__enumerate); if (!__pyx_builtin_enumerate) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_ValueError = __Pyx_GetName(__pyx_b, __pyx_n_s__ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_MemoryError = __Pyx_GetName(__pyx_b, __pyx_n_s__MemoryError); if (!__pyx_builtin_MemoryError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 463; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_RuntimeError = __Pyx_GetName(__pyx_b, __pyx_n_s__RuntimeError); if (!__pyx_builtin_RuntimeError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_unichr = __Pyx_GetName(__pyx_b, __pyx_n_s__unichr); if (!__pyx_builtin_unichr) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 763; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "javabridge/_javabridge.pyx":441
 *                      sig = sig[2:]
 *                      continue
 *             sig = sig[sig.find(';')+1:]             # <<<<<<<<<<<<<<
 *         else:
 *             return ValueError("Unhandled signature: %s"%orig_sig)
 */
  __pyx_k_tuple_11 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_10)); if (unlikely(!__pyx_k_tuple_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_11);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_11));

  /* "javabridge/_javabridge.pyx":463
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")             # <<<<<<<<<<<<<<
 *         options = [str(option) for option in options]
 *         for i, option in enumerate(options):
 */
  __pyx_k_tuple_15 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_14)); if (unlikely(!__pyx_k_tuple_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 463; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_15);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_15));

  /* "javabridge/_javabridge.pyx":504
 *         args.options = <JavaVMOption *>malloc(sizeof(JavaVMOption)*args.nOptions)
 *         if args.options == NULL:
 *             raise MemoryError("Failed to allocate JavaVMInitArgs")             # <<<<<<<<<<<<<<
 *         options = [str(option) for option in options]
 *         for i, option in enumerate(options):
 */
  __pyx_k_tuple_17 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_14)); if (unlikely(!__pyx_k_tuple_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_17);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_17));

  /* "javabridge/_javabridge.pyx":674
 *             __JB_MethodID result
 *         if c is None:
 *             raise ValueError("Class = None on call to get_method_id")             # <<<<<<<<<<<<<<
 *         id = self.env[0].GetMethodID(self.env, c.c, name, sig)
 *         if id == NULL:
 */
  __pyx_k_tuple_22 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_21)); if (unlikely(!__pyx_k_tuple_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 674; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_22);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_22));

  /* "javabridge/_javabridge.pyx":740
 * 
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")             # <<<<<<<<<<<<<<
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use call_static_method instead")
 */
  __pyx_k_tuple_24 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_23)); if (unlikely(!__pyx_k_tuple_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 740; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_24);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_24));

  /* "javabridge/_javabridge.pyx":742
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if m.is_static:
 *             raise ValueError("call_method called with a static method. Use call_static_method instead")             # <<<<<<<<<<<<<<
 *         sig = m.sig
 *         if sig[0] != '(':
 */
  __pyx_k_tuple_26 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_25)); if (unlikely(!__pyx_k_tuple_26)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_26);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_26));

  /* "javabridge/_javabridge.pyx":746
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_k_tuple_30 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_29)); if (unlikely(!__pyx_k_tuple_30)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 746; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_30);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_30));

  /* "javabridge/_javabridge.pyx":805
 * 
 *         if m is None:
 *             raise ValueError("Method ID is None - check your method ID call")             # <<<<<<<<<<<<<<
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")
 */
  __pyx_k_tuple_32 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_23)); if (unlikely(!__pyx_k_tuple_32)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_32);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_32));

  /* "javabridge/_javabridge.pyx":807
 *             raise ValueError("Method ID is None - check your method ID call")
 *         if not m.is_static:
 *             raise ValueError("static_call_method called with an object method. Use call_method instead")             # <<<<<<<<<<<<<<
 *         sig = m.sig
 *         if sig[0] != '(':
 */
  __pyx_k_tuple_34 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_33)); if (unlikely(!__pyx_k_tuple_34)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_34);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_34));

  /* "javabridge/_javabridge.pyx":811
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_k_tuple_35 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_29)); if (unlikely(!__pyx_k_tuple_35)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_35);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_35));

  /* "javabridge/_javabridge.pyx":1182
 *         if sig[0] != '(':
 *             raise ValueError("Bad function signature: %s"%m.sig)
 *         arg_end = sig.find(')')             # <<<<<<<<<<<<<<
 *         if arg_end == -1:
 *             raise ValueError("Bad function signature: %s"%m.sig)
 */
  __pyx_k_tuple_36 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_29)); if (unlikely(!__pyx_k_tuple_36)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_36);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_36));

  /* "javabridge/_javabridge.pyx":1204
 *         o = self.env[0].NewStringUTF(self.env, s)
 *         if o == NULL:
 *             raise MemoryError("Failed to allocate string")             # <<<<<<<<<<<<<<
 *         jbo, e = make_jb_object(self, o)
 *         if e is not None:
 */
  __pyx_k_tuple_38 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_37)); if (unlikely(!__pyx_k_tuple_38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_38);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_38));

  /* "javabridge/_javabridge.pyx":1519
 *     oref = env.env[0].NewGlobalRef(env.env, o)
 *     if oref == NULL:
 *         return (None, MemoryError("Failed to make new global reference"))             # <<<<<<<<<<<<<<
 *     env.env[0].DeleteLocalRef(env.env, o)
 *     jbo = JB_Object()
 */
  __pyx_k_tuple_47 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_s_46)); if (unlikely(!__pyx_k_tuple_47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1519; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_47);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_47));

  /* "numpy.pxd":215
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
  __pyx_k_tuple_49 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_48)); if (unlikely(!__pyx_k_tuple_49)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 215; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_49);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_49));

  /* "numpy.pxd":219
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
  __pyx_k_tuple_51 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_50)); if (unlikely(!__pyx_k_tuple_51)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_51);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_51));

  /* "numpy.pxd":257
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
  __pyx_k_tuple_53 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_52)); if (unlikely(!__pyx_k_tuple_53)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_53);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_53));

  /* "numpy.pxd":799
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
  __pyx_k_tuple_56 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_55)); if (unlikely(!__pyx_k_tuple_56)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_56);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_56));

  /* "numpy.pxd":803
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
  __pyx_k_tuple_57 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_52)); if (unlikely(!__pyx_k_tuple_57)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_57);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_57));

  /* "numpy.pxd":823
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
  __pyx_k_tuple_59 = PyTuple_Pack(1, ((PyObject *)__pyx_kp_u_58)); if (unlikely(!__pyx_k_tuple_59)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_59);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_59));

  /* "javabridge/_javabridge.pyx":314
 * 
 * 
 * def get_default_java_vm_init_args():             # <<<<<<<<<<<<<<
 *     '''Return the version and default option strings as a tuple'''
 *     cdef:
 */
  __pyx_k_tuple_61 = PyTuple_Pack(3, ((PyObject *)__pyx_n_s__args), ((PyObject *)__pyx_n_s__result), ((PyObject *)__pyx_n_s__i)); if (unlikely(!__pyx_k_tuple_61)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 314; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_61);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_61));
  __pyx_k_codeobj_62 = (PyObject*)__Pyx_PyCode_New(0, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_k_tuple_61, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_64, __pyx_n_s_63, 314, __pyx_empty_bytes); if (unlikely(!__pyx_k_codeobj_62)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 314; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_javabridge(void); /*proto*/
PyMODINIT_FUNC init_javabridge(void)
#else
PyMODINIT_FUNC PyInit__javabridge(void); /*proto*/
PyMODINIT_FUNC PyInit__javabridge(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__javabridge(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("_javabridge"), __pyx_methods, __Pyx_DOCSTR(__pyx_k_60), 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "javabridge._javabridge")) {
      if (unlikely(PyDict_SetItemString(modules, "javabridge._javabridge", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_module_is_main_javabridge___javabridge) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  __pyx_ptype_10javabridge_11_javabridge_ndarray = __Pyx_ImportType("numpy", "ndarray", sizeof(PyArrayObject), 0); if (unlikely(!__pyx_ptype_10javabridge_11_javabridge_ndarray)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyType_Ready(&__pyx_type_10javabridge_11_javabridge_JB_Object) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 323; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "JB_Object", (PyObject *)&__pyx_type_10javabridge_11_javabridge_JB_Object) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 323; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_10javabridge_11_javabridge_JB_Object = &__pyx_type_10javabridge_11_javabridge_JB_Object;
  if (PyType_Ready(&__pyx_type_10javabridge_11_javabridge_JB_Class) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 344; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "JB_Class", (PyObject *)&__pyx_type_10javabridge_11_javabridge_JB_Class) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 344; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_10javabridge_11_javabridge_JB_Class = &__pyx_type_10javabridge_11_javabridge_JB_Class;
  if (PyType_Ready(&__pyx_type_10javabridge_11_javabridge___JB_MethodID) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 353; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "__JB_MethodID", (PyObject *)&__pyx_type_10javabridge_11_javabridge___JB_MethodID) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 353; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_10javabridge_11_javabridge___JB_MethodID = &__pyx_type_10javabridge_11_javabridge___JB_MethodID;
  if (PyType_Ready(&__pyx_type_10javabridge_11_javabridge___JB_FieldID) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "__JB_FieldID", (PyObject *)&__pyx_type_10javabridge_11_javabridge___JB_FieldID) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_10javabridge_11_javabridge___JB_FieldID = &__pyx_type_10javabridge_11_javabridge___JB_FieldID;
  if (PyType_Ready(&__pyx_type_10javabridge_11_javabridge_JB_VM) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 448; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "JB_VM", (PyObject *)&__pyx_type_10javabridge_11_javabridge_JB_VM) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 448; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_10javabridge_11_javabridge_JB_VM = &__pyx_type_10javabridge_11_javabridge_JB_VM;
  if (PyType_Ready(&__pyx_type_10javabridge_11_javabridge_JB_Env) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 546; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "JB_Env", (PyObject *)&__pyx_type_10javabridge_11_javabridge_JB_Env) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 546; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_10javabridge_11_javabridge_JB_Env = &__pyx_type_10javabridge_11_javabridge_JB_Env;
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "type", 
  #if CYTHON_COMPILING_IN_PYPY
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  0); if (unlikely(!__pyx_ptype_7cpython_4type_type)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType("numpy", "dtype", sizeof(PyArray_Descr), 0); if (unlikely(!__pyx_ptype_5numpy_dtype)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType("numpy", "flatiter", sizeof(PyArrayIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_flatiter)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType("numpy", "broadcast", sizeof(PyArrayMultiIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_broadcast)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType("numpy", "ndarray", sizeof(PyArrayObject), 0); if (unlikely(!__pyx_ptype_5numpy_ndarray)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType("numpy", "ufunc", sizeof(PyUFuncObject), 0); if (unlikely(!__pyx_ptype_5numpy_ufunc)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 861; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "javabridge/_javabridge.pyx":29
 * '''
 * 
 * import numpy as np             # <<<<<<<<<<<<<<
 * import sys
 * cimport numpy as np
 */
  __pyx_t_1 = __Pyx_Import(((PyObject *)__pyx_n_s__numpy), 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 29; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__np, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 29; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":30
 * 
 * import numpy as np
 * import sys             # <<<<<<<<<<<<<<
 * cimport numpy as np
 * cimport cython
 */
  __pyx_t_1 = __Pyx_Import(((PyObject *)__pyx_n_s__sys), 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__sys, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":57
 *     cdef int  PyArray_ITEMSIZE(np.ndarray)
 * 
 * import_array()             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "jni.h":
 */
  import_array();

  /* "javabridge/_javabridge.pyx":314
 * 
 * 
 * def get_default_java_vm_init_args():             # <<<<<<<<<<<<<<
 *     '''Return the version and default option strings as a tuple'''
 *     cdef:
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_10javabridge_11_javabridge_1get_default_java_vm_init_args, NULL, __pyx_n_s_65); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 314; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_63, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 314; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "javabridge/_javabridge.pyx":1
 * '''javabridge - a Python/Java bridge via JNI             # <<<<<<<<<<<<<<
 * 
 * javabridge is designed to wrap JNI at the lowest level. The bridge can create
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s____test__, ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "numpy.pxd":975
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  if (__pyx_m) {
    __Pyx_AddTraceback("init javabridge._javabridge", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init javabridge._javabridge");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetName(PyObject *dict, PyObject *name) {
    PyObject *result;
    result = PyObject_GetAttr(dict, name);
    if (!result) {
        if (dict != __pyx_b) {
            PyErr_Clear();
            result = PyObject_GetAttr(__pyx_b, name);
        }
        if (!result) {
            PyErr_SetObject(PyExc_NameError, name);
        }
    }
    return result;
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%s() takes %s %" CYTHON_FORMAT_SSIZE_T "d positional argument%s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if CYTHON_COMPILING_IN_PYPY
    float_value = PyNumber_Float(obj);
#else
    if (Py_TYPE(obj)->tp_as_number && Py_TYPE(obj)->tp_as_number->nb_float) {
        return PyFloat_AsDouble(obj);
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    #if PY_VERSION_HEX < 0x02050000
    if (PyClass_Check(type)) {
    #else
    if (PyType_Check(type)) {
    #endif
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        #if PY_VERSION_HEX < 0x02050000
            if (PyInstance_Check(type)) {
                type = (PyObject*) ((PyInstanceObject*)type)->in_class;
                Py_INCREF(type);
            }
            else {
                type = 0;
                PyErr_SetString(PyExc_TypeError,
                    "raise: exception must be an old-style class or instance");
                goto raise_error;
            }
        #else
            type = (PyObject*) Py_TYPE(type);
            Py_INCREF(type);
            if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
                PyErr_SetString(PyExc_TypeError,
                    "raise: exception class must be a subclass of BaseException");
                goto raise_error;
            }
        #endif
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else /* Python 3+ */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *args;
        if (!value)
            args = PyTuple_New(0);
        else if (PyTuple_Check(value)) {
            Py_INCREF(value);
            args = value;
        }
        else
            args = PyTuple_Pack(1, value);
        if (!args)
            goto bad;
        owned_instance = PyEval_CallObject(type, args);
        Py_DECREF(args);
        if (!owned_instance)
            goto bad;
        value = owned_instance;
        if (!PyExceptionInstance_Check(value)) {
            PyErr_Format(PyExc_TypeError,
                         "calling %R should have returned an instance of "
                         "BaseException, not %R",
                         type, Py_TYPE(value));
            goto bad;
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause && cause != Py_None) {
        PyObject *fixed_cause;
        if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        }
        else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        }
        else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact)
{
    if (!type) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (none_allowed && obj == Py_None) return 1;
    else if (exact) {
        if (Py_TYPE(obj) == type) return 1;
    }
    else {
        if (PyObject_TypeCheck(obj, type)) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%s' has incorrect type (expected %s, got %s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

static CYTHON_INLINE long __Pyx_div_long(long a, long b) {
    long q = a / b;
    long r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

static CYTHON_INLINE long __Pyx_mod_long(long a, long b) {
    long r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

static CYTHON_INLINE int __Pyx_IsLittleEndian(void) {
  unsigned int n = 1;
  return *(unsigned char*)(&n) != 0;
}
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t < '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1) /* First char was not a digit */
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparseable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count; /* Consume from buffer string */
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break; /* breaks both loops as ctx->enc_count == 0 */
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue; /* empty struct */
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static CYTHON_INLINE PyObject *
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number;
    int ndim = ctx->head->field->type->ndim;
;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return NULL;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
    while (*ts && *ts != ')') {
        if (isspace(*ts))
            continue;
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return NULL;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i])
            return PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
        if (*ts != ',' && *ts != ')')
            return PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim)
        return PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return NULL;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return Py_None;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
                return ts;
      case ' ':
      case 10:
      case 13:
        ++ts;
        break;
      case '<':
        if (!__Pyx_IsLittleEndian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_IsLittleEndian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T': /* substruct */
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0; /* Erase processed last struct element */
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}': /* end of substruct; either repeat or move on */
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0; /* Erase processed last struct element */
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }        /* fall through */
      case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 's': case 'p':
        if (ctx->enc_type == *ts && got_Z == ctx->is_complex &&
            ctx->enc_packmode == ctx->new_packmode) {
          ctx->enc_count += ctx->new_count;
        } else {
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_count = ctx->new_count;
          ctx->enc_packmode = ctx->new_packmode;
          ctx->enc_type = *ts;
          ctx->is_complex = got_Z;
        }
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (!__pyx_buffmt_parse_array(ctx, &ts)) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}
static CYTHON_INLINE void __Pyx_ZeroBuffer(Py_buffer* buf) {
  buf->buf = NULL;
  buf->obj = NULL;
  buf->strides = __Pyx_zeros;
  buf->shape = __Pyx_zeros;
  buf->suboffsets = __Pyx_minusones;
}
static CYTHON_INLINE int __Pyx_GetBufferAndValidate(
        Py_buffer* buf, PyObject* obj,  __Pyx_TypeInfo* dtype, int flags,
        int nd, int cast, __Pyx_BufFmt_StackElem* stack)
{
  if (obj == Py_None || obj == NULL) {
    __Pyx_ZeroBuffer(buf);
    return 0;
  }
  buf->buf = NULL;
  if (__Pyx_GetBuffer(obj, buf, flags) == -1) goto fail;
  if (buf->ndim != nd) {
    PyErr_Format(PyExc_ValueError,
                 "Buffer has wrong number of dimensions (expected %d, got %d)",
                 nd, buf->ndim);
    goto fail;
  }
  if (!cast) {
    __Pyx_BufFmt_Context ctx;
    __Pyx_BufFmt_Init(&ctx, stack, dtype);
    if (!__Pyx_BufFmt_CheckString(&ctx, buf->format)) goto fail;
  }
  if ((unsigned)buf->itemsize != dtype->size) {
    PyErr_Format(PyExc_ValueError,
      "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "d byte%s) does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "d byte%s)",
      buf->itemsize, (buf->itemsize > 1) ? "s" : "",
      dtype->name, (Py_ssize_t)dtype->size, (dtype->size > 1) ? "s" : "");
    goto fail;
  }
  if (buf->suboffsets == NULL) buf->suboffsets = __Pyx_minusones;
  return 0;
fail:;
  __Pyx_ZeroBuffer(buf);
  return -1;
}
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info) {
  if (info->buf == NULL) return;
  if (info->suboffsets == __Pyx_minusones) info->suboffsets = NULL;
  __Pyx_ReleaseBuffer(info);
}

static void __Pyx_RaiseBufferFallbackError(void) {
  PyErr_Format(PyExc_ValueError,
     "Buffer acquisition failed on assignment; and then reacquiring the old buffer failed too!");
}

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    CYTHON_UNUSED PyObject *getbuffer_cobj;
  #if PY_VERSION_HEX >= 0x02060000
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
  #endif
        if (PyObject_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) return __pyx_pw_5numpy_7ndarray_1__getbuffer__(obj, view, flags);
  #if PY_VERSION_HEX < 0x02060000
    if (obj->ob_type->tp_dict &&
        (getbuffer_cobj = PyMapping_GetItemString(obj->ob_type->tp_dict,
                                             "__pyx_getbuffer"))) {
        getbufferproc func;
      #if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION == 0)
        func = (getbufferproc) PyCapsule_GetPointer(getbuffer_cobj, "getbuffer(obj, view, flags)");
      #else
        func = (getbufferproc) PyCObject_AsVoidPtr(getbuffer_cobj);
      #endif
        Py_DECREF(getbuffer_cobj);
        if (!func)
            goto fail;
        return func(obj, view, flags);
    } else {
        PyErr_Clear();
    }
  #endif
    PyErr_Format(PyExc_TypeError, "'%100s' does not have the buffer interface", Py_TYPE(obj)->tp_name);
#if PY_VERSION_HEX < 0x02060000
fail:
#endif
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    CYTHON_UNUSED PyObject *releasebuffer_cobj;
    if (!obj) return;
  #if PY_VERSION_HEX >= 0x02060000
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
  #endif
        if (PyObject_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) { __pyx_pw_5numpy_7ndarray_3__releasebuffer__(obj, view); return; }
  #if PY_VERSION_HEX < 0x02060000
    if (obj->ob_type->tp_dict &&
        (releasebuffer_cobj = PyMapping_GetItemString(obj->ob_type->tp_dict,
                                                      "__pyx_releasebuffer"))) {
        releasebufferproc func;
      #if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION == 0)
        func = (releasebufferproc) PyCapsule_GetPointer(releasebuffer_cobj, "releasebuffer(obj, view)");
      #else
        func = (releasebufferproc) PyCObject_AsVoidPtr(releasebuffer_cobj);
      #endif
        Py_DECREF(releasebuffer_cobj);
        if (!func)
            goto fail;
        func(obj, view);
        return;
    } else {
        PyErr_Clear();
    }
  #endif
    goto nofail;
#if PY_VERSION_HEX < 0x02060000
fail:
#endif
    PyErr_WriteUnraisable(obj);
nofail:
    Py_DECREF(obj);
    view->obj = NULL;
}
#endif /*  PY_MAJOR_VERSION < 3 */


    static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import = 0;
    py_import = __Pyx_GetAttrString(__pyx_b, "__import__");
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jint(jint val) {
    const jint neg_one = (jint)-1, const_zero = (jint)0;
    const int is_unsigned = const_zero < neg_one;
    if ((sizeof(jint) == sizeof(char))  ||
        (sizeof(jint) == sizeof(short))) {
        return PyInt_FromLong((long)val);
    } else if ((sizeof(jint) == sizeof(int)) ||
               (sizeof(jint) == sizeof(long))) {
        if (is_unsigned)
            return PyLong_FromUnsignedLong((unsigned long)val);
        else
            return PyInt_FromLong((long)val);
    } else if (sizeof(jint) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG)val);
        else
            return PyLong_FromLongLong((PY_LONG_LONG)val);
    } else {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        return _PyLong_FromByteArray(bytes, sizeof(jint),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE jint __Pyx_PyInt_from_py_jint(PyObject* x) {
    const jint neg_one = (jint)-1, const_zero = (jint)0;
    const int is_unsigned = const_zero < neg_one;
    if (sizeof(jint) == sizeof(char)) {
        if (is_unsigned)
            return (jint)__Pyx_PyInt_AsUnsignedChar(x);
        else
            return (jint)__Pyx_PyInt_AsSignedChar(x);
    } else if (sizeof(jint) == sizeof(short)) {
        if (is_unsigned)
            return (jint)__Pyx_PyInt_AsUnsignedShort(x);
        else
            return (jint)__Pyx_PyInt_AsSignedShort(x);
    } else if (sizeof(jint) == sizeof(int)) {
        if (is_unsigned)
            return (jint)__Pyx_PyInt_AsUnsignedInt(x);
        else
            return (jint)__Pyx_PyInt_AsSignedInt(x);
    } else if (sizeof(jint) == sizeof(long)) {
        if (is_unsigned)
            return (jint)__Pyx_PyInt_AsUnsignedLong(x);
        else
            return (jint)__Pyx_PyInt_AsSignedLong(x);
    } else if (sizeof(jint) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return (jint)__Pyx_PyInt_AsUnsignedLongLong(x);
        else
            return (jint)__Pyx_PyInt_AsSignedLongLong(x);
    }  else {
        #if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
        #else
        jint val;
        PyObject *v = __Pyx_PyNumber_Int(x);
        #if PY_VERSION_HEX < 0x03000000
        if (likely(v) && !PyLong_Check(v)) {
            PyObject *tmp = v;
            v = PyNumber_Long(tmp);
            Py_DECREF(tmp);
        }
        #endif
        if (likely(v)) {
            int one = 1; int is_little = (int)*(unsigned char *)&one;
            unsigned char *bytes = (unsigned char *)&val;
            int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                          bytes, sizeof(val),
                                          is_little, !is_unsigned);
            Py_DECREF(v);
            if (likely(!ret))
                return val;
        }
        #endif
        return (jint)-1;
    }
}

static CYTHON_INLINE jbyte __Pyx_PyInt_from_py_jbyte(PyObject* x) {
    const jbyte neg_one = (jbyte)-1, const_zero = (jbyte)0;
    const int is_unsigned = const_zero < neg_one;
    if (sizeof(jbyte) == sizeof(char)) {
        if (is_unsigned)
            return (jbyte)__Pyx_PyInt_AsUnsignedChar(x);
        else
            return (jbyte)__Pyx_PyInt_AsSignedChar(x);
    } else if (sizeof(jbyte) == sizeof(short)) {
        if (is_unsigned)
            return (jbyte)__Pyx_PyInt_AsUnsignedShort(x);
        else
            return (jbyte)__Pyx_PyInt_AsSignedShort(x);
    } else if (sizeof(jbyte) == sizeof(int)) {
        if (is_unsigned)
            return (jbyte)__Pyx_PyInt_AsUnsignedInt(x);
        else
            return (jbyte)__Pyx_PyInt_AsSignedInt(x);
    } else if (sizeof(jbyte) == sizeof(long)) {
        if (is_unsigned)
            return (jbyte)__Pyx_PyInt_AsUnsignedLong(x);
        else
            return (jbyte)__Pyx_PyInt_AsSignedLong(x);
    } else if (sizeof(jbyte) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return (jbyte)__Pyx_PyInt_AsUnsignedLongLong(x);
        else
            return (jbyte)__Pyx_PyInt_AsSignedLongLong(x);
    }  else {
        #if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
        #else
        jbyte val;
        PyObject *v = __Pyx_PyNumber_Int(x);
        #if PY_VERSION_HEX < 0x03000000
        if (likely(v) && !PyLong_Check(v)) {
            PyObject *tmp = v;
            v = PyNumber_Long(tmp);
            Py_DECREF(tmp);
        }
        #endif
        if (likely(v)) {
            int one = 1; int is_little = (int)*(unsigned char *)&one;
            unsigned char *bytes = (unsigned char *)&val;
            int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                          bytes, sizeof(val),
                                          is_little, !is_unsigned);
            Py_DECREF(v);
            if (likely(!ret))
                return val;
        }
        #endif
        return (jbyte)-1;
    }
}

static CYTHON_INLINE jshort __Pyx_PyInt_from_py_jshort(PyObject* x) {
    const jshort neg_one = (jshort)-1, const_zero = (jshort)0;
    const int is_unsigned = const_zero < neg_one;
    if (sizeof(jshort) == sizeof(char)) {
        if (is_unsigned)
            return (jshort)__Pyx_PyInt_AsUnsignedChar(x);
        else
            return (jshort)__Pyx_PyInt_AsSignedChar(x);
    } else if (sizeof(jshort) == sizeof(short)) {
        if (is_unsigned)
            return (jshort)__Pyx_PyInt_AsUnsignedShort(x);
        else
            return (jshort)__Pyx_PyInt_AsSignedShort(x);
    } else if (sizeof(jshort) == sizeof(int)) {
        if (is_unsigned)
            return (jshort)__Pyx_PyInt_AsUnsignedInt(x);
        else
            return (jshort)__Pyx_PyInt_AsSignedInt(x);
    } else if (sizeof(jshort) == sizeof(long)) {
        if (is_unsigned)
            return (jshort)__Pyx_PyInt_AsUnsignedLong(x);
        else
            return (jshort)__Pyx_PyInt_AsSignedLong(x);
    } else if (sizeof(jshort) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return (jshort)__Pyx_PyInt_AsUnsignedLongLong(x);
        else
            return (jshort)__Pyx_PyInt_AsSignedLongLong(x);
    }  else {
        #if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
        #else
        jshort val;
        PyObject *v = __Pyx_PyNumber_Int(x);
        #if PY_VERSION_HEX < 0x03000000
        if (likely(v) && !PyLong_Check(v)) {
            PyObject *tmp = v;
            v = PyNumber_Long(tmp);
            Py_DECREF(tmp);
        }
        #endif
        if (likely(v)) {
            int one = 1; int is_little = (int)*(unsigned char *)&one;
            unsigned char *bytes = (unsigned char *)&val;
            int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                          bytes, sizeof(val),
                                          is_little, !is_unsigned);
            Py_DECREF(v);
            if (likely(!ret))
                return val;
        }
        #endif
        return (jshort)-1;
    }
}

static CYTHON_INLINE jlong __Pyx_PyInt_from_py_jlong(PyObject* x) {
    const jlong neg_one = (jlong)-1, const_zero = (jlong)0;
    const int is_unsigned = const_zero < neg_one;
    if (sizeof(jlong) == sizeof(char)) {
        if (is_unsigned)
            return (jlong)__Pyx_PyInt_AsUnsignedChar(x);
        else
            return (jlong)__Pyx_PyInt_AsSignedChar(x);
    } else if (sizeof(jlong) == sizeof(short)) {
        if (is_unsigned)
            return (jlong)__Pyx_PyInt_AsUnsignedShort(x);
        else
            return (jlong)__Pyx_PyInt_AsSignedShort(x);
    } else if (sizeof(jlong) == sizeof(int)) {
        if (is_unsigned)
            return (jlong)__Pyx_PyInt_AsUnsignedInt(x);
        else
            return (jlong)__Pyx_PyInt_AsSignedInt(x);
    } else if (sizeof(jlong) == sizeof(long)) {
        if (is_unsigned)
            return (jlong)__Pyx_PyInt_AsUnsignedLong(x);
        else
            return (jlong)__Pyx_PyInt_AsSignedLong(x);
    } else if (sizeof(jlong) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return (jlong)__Pyx_PyInt_AsUnsignedLongLong(x);
        else
            return (jlong)__Pyx_PyInt_AsSignedLongLong(x);
    }  else {
        #if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
        #else
        jlong val;
        PyObject *v = __Pyx_PyNumber_Int(x);
        #if PY_VERSION_HEX < 0x03000000
        if (likely(v) && !PyLong_Check(v)) {
            PyObject *tmp = v;
            v = PyNumber_Long(tmp);
            Py_DECREF(tmp);
        }
        #endif
        if (likely(v)) {
            int one = 1; int is_little = (int)*(unsigned char *)&one;
            unsigned char *bytes = (unsigned char *)&val;
            int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                          bytes, sizeof(val),
                                          is_little, !is_unsigned);
            Py_DECREF(v);
            if (likely(!ret))
                return val;
        }
        #endif
        return (jlong)-1;
    }
}

#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static PyObject *__Pyx_GetStdout(void) {
    PyObject *f = PySys_GetObject((char *)"stdout");
    if (!f) {
        PyErr_SetString(PyExc_RuntimeError, "lost sys.stdout");
    }
    return f;
}
static int __Pyx_Print(PyObject* f, PyObject *arg_tuple, int newline) {
    int i;
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    for (i=0; i < PyTuple_GET_SIZE(arg_tuple); i++) {
        PyObject* v;
        if (PyFile_SoftSpace(f, 1)) {
            if (PyFile_WriteString(" ", f) < 0)
                goto error;
        }
        v = PyTuple_GET_ITEM(arg_tuple, i);
        if (PyFile_WriteObject(v, f, Py_PRINT_RAW) < 0)
            goto error;
        if (PyString_Check(v)) {
            char *s = PyString_AsString(v);
            Py_ssize_t len = PyString_Size(v);
            if (len > 0 &&
                isspace(Py_CHARMASK(s[len-1])) &&
                s[len-1] != ' ')
                    PyFile_SoftSpace(f, 0);
        }
    }
    if (newline) {
        if (PyFile_WriteString("\n", f) < 0)
            goto error;
        PyFile_SoftSpace(f, 0);
    }
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
}
#else /* Python 3 has a print function */
static int __Pyx_Print(PyObject* stream, PyObject *arg_tuple, int newline) {
    PyObject* kwargs = 0;
    PyObject* result = 0;
    PyObject* end_string;
    if (unlikely(!__pyx_print)) {
        __pyx_print = __Pyx_GetAttrString(__pyx_b, "print");
        if (!__pyx_print)
            return -1;
    }
    if (stream) {
        kwargs = PyDict_New();
        if (unlikely(!kwargs))
            return -1;
        if (unlikely(PyDict_SetItemString(kwargs, "file", stream) < 0))
            goto bad;
        if (!newline) {
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                goto bad;
            if (PyDict_SetItemString(kwargs, "end", end_string) < 0) {
                Py_DECREF(end_string);
                goto bad;
            }
            Py_DECREF(end_string);
        }
    } else if (!newline) {
        if (unlikely(!__pyx_print_kwargs)) {
            __pyx_print_kwargs = PyDict_New();
            if (unlikely(!__pyx_print_kwargs))
                return -1;
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                return -1;
            if (PyDict_SetItemString(__pyx_print_kwargs, "end", end_string) < 0) {
                Py_DECREF(end_string);
                return -1;
            }
            Py_DECREF(end_string);
        }
        kwargs = __pyx_print_kwargs;
    }
    result = PyObject_Call(__pyx_print, arg_tuple, kwargs);
    if (unlikely(kwargs) && (kwargs != __pyx_print_kwargs))
        Py_DECREF(kwargs);
    if (!result)
        return -1;
    Py_DECREF(result);
    return 0;
bad:
    if (kwargs != __pyx_print_kwargs)
        Py_XDECREF(kwargs);
    return -1;
}
#endif

#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static int __Pyx_PrintOne(PyObject* f, PyObject *o) {
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    if (PyFile_SoftSpace(f, 0)) {
        if (PyFile_WriteString(" ", f) < 0)
            goto error;
    }
    if (PyFile_WriteObject(o, f, Py_PRINT_RAW) < 0)
        goto error;
    if (PyFile_WriteString("\n", f) < 0)
        goto error;
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
    /* the line below is just to avoid C compiler
     * warnings about unused functions */
    return __Pyx_Print(f, NULL, 0);
}
#else /* Python 3 has a print function */
static int __Pyx_PrintOne(PyObject* stream, PyObject *o) {
    int res;
    PyObject* arg_tuple = PyTuple_Pack(1, o);
    if (unlikely(!arg_tuple))
        return -1;
    res = __Pyx_Print(stream, arg_tuple, 1);
    Py_DECREF(arg_tuple);
    return res;
}
#endif

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jbyte(jbyte val) {
    const jbyte neg_one = (jbyte)-1, const_zero = (jbyte)0;
    const int is_unsigned = const_zero < neg_one;
    if ((sizeof(jbyte) == sizeof(char))  ||
        (sizeof(jbyte) == sizeof(short))) {
        return PyInt_FromLong((long)val);
    } else if ((sizeof(jbyte) == sizeof(int)) ||
               (sizeof(jbyte) == sizeof(long))) {
        if (is_unsigned)
            return PyLong_FromUnsignedLong((unsigned long)val);
        else
            return PyInt_FromLong((long)val);
    } else if (sizeof(jbyte) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG)val);
        else
            return PyLong_FromLongLong((PY_LONG_LONG)val);
    } else {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        return _PyLong_FromByteArray(bytes, sizeof(jbyte),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jchar(jchar val) {
    const jchar neg_one = (jchar)-1, const_zero = (jchar)0;
    const int is_unsigned = const_zero < neg_one;
    if ((sizeof(jchar) == sizeof(char))  ||
        (sizeof(jchar) == sizeof(short))) {
        return PyInt_FromLong((long)val);
    } else if ((sizeof(jchar) == sizeof(int)) ||
               (sizeof(jchar) == sizeof(long))) {
        if (is_unsigned)
            return PyLong_FromUnsignedLong((unsigned long)val);
        else
            return PyInt_FromLong((long)val);
    } else if (sizeof(jchar) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG)val);
        else
            return PyLong_FromLongLong((PY_LONG_LONG)val);
    } else {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        return _PyLong_FromByteArray(bytes, sizeof(jchar),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jshort(jshort val) {
    const jshort neg_one = (jshort)-1, const_zero = (jshort)0;
    const int is_unsigned = const_zero < neg_one;
    if ((sizeof(jshort) == sizeof(char))  ||
        (sizeof(jshort) == sizeof(short))) {
        return PyInt_FromLong((long)val);
    } else if ((sizeof(jshort) == sizeof(int)) ||
               (sizeof(jshort) == sizeof(long))) {
        if (is_unsigned)
            return PyLong_FromUnsignedLong((unsigned long)val);
        else
            return PyInt_FromLong((long)val);
    } else if (sizeof(jshort) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG)val);
        else
            return PyLong_FromLongLong((PY_LONG_LONG)val);
    } else {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        return _PyLong_FromByteArray(bytes, sizeof(jshort),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_jlong(jlong val) {
    const jlong neg_one = (jlong)-1, const_zero = (jlong)0;
    const int is_unsigned = const_zero < neg_one;
    if ((sizeof(jlong) == sizeof(char))  ||
        (sizeof(jlong) == sizeof(short))) {
        return PyInt_FromLong((long)val);
    } else if ((sizeof(jlong) == sizeof(int)) ||
               (sizeof(jlong) == sizeof(long))) {
        if (is_unsigned)
            return PyLong_FromUnsignedLong((unsigned long)val);
        else
            return PyInt_FromLong((long)val);
    } else if (sizeof(jlong) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG)val);
        else
            return PyLong_FromLongLong((PY_LONG_LONG)val);
    } else {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        return _PyLong_FromByteArray(bytes, sizeof(jlong),
                                     little, !is_unsigned);
    }
}

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eqf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sumf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_difff(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prodf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quotf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        float denom = b.real * b.real + b.imag * b.imag;
        z.real = (a.real * b.real + a.imag * b.imag) / denom;
        z.imag = (a.imag * b.real - a.real * b.imag) / denom;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_negf(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zerof(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conjf(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_absf(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_powf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(a, a);
                    case 3:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(z, a);
                    case 4:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                }
                r = a.real;
                theta = 0;
            } else {
                r = __Pyx_c_absf(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        double denom = b.real * b.real + b.imag * b.imag;
        z.real = (a.real * b.real + a.imag * b.imag) / denom;
        z.imag = (a.imag * b.real - a.real * b.imag) / denom;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(a, a);
                    case 3:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(z, a);
                    case 4:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                }
                r = a.real;
                theta = 0;
            } else {
                r = __Pyx_c_abs(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%s.%s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        #if PY_VERSION_HEX < 0x02050000
        if (PyErr_Warn(NULL, warning) < 0) goto bad;
        #else
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
        #endif
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%s.%s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_VERSION_HEX < 0x03000000
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_VERSION_HEX < 0x03000000
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val == (unsigned PY_LONG_LONG)-1 && PyErr_Occurred())) {
       return (size_t)-1;
   } else if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       PyErr_SetString(PyExc_OverflowError,
                       "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
